@@ -42,7 +42,8 @@ namespace vtkpiston {
   int QueryVertsPer(vtkPistonDataObject *id);
   void CudaRegisterBuffer(struct cudaGraphicsResource **vboResource,
                           GLuint vboBuffer);
-  void CudaTransferToGL(vtkPistonDataObject *id, unsigned long dataObjectMTimeCache,
+  void CudaUnregisterResource(struct cudaGraphicsResource* vboResource);
+  void CudaTransferToGL(vtkPistonDataObject *id, vtkMTimeType dataObjectMTimeCache,
                         vtkPistonScalarsColors *psc,
                         struct cudaGraphicsResource **vboResources,
                         bool &hasNormals, bool &hasColors);
@@ -81,7 +82,7 @@ public:
   GLuint vboBuffers[3];
   struct cudaGraphicsResource* vboResources[3];
 
-  unsigned long DataObjectMTimeCache;
+  vtkMTimeType DataObjectMTimeCache;
   vtkPistonScalarsColors *PistonScalarsColors;
 };
 
@@ -114,6 +115,8 @@ void vtkPistonMapper::InitCudaGL(vtkRenderWindow *rw)
 //-----------------------------------------------------------------------------
 vtkPistonMapper::vtkPistonMapper()
 {
+  VTK_LEGACY_BODY(vtkPistonMapper::vtkPistonMapper, "VTK 6.3");
+
   //cerr << "PM(" << this << ") create" << endl;
   vtkMath::UninitializeBounds(this->Bounds);
   this->Center[0] = this->Center[1] = this->Center[2] = 0.0;
@@ -148,6 +151,9 @@ void vtkPistonMapper::PrepareDirectRenderBuffers(int nPoints)
   if (this->Internal->BufferSize != 0)
     {
     // Release old buffer
+    vtkpiston::CudaUnregisterResource(this->Internal->vboResources[0]);
+    vtkpiston::CudaUnregisterResource(this->Internal->vboResources[1]);
+    vtkpiston::CudaUnregisterResource(this->Internal->vboResources[2]);
     vtkgl::DeleteBuffers(3, this->Internal->vboBuffers);
     vtkOpenGLCheckErrorMacro("failed at glDeleteBuffers");
     }
@@ -235,15 +241,15 @@ void vtkPistonMapper::RenderOnCPU()
 
   int vertsPer = vtkpiston::QueryVertsPer(id);
 
-  vtkFloatArray *normals = vtkFloatArray::SafeDownCast(
+  vtkFloatArray *normals = vtkArrayDownCast<vtkFloatArray>(
       od->GetPointData()->GetNormals());
   if (!normals)
     {
-     normals = vtkFloatArray::SafeDownCast(
+     normals = vtkArrayDownCast<vtkFloatArray>(
        od->GetPointData()->GetArray("Normals"));
     }
 
-  vtkFloatArray *scalars = vtkFloatArray::SafeDownCast(
+  vtkFloatArray *scalars = vtkArrayDownCast<vtkFloatArray>(
       od->GetPointData()->GetScalars());
   if (scalars)
     {
@@ -582,18 +588,18 @@ void vtkPistonMapper::Update()
 {
   this->UpdateInformation();
 
-  vtkInformation* inInfo = this->GetInputInformation();
+  // vtkInformation* inInfo = this->GetInputInformation();
 
   // If the estimated pipeline memory usage is larger than
   // the memory limit, break the current piece into sub-pieces.
-  if (inInfo)
-    {
-    vtkStreamingDemandDrivenPipeline::SetUpdateExtent(
-      inInfo,
-      this->Piece,
-      this->NumberOfPieces,
-      this->GhostLevel);
-    }
+  // if (inInfo)
+  //   {
+  //   vtkStreamingDemandDrivenPipeline::SetUpdateExtent(
+  //     inInfo,
+  //     this->Piece,
+  //     this->NumberOfPieces,
+  //     this->GhostLevel);
+  //   }
 
   this->vtkMapper::Update();
 }
