@@ -26,7 +26,6 @@
 #include <cctype> // Header to ensure std::tolower is present
 #include <cstdlib>
 
-
 class vtkNamedColorsDataStore
 {
 public:
@@ -58,19 +57,19 @@ public:
   void GetColor(const vtkStdString & name, vtkColor4ub & color)
   {
     for(int i = 0; i < 3; ++i)
-      {
+    {
       color[i] = 0;
-      }
+    }
     color[3] = 255;
     if ( !name.empty() )
-      {
+    {
       vtkStdString s = this->ToLowercase(name);
       std::map<vtkStdString, vtkColor4ub>::iterator p = this->colorMap.find(s);
       if ( p != this->colorMap.end() )
-        {
+      {
         color = p->second;
-        }
       }
+    }
   }
 
   //-----------------------------------------------------------------------------
@@ -83,9 +82,9 @@ public:
     vtkColor4ub c;
     this->GetColor(name,c);
     for(int i = 0; i < c.GetSize(); ++i)
-      {
+    {
       color[i] = static_cast<double>(c[i] / 255.0);
-      }
+    }
   }
 
   //-----------------------------------------------------------------------------
@@ -98,9 +97,9 @@ public:
     vtkColor4ub c;
     this->GetColor(name,c);
     for(int i = 0; i < color.GetSize(); ++i)
-      {
+    {
       color[i] = c[i];
-      }
+    }
   }
 
   //-----------------------------------------------------------------------------
@@ -113,9 +112,9 @@ public:
     vtkColor4d c;
     this->GetColor(name,c);
     for(int i = 0; i < color.GetSize(); ++i)
-      {
+    {
       color[i] = c[i];
-      }
+    }
   }
 
   //-----------------------------------------------------------------------------
@@ -126,10 +125,10 @@ public:
   void SetColor(const vtkStdString & name, const vtkColor4ub & color)
   {
     if ( !name.empty() && color.GetSize() == 4 )
-      {
+    {
       vtkStdString s = this->ToLowercase(name);
       this->colorMap[s] = color;
-      }
+    }
   }
 
   //-----------------------------------------------------------------------------
@@ -140,16 +139,15 @@ public:
   void SetColor(const vtkStdString & name, const vtkColor4d & color)
   {
     if ( !name.empty() && color.GetSize() == 4 )
-      {
+    {
       vtkStdString s = this->ToLowercase(name);
-      std::vector<unsigned char> uv;
       unsigned char r, g, b, a;
       r = static_cast<unsigned char>(color.GetRed() * 255.0);
       g = static_cast<unsigned char>(color.GetGreen() * 255.0);
       b = static_cast<unsigned char>(color.GetBlue() * 255.0);
       a = static_cast<unsigned char>(color.GetAlpha() * 255.0);
       this->colorMap[s] = vtkColor4ub(r,g,b,a);
-      }
+    }
   }
 
   //-----------------------------------------------------------------------------
@@ -161,9 +159,9 @@ public:
   {
     vtkColor4ub c;
     for(int i = 0; i < 3; ++i)
-      {
+    {
       c[i] = color[i];
-      }
+    }
     c[3] = 255;
     this->SetColor(name,c);
   }
@@ -177,9 +175,9 @@ public:
   {
     vtkColor4d c;
     for(int i = 0; i < 3; ++i)
-      {
+    {
         c[i] = color[i];
-      }
+    }
     c[3] = 1.0;
     this->SetColor(name,c);
   }
@@ -190,14 +188,14 @@ public:
   void RemoveColor(const vtkStdString & name)
   {
     if (!name.empty())
-      {
+    {
       vtkStdString s = this->ToLowercase(name);
       std::map<vtkStdString, vtkColor4ub>::iterator p = this->colorMap.find(s);
       if ( p != this->colorMap.end() )
-        {
+      {
         this->colorMap.erase(p);
-        }
       }
+    }
   }
 
   //-----------------------------------------------------------------------------
@@ -216,9 +214,9 @@ std::vector<vtkStdString> GetColorNames()
   for(std::map<vtkStdString, vtkColor4ub>::const_iterator p =
     this->GetColorMap()->begin();
     p != this->GetColorMap()->end(); ++p )
-    {
+  {
     colorNames.push_back(p->first);
-    }
+  }
   return colorNames;
 }
 
@@ -232,50 +230,50 @@ std::vector<std::vector<vtkStdString> > GetSynonyms()
   std::map<vtkStdString, std::vector<vtkStdString> > synonyms;
   for ( std::vector<vtkStdString>::const_iterator p =
     cn.begin(); p != cn.end(); ++p )
-    {
+  {
     vtkColor4ub vu;
     this->GetColor(*p,vu);
     std::vector<vtkStdString> duplicates;
     for ( std::map<vtkStdString, vtkColor4ub>::const_iterator
       q = this->GetColorMap()->begin();
       q != this->GetColorMap()->end(); ++q )
-      {
+    {
       if( *p != q->first && vu.Compare( q->second, 1 ) )
-        {
-        duplicates.push_back(q->first);
-        }
-      }
-    if ( !duplicates.empty() )
       {
+        duplicates.push_back(q->first);
+      }
+    }
+    if ( !duplicates.empty() )
+    {
       bool alreadyInMap = false;
       for( std::vector<vtkStdString>::const_iterator r =
         duplicates.begin(); r != duplicates.end(); ++r)
-        {
+      {
         if( synonyms.find(*r) != synonyms.end() )
-          {
+        {
           alreadyInMap = true;
           break;
-          }
-        }
-      if ( !alreadyInMap )
-        {
-        synonyms[*p] = duplicates;
         }
       }
+      if ( !alreadyInMap )
+      {
+        synonyms[*p] = duplicates;
+      }
     }
+  }
   std::vector<std::vector<vtkStdString> > retVec;
   for(std::map<vtkStdString,std::vector<vtkStdString> >::const_iterator p =
     synonyms.begin(); p != synonyms.end(); ++p)
-    {
+  {
     std::vector<vtkStdString> vstr;
     vstr.push_back(p->first);
     for(std::vector<vtkStdString>::const_iterator q =
       p->second.begin(); q!= p->second.end(); ++q)
-      {
+    {
       vstr.push_back(*q);
-      }
-    retVec.push_back(vstr);
     }
+    retVec.push_back(vstr);
+  }
   return retVec;
 }
 
@@ -661,7 +659,7 @@ static const char *colorTable[] =
     // Here we fill the color map.
     size_t colorTableSz = sizeof(colorTable)/sizeof(colorTable[0]);
     for (size_t i = 0; i < colorTableSz; ++i)
-      {
+    {
       std::vector<unsigned char> color;
       vtkStdString s = colorTable[i];
       size_t idx = s.find(',');
@@ -684,7 +682,7 @@ static const char *colorTable[] =
       t = s.substr(start,s.size() - start); // Alpha
       color.push_back(static_cast<unsigned char>(atoi(t.c_str())));
       this->colorMap[name] = vtkColor4ub(color[0],color[1],color[2],color[3]);
-      }
+    }
   }
 
 private:
@@ -702,6 +700,263 @@ private:
   std::map<vtkStdString, vtkColor4ub> colorMap;
 };
 
+
+//------------------------------------------------------------------------------
+// Helper class for parsing a string which defines a RGB or RGBA color.
+class vtkColorStringParser
+{
+public:
+  vtkColorStringParser(vtkNamedColors* namedColors)
+  {
+    this->Color.Set(0, 0, 0, 255);
+    this->StateGood = true;
+    this->NamedColors = namedColors;
+  }
+
+  bool Parse(const vtkStdString& colorString);
+
+  const vtkColor4ub& GetColor() const
+  {
+    return this->Color;
+  }
+
+private:
+
+  void RGBAFuncStringToRGBA(vtkStdString color,
+                            vtkStdString::size_type pos,
+                            unsigned int argCount);
+
+  void HexStringToRGBA(vtkStdString color);
+
+  // Convert a string to lowercase.
+  vtkStdString ToLowercase(const vtkStdString & str)
+  {
+    vtkStdString s;
+    std::transform(str.begin(),str.end(),std::back_inserter(s),
+                   (int (*)(int))std::tolower);
+    return s;
+  }
+
+private:
+  vtkColor4ub Color;
+  bool StateGood;
+  vtkNamedColors* NamedColors;
+};
+
+//------------------------------------------------------------------------------
+// Parse a color string in any of the following format:
+// - #RGB
+// - #RGBA
+// - #RRGGBB
+// - rgb(r, g, b)
+// - rgba(r, g, b, a)
+// - a CSS3 color name, e.g. "steelblue"
+// If the passed string defines a color using one of the above formats returns
+// true else returns false.
+bool vtkColorStringParser::Parse(const vtkStdString& colorString)
+{
+  vtkStdString color = this->ToLowercase(colorString);
+
+  // Skip heading spaces.
+  vtkStdString::size_type pos = color.find_first_not_of(" \t");
+  this->StateGood = (pos != vtkStdString::npos);
+
+  if (this->StateGood)
+  {
+    if (color[pos] == '#')
+    {
+      // Trim trailing spaces.
+      vtkStdString::size_type last = color.find_last_not_of(" \t");
+      this->HexStringToRGBA(color.substr(pos + 1, last - pos));
+    }
+    else if (color.compare(pos, 4, "rgba") == 0)
+    {
+      this->RGBAFuncStringToRGBA(color, pos+4, 4);
+    }
+    else if (color.compare(pos, 3, "rgb") == 0)
+    {
+      this->RGBAFuncStringToRGBA(color, pos+3, 3);
+      this->Color[3] = 255;
+    }
+    else
+    {
+      this->StateGood = this->NamedColors->ColorExists(color);
+      if (this->StateGood)
+      {
+          this->NamedColors->GetColor(color, this->Color);
+      }
+    }
+  }
+
+  if (!this->StateGood)
+  {
+    this->Color.Set(0, 0, 0, 0);
+  }
+  return this->StateGood;
+}
+
+//------------------------------------------------------------------------------
+unsigned char clip(long int value)
+{
+  if (value < 0)
+  {
+    value = 0;
+  }
+  else if (value > 255)
+  {
+    value = 255;
+  }
+  return static_cast<unsigned char>(value);
+}
+
+//------------------------------------------------------------------------------
+double clip(double value)
+{
+  if (value < 0.0)
+  {
+    value = 0.0;
+  }
+  else if (value > 1.0)
+  {
+    value = 1.0;
+  }
+  return value;
+}
+
+//------------------------------------------------------------------------------
+double clipPercentage(double value)
+{
+  return clip(value / 100.0);
+}
+
+//------------------------------------------------------------------------------
+// Parse a string of type "#RRGGBB".
+// Heading and trailing spaces must be already trimmed.
+// If the parsed string is not valid set `StateGood` to false.
+void vtkColorStringParser::HexStringToRGBA(vtkStdString color)
+{
+  // Check if it is valid hexadecimal representation.
+  vtkStdString::size_type pos = color.find_first_not_of("0123456789abcdefABCDEF");
+  this->StateGood = (pos == vtkStdString::npos);
+
+  if (this->StateGood)
+  {
+    if (color.size() == 3) // #RGB -> #RRGGBB
+    {
+      color.resize(6);
+      vtkStdString::size_type i = 3, j = 6;
+      do
+      {
+        color[--j] = color[--i];
+        color[--j] = color[i];
+      } while (i != 0);
+    }
+    else if (color.size() != 6)
+    {
+      this->StateGood = false;
+    }
+
+    // Parse hex bytes.
+    if (this->StateGood)
+    {
+      std::istringstream istr;
+      int c;
+      for (unsigned int i = 0; i < 3; ++i)
+      {
+        istr.str(color.substr(i * 2, 2));
+        istr >> std::hex >> c;
+        this->Color[i] = static_cast<unsigned char>(c);
+        istr.clear();
+      }
+      this->Color[3] = 255;
+    }
+  }
+}
+
+//------------------------------------------------------------------------------
+// Parse a string of type "rgb(r, g, b)" or a "rgba(r, g, b, a)" and return
+// the parsed value in `Color`.
+// r, g, b must be integral value in 0..255 or percentage values in 0.0%..100.0%
+// a is a floating number in 0.0..1.0.
+// If the parsed string is not valid set `StateGood` to false.
+void vtkColorStringParser::RGBAFuncStringToRGBA(vtkStdString color,
+                                             vtkStdString::size_type pos,
+                                             unsigned int argCount)
+{
+  // Parse '('.
+  pos = color.find_first_not_of(" \t", pos);
+  this->StateGood = (pos != vtkStdString::npos && color[pos] == '(');
+
+  // Check if percentage values are used.
+  bool usePercentage = (color.find_first_of("%", pos+1) != vtkStdString::npos);
+
+  // Count and replace delimiters.
+  unsigned int delimiterCount = 0;
+  for (vtkStdString::size_type i = pos + 1;
+       (delimiterCount < argCount) && (i < color.size());
+       ++i)
+  {
+    if (color[i] == ',')
+    {
+      color[i] = ' ';
+      ++delimiterCount;
+    }
+  }
+  this->StateGood = (delimiterCount + 1 == argCount);
+
+  // Parse arguments.
+  const char* start = color.c_str() + pos + 1;
+  char* end;
+  char** final = &end;
+
+  if (!usePercentage)
+  {
+    long int value;
+    for (unsigned int i = 0; this->StateGood && (i < 3); ++i)
+    {
+      value = strtol(start, final, 10);
+      this->Color[i] = clip(value);
+      this->StateGood = (start != end);
+      start = end;
+    }
+  }
+  else
+  {
+    double value;
+    for (unsigned int i = 0; this->StateGood && (i < 3); ++i)
+    {
+      value = strtod(start, final);
+      this->Color[i] = static_cast<unsigned char>(255 * clipPercentage(value));
+      this->StateGood = (start != end && *end == '%');
+      start = ++end;
+    }
+  }
+
+  // Parse the alpha value if needed.
+  if (this->StateGood && argCount == 4)
+  {
+    double value = strtod(start, final);
+    this->Color[3] = static_cast<unsigned char>(255 * clip(value));
+    this->StateGood = (start != end);
+  }
+
+  // Parse ')'.
+  if (this->StateGood)
+  {
+    pos = end - color.c_str();
+    pos = color.find_first_not_of(" \t", pos);
+    this->StateGood = (pos != vtkStdString::npos && color[pos] == ')');
+  }
+
+  // Left characters must be only trailing spaces or the string is not valid.
+  if (this->StateGood)
+  {
+    pos = color.find_first_not_of(" \t", pos + 1);
+    this->StateGood = (pos == vtkStdString::npos);
+  }
+}
+
+
 //-----------------------------------------------------------------------------
 vtkStandardNewMacro(vtkNamedColors);
 
@@ -709,11 +964,13 @@ vtkStandardNewMacro(vtkNamedColors);
 vtkNamedColors::vtkNamedColors()
 {
   this->Colors = new vtkNamedColorsDataStore;
+  this->Parser = new vtkColorStringParser(this);
 }
 
 //----------------------------------------------------------------------------
 vtkNamedColors::~vtkNamedColors()
 {
+  delete this->Parser;
   delete this->Colors;
 }
 
@@ -725,19 +982,19 @@ void vtkNamedColors::PrintSelf(ostream &os, vtkIndent indent)
   for ( std::map<vtkStdString, vtkColor4ub >::const_iterator p =
     this->Colors->GetColorMap()->begin();
     p != this->Colors->GetColorMap()->end(); ++p )
-    {
+  {
     os << indent << ": " << p->first << "(";
     if (p->second.GetSize() == 4)
-      {
+    {
       int r = p->second.GetRed();
       int g = p->second.GetGreen();
       int b = p->second.GetBlue();
       int a = p->second.GetAlpha();
       os << setw(3) << r << "," << setw(3) << g
         << ","<< setw(3) << b <<"," << setw(3) << a;
-      }
-      os << ")" << endl;
     }
+      os << ")" << endl;
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -751,13 +1008,13 @@ vtkStdString vtkNamedColors::GetColorNames()
   // Now just iterate through the map getting the color names.
   for(std::vector<vtkStdString>::const_iterator p =
     cnv.begin(); p != cnv.end(); ++p )
-    {
+  {
     colorNames += *p;
     if (p != lastItr)
-      {
+    {
       colorNames += "\n";
-      }
     }
+  }
   return colorNames;
 }
 
@@ -768,9 +1025,9 @@ void vtkNamedColors::GetColorNames(vtkStringArray * colorNames)
   // Now just iterate through the map getting the color names.
   for(std::vector<vtkStdString>::const_iterator p =
     cnv.begin(); p != cnv.end(); ++p )
-    {
+  {
     colorNames->InsertNextValue(*p);
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -782,25 +1039,25 @@ vtkStdString vtkNamedColors::GetSynonyms()
   --synLast;
   for(std::vector<std::vector<vtkStdString> >::const_iterator p =
     syn.begin(); p != syn.end(); ++p)
-    {
+  {
     // Get the last element in the vector.
     std::vector<vtkStdString>::const_iterator strLast =
       p->end();
     --strLast;
     for(std::vector<vtkStdString>::const_iterator q =
       p->begin(); q!= p->end(); ++q)
-      {
+    {
       synonyms += *q;
       if(q != strLast)
-        {
-        synonyms += "\n";
-        }
-      }
-    if (p != synLast)
       {
-      synonyms += "\n\n";
+        synonyms += "\n";
       }
     }
+    if (p != synLast)
+    {
+      synonyms += "\n\n";
+    }
+  }
   return synonyms;
 }
 
@@ -850,9 +1107,9 @@ void vtkNamedColors::GetColor(const vtkStdString & name, unsigned char rgba[4])
   vtkColor4ub color;
   this->Colors->GetColor(name,color);
   for(int i = 0; i < color.GetSize(); ++i)
-    {
+  {
     rgba[i] = color[i];
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -887,9 +1144,9 @@ void vtkNamedColors::GetColor(const vtkStdString & name, double rgba[4])
   vtkColor4d color;
   this->Colors->GetColor(name,color);
   for(int i = 0; i < color.GetSize(); ++i)
-    {
+  {
     rgba[i] = color[i];
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -931,9 +1188,9 @@ void vtkNamedColors::GetColorRGB(const vtkStdString & name, double rgb[3])
   vtkColor3d color;
   this->Colors->GetColor(name,color);
   for(int i = 0; i < color.GetSize(); ++i)
-    {
+  {
     rgb[i] = color[i];
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -967,9 +1224,9 @@ void vtkNamedColors::SetColor(const vtkStdString & name,
 {
   vtkColor4ub v;
   for ( int i = 0; i < v.GetSize(); ++i )
-    {
+  {
     v[i] = rgba[i];
-    }
+  }
   this->Colors->SetColor(name,v);
 }
 
@@ -1005,9 +1262,9 @@ void vtkNamedColors::SetColor(const vtkStdString & name, const double rgba[4])
 {
   vtkColor4d v;
   for ( int i = 0; i < v.GetSize(); ++i )
-    {
+  {
     v[i] = rgba[i];
-    }
+  }
   this->Colors->SetColor(name,v);
 }
 
@@ -1017,9 +1274,9 @@ void vtkNamedColors::SetColor(const vtkStdString & name,
 {
   vtkColor4d v;
   for ( int i = 0; i < v.GetSize(); ++i )
-    {
+  {
     v[i] = rgba[i];
-    }
+  }
   this->Colors->SetColor(name,v);
 }
 
@@ -1034,7 +1291,62 @@ void vtkNamedColors::SetColor(const vtkStdString & name,
 void vtkNamedColors::RemoveColor(const vtkStdString & name)
 {
   if (!name.empty())
-    {
+  {
     this->Colors->RemoveColor(name);
+  }
+}
+
+//-----------------------------------------------------------------------------
+vtkColor4ub vtkNamedColors::HTMLColorToRGBA(const vtkStdString & colorString)
+{
+  this->Parser->Parse(colorString);
+  return this->Parser->GetColor();
+}
+
+//-----------------------------------------------------------------------------
+vtkColor3ub vtkNamedColors::HTMLColorToRGB(const vtkStdString & colorString)
+{
+  vtkColor4ub color4ub = this->HTMLColorToRGBA(colorString);
+  vtkColor3ub color3ub;
+  color3ub[0] = color4ub[0];
+  color3ub[1] = color4ub[1];
+  color3ub[2] = color4ub[2];
+  return color3ub;
+}
+
+//-----------------------------------------------------------------------------
+void vtkNamedColors::SetColor(const vtkStdString & name,
+                              const vtkStdString & htmlString)
+{
+  if (!name.empty())
+  {
+    vtkColor4ub noColor(0, 0, 0, 0);
+    vtkColor4ub color = this->HTMLColorToRGBA(htmlString);
+    if (color != noColor)
+    {
+      this->SetColor(name, color);
     }
+  }
+}
+
+//-----------------------------------------------------------------------------
+vtkStdString vtkNamedColors::RGBToHTMLColor(const vtkColor3ub & rgb)
+{
+  std::stringstream ss;
+  ss << "#" << std::hex << std::setfill('0')
+      << std::setw(2) << (int)(rgb.GetRed())
+      << std::setw(2) << (int)(rgb.GetGreen())
+      << std::setw(2) << (int)(rgb.GetBlue());
+
+  return ss.str();
+}
+
+//-----------------------------------------------------------------------------
+vtkStdString vtkNamedColors::RGBAToHTMLColor(const vtkColor4ub & rgba)
+{
+  std::stringstream ss;
+  ss.precision(3);
+  ss << "rgba(" << (int)(rgba.GetRed()) << "," << (int)(rgba.GetGreen()) <<
+        "," << (int)(rgba.GetBlue()) << "," << (rgba.GetAlpha() / 255.0) << ")";
+  return ss.str();
 }
