@@ -41,7 +41,6 @@ vtkInformationKeyMacro(vtkDataObject, DATA_EXTENT_TYPE, Integer);
 vtkInformationKeyMacro(vtkDataObject, DATA_PIECE_NUMBER, Integer);
 vtkInformationKeyMacro(vtkDataObject, DATA_NUMBER_OF_PIECES, Integer);
 vtkInformationKeyMacro(vtkDataObject, DATA_NUMBER_OF_GHOST_LEVELS, Integer);
-vtkInformationKeyMacro(vtkDataObject, DATA_RESOLUTION, Double);
 vtkInformationKeyMacro(vtkDataObject, DATA_TIME_STEP, Double);
 vtkInformationKeyMacro(vtkDataObject, POINT_DATA_VECTOR, InformationVector);
 vtkInformationKeyMacro(vtkDataObject, CELL_DATA_VECTOR, InformationVector);
@@ -55,14 +54,12 @@ vtkInformationKeyMacro(vtkDataObject, FIELD_NAME, String);
 vtkInformationKeyMacro(vtkDataObject, FIELD_NUMBER_OF_COMPONENTS, Integer);
 vtkInformationKeyMacro(vtkDataObject, FIELD_NUMBER_OF_TUPLES, Integer);
 vtkInformationKeyRestrictedMacro(vtkDataObject, FIELD_RANGE, DoubleVector, 2);
-vtkInformationKeyRestrictedMacro(vtkDataObject, PIECE_FIELD_RANGE, DoubleVector, 2);
-vtkInformationKeyMacro(vtkDataObject, FIELD_ARRAY_NAME, String);
 vtkInformationKeyRestrictedMacro(vtkDataObject, PIECE_EXTENT, IntegerVector, 6);
 vtkInformationKeyMacro(vtkDataObject, FIELD_OPERATION, Integer);
+vtkInformationKeyRestrictedMacro(vtkDataObject, ALL_PIECES_EXTENT, IntegerVector, 6);
 vtkInformationKeyRestrictedMacro(vtkDataObject, DATA_EXTENT, IntegerPointer, 6);
 vtkInformationKeyRestrictedMacro(vtkDataObject, ORIGIN, DoubleVector, 3);
 vtkInformationKeyRestrictedMacro(vtkDataObject, SPACING, DoubleVector, 3);
-vtkInformationKeyMacro(vtkDataObject, DATA_GEOMETRY_UNMODIFIED, Integer);
 vtkInformationKeyMacro(vtkDataObject, SIL, DataObject);
 vtkInformationKeyRestrictedMacro(vtkDataObject, BOUNDING_BOX, DoubleVector, 6);
 
@@ -120,13 +117,13 @@ void vtkDataObject::PrintSelf(ostream& os, vtkIndent indent)
   this->Superclass::PrintSelf(os,indent);
 
   if ( this->Information )
-    {
+  {
     os << indent << "Information: " << this->Information << "\n";
-    }
+  }
   else
-    {
+  {
     os << indent << "Information: (none)\n";
-    }
+  }
 
   os << indent << "Data Released: "
      << (this->DataReleased ? "True\n" : "False\n");
@@ -141,16 +138,16 @@ void vtkDataObject::PrintSelf(ostream& os, vtkIndent indent)
 
 //----------------------------------------------------------------------------
 // Determine the modified time of this object
-unsigned long int vtkDataObject::GetMTime()
+vtkMTimeType vtkDataObject::GetMTime()
 {
-  unsigned long result;
+  vtkMTimeType result;
 
   result = vtkObject::GetMTime();
   if ( this->FieldData )
-    {
-    unsigned long mtime = this->FieldData->GetMTime();
+  {
+    vtkMTimeType mtime = this->FieldData->GetMTime();
     result = ( mtime > result ? mtime : result);
-    }
+  }
 
   return result;
 }
@@ -159,19 +156,19 @@ unsigned long int vtkDataObject::GetMTime()
 void vtkDataObject::Initialize()
 {
   if (this->FieldData)
-    {
+  {
     this->FieldData->Initialize();
-    }
+  }
 
   if (this->Information)
-    {
+  {
     // Make sure the information is cleared.
+    this->Information->Remove(ALL_PIECES_EXTENT());
     this->Information->Remove(DATA_PIECE_NUMBER());
     this->Information->Remove(DATA_NUMBER_OF_PIECES());
     this->Information->Remove(DATA_NUMBER_OF_GHOST_LEVELS());
     this->Information->Remove(DATA_TIME_STEP());
-    this->Information->Remove(DATA_RESOLUTION());
-    }
+  }
 
   this->Modified();
 }
@@ -180,9 +177,9 @@ void vtkDataObject::Initialize()
 void vtkDataObject::SetGlobalReleaseDataFlag(int val)
 {
   if (val == vtkDataObjectGlobalReleaseDataFlag)
-    {
+  {
     return;
-    }
+  }
   vtkDataObjectGlobalReleaseDataFlag = val;
 }
 
@@ -195,41 +192,41 @@ vtkInformation *vtkDataObject::GetActiveFieldInformation(vtkInformation *info,
   vtkInformationVector *fieldDataInfoVector;
 
   if (fieldAssociation == FIELD_ASSOCIATION_POINTS)
-    {
+  {
     fieldDataInfoVector = info->Get(POINT_DATA_VECTOR());
-    }
+  }
   else if (fieldAssociation == FIELD_ASSOCIATION_CELLS)
-    {
+  {
     fieldDataInfoVector = info->Get(CELL_DATA_VECTOR());
-    }
+  }
   else if (fieldAssociation == FIELD_ASSOCIATION_VERTICES)
-    {
+  {
     fieldDataInfoVector = info->Get(VERTEX_DATA_VECTOR());
-    }
+  }
   else if (fieldAssociation == FIELD_ASSOCIATION_EDGES)
-    {
+  {
     fieldDataInfoVector = info->Get(EDGE_DATA_VECTOR());
-    }
+  }
   else
-    {
+  {
     vtkGenericWarningMacro("Unrecognized field association!");
     return NULL;
-    }
+  }
 
   if (!fieldDataInfoVector)
-    {
+  {
     return NULL;
-    }
+  }
 
   for (i = 0; i < fieldDataInfoVector->GetNumberOfInformationObjects(); i++)
-    {
+  {
     fieldDataInfo = fieldDataInfoVector->GetInformationObject(i);
     if ( fieldDataInfo->Has(FIELD_ACTIVE_ATTRIBUTE()) &&
       (fieldDataInfo->Get(FIELD_ACTIVE_ATTRIBUTE()) & (1 << attributeType )) )
-      {
+    {
       return fieldDataInfo;
-      }
     }
+  }
   return NULL;
 }
 
@@ -243,41 +240,41 @@ vtkInformation *vtkDataObject::GetNamedFieldInformation(vtkInformation *info,
   vtkInformationVector *fieldDataInfoVector;
 
   if (fieldAssociation == FIELD_ASSOCIATION_POINTS)
-    {
+  {
     fieldDataInfoVector = info->Get(POINT_DATA_VECTOR());
-    }
+  }
   else if (fieldAssociation == FIELD_ASSOCIATION_CELLS)
-    {
+  {
     fieldDataInfoVector = info->Get(CELL_DATA_VECTOR());
-    }
+  }
   else if (fieldAssociation == FIELD_ASSOCIATION_VERTICES)
-    {
+  {
     fieldDataInfoVector = info->Get(VERTEX_DATA_VECTOR());
-    }
+  }
   else if (fieldAssociation == FIELD_ASSOCIATION_EDGES)
-    {
+  {
     fieldDataInfoVector = info->Get(EDGE_DATA_VECTOR());
-    }
+  }
   else
-    {
+  {
     vtkGenericWarningMacro("Unrecognized field association!");
     return NULL;
-    }
+  }
 
   if (!fieldDataInfoVector)
-    {
+  {
     return NULL;
-    }
+  }
 
   for (i = 0; i < fieldDataInfoVector->GetNumberOfInformationObjects(); i++)
-    {
+  {
     fieldDataInfo = fieldDataInfoVector->GetInformationObject(i);
     if ( fieldDataInfo->Has(FIELD_NAME()) &&
          !strcmp(fieldDataInfo->Get(FIELD_NAME()),name))
-      {
+    {
       return fieldDataInfo;
-      }
     }
+  }
   return NULL;
 }
 
@@ -291,42 +288,42 @@ void vtkDataObject::RemoveNamedFieldInformation(vtkInformation *info,
   vtkInformationVector *fieldDataInfoVector;
 
   if (fieldAssociation == FIELD_ASSOCIATION_POINTS)
-    {
+  {
     fieldDataInfoVector = info->Get(POINT_DATA_VECTOR());
-    }
+  }
   else if (fieldAssociation == FIELD_ASSOCIATION_CELLS)
-    {
+  {
     fieldDataInfoVector = info->Get(CELL_DATA_VECTOR());
-    }
+  }
   else if (fieldAssociation == FIELD_ASSOCIATION_VERTICES)
-    {
+  {
     fieldDataInfoVector = info->Get(VERTEX_DATA_VECTOR());
-    }
+  }
   else if (fieldAssociation == FIELD_ASSOCIATION_EDGES)
-    {
+  {
     fieldDataInfoVector = info->Get(EDGE_DATA_VECTOR());
-    }
+  }
   else
-    {
+  {
     vtkGenericWarningMacro("Unrecognized field association!");
     return;
-    }
+  }
 
   if (!fieldDataInfoVector)
-    {
+  {
     return;
-    }
+  }
 
   for (i = 0; i < fieldDataInfoVector->GetNumberOfInformationObjects(); i++)
-    {
+  {
     fieldDataInfo = fieldDataInfoVector->GetInformationObject(i);
     if ( fieldDataInfo->Has(FIELD_NAME()) &&
          !strcmp(fieldDataInfo->Get(FIELD_NAME()),name))
-      {
+    {
       fieldDataInfoVector->Remove(fieldDataInfo);
       return;
-      }
     }
+  }
   return;
 }
 
@@ -341,47 +338,47 @@ vtkInformation *vtkDataObject::SetActiveAttribute(vtkInformation *info,
   vtkInformationVector *fieldDataInfoVector;
 
   if (fieldAssociation == FIELD_ASSOCIATION_POINTS)
-    {
+  {
     fieldDataInfoVector = info->Get(POINT_DATA_VECTOR());
-    }
+  }
   else if (fieldAssociation == FIELD_ASSOCIATION_CELLS)
-    {
+  {
     fieldDataInfoVector = info->Get(CELL_DATA_VECTOR());
-    }
+  }
   else if (fieldAssociation == FIELD_ASSOCIATION_VERTICES)
-    {
+  {
     fieldDataInfoVector = info->Get(VERTEX_DATA_VECTOR());
-    }
+  }
   else if (fieldAssociation == FIELD_ASSOCIATION_EDGES)
-    {
+  {
     fieldDataInfoVector = info->Get(EDGE_DATA_VECTOR());
-    }
+  }
   else
-    {
+  {
     vtkGenericWarningMacro("Unrecognized field association!");
     return NULL;
-    }
+  }
   if (!fieldDataInfoVector)
-    {
+  {
     fieldDataInfoVector = vtkInformationVector::New();
     if (fieldAssociation == FIELD_ASSOCIATION_POINTS)
-      {
+    {
       info->Set(POINT_DATA_VECTOR(), fieldDataInfoVector);
-      }
-    else if (fieldAssociation == FIELD_ASSOCIATION_CELLS)
-      {
-      info->Set(CELL_DATA_VECTOR(), fieldDataInfoVector);
-      }
-    else if (fieldAssociation == FIELD_ASSOCIATION_VERTICES)
-      {
-      info->Set(VERTEX_DATA_VECTOR(), fieldDataInfoVector);
-      }
-    else // if (fieldAssociation == FIELD_ASSOCIATION_EDGES)
-      {
-      info->Set(EDGE_DATA_VECTOR(), fieldDataInfoVector);
-      }
-    fieldDataInfoVector->FastDelete();
     }
+    else if (fieldAssociation == FIELD_ASSOCIATION_CELLS)
+    {
+      info->Set(CELL_DATA_VECTOR(), fieldDataInfoVector);
+    }
+    else if (fieldAssociation == FIELD_ASSOCIATION_VERTICES)
+    {
+      info->Set(VERTEX_DATA_VECTOR(), fieldDataInfoVector);
+    }
+    else // if (fieldAssociation == FIELD_ASSOCIATION_EDGES)
+    {
+      info->Set(EDGE_DATA_VECTOR(), fieldDataInfoVector);
+    }
+    fieldDataInfoVector->FastDelete();
+  }
 
   // if we find a matching field, turn it on (active);  if another field of same
   // attribute type was active, turn it off (not active)
@@ -389,38 +386,38 @@ vtkInformation *vtkDataObject::SetActiveAttribute(vtkInformation *info,
   int activeAttribute;
   const char *fieldName;
   for (i = 0; i < fieldDataInfoVector->GetNumberOfInformationObjects(); i++)
-    {
+  {
     fieldDataInfo = fieldDataInfoVector->GetInformationObject(i);
     activeAttribute = fieldDataInfo->Get( FIELD_ACTIVE_ATTRIBUTE() );
     fieldName = fieldDataInfo->Get(FIELD_NAME());
     // if names match (or both empty... no field name), then set active
     if ( (attributeName && fieldName && !strcmp(attributeName, fieldName)) ||
       (!attributeName && !fieldName) )
-      {
+    {
       activeAttribute |= 1 << attributeType;
       fieldDataInfo->Set( FIELD_ACTIVE_ATTRIBUTE(), activeAttribute );
       activeField = fieldDataInfo;
-      }
+    }
     else if ( activeAttribute & (1 << attributeType) )
-      {
+    {
       activeAttribute &= ~(1 << attributeType);
       fieldDataInfo->Set( FIELD_ACTIVE_ATTRIBUTE(), activeAttribute );
-      }
     }
+  }
 
   // if we didn't find a matching field, create one
   if (!activeField)
-    {
+  {
     activeField = vtkInformation::New();
     activeField->Set( FIELD_ACTIVE_ATTRIBUTE(), 1 << attributeType);
     activeField->Set(FIELD_ASSOCIATION(), fieldAssociation);
     if (attributeName)
-      {
+    {
       activeField->Set( FIELD_NAME(), attributeName );
-      }
+    }
     fieldDataInfoVector->Append(activeField);
     activeField->FastDelete();
-    }
+  }
 
   return activeField;
 }
@@ -437,52 +434,52 @@ void vtkDataObject::SetActiveAttributeInfo(vtkInformation *info,
   vtkInformation *attrInfo = vtkDataObject::GetActiveFieldInformation(info,
     fieldAssociation, attributeType);
   if (!attrInfo)
-    {
+  {
     // create an entry and set it as active
     attrInfo = SetActiveAttribute(info, fieldAssociation, name, attributeType);
-    }
+  }
 
   if (name)
-    {
+  {
     attrInfo->Set(FIELD_NAME(), name);
-    }
+  }
 
   // Set the scalar type if it was given.  If it was not given and
   // there is no current scalar type set the default to VTK_DOUBLE.
   if (arrayType != -1)
-    {
+  {
     attrInfo->Set(FIELD_ARRAY_TYPE(), arrayType);
-    }
+  }
   else if(!attrInfo->Has(FIELD_ARRAY_TYPE()))
-    {
+  {
     attrInfo->Set(FIELD_ARRAY_TYPE(), VTK_DOUBLE);
-    }
+  }
 
   // Set the number of components if it was given.  If it was not
   // given and there is no current number of components set the
   // default to 1.
   if (numComponents != -1)
-    {
+  {
     attrInfo->Set(FIELD_NUMBER_OF_COMPONENTS(), numComponents);
-    }
+  }
   else if(!attrInfo->Has(FIELD_NUMBER_OF_COMPONENTS()))
-    {
+  {
     attrInfo->Set(FIELD_NUMBER_OF_COMPONENTS(), 1);
-    }
+  }
 
   if (numTuples != -1)
-    {
+  {
     attrInfo->Set(FIELD_NUMBER_OF_TUPLES(), numTuples);
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
 void vtkDataObject::SetPointDataActiveScalarInfo(vtkInformation *info,
                                         int arrayType, int numComponents)
-  {
+{
   vtkDataObject::SetActiveAttributeInfo(info, FIELD_ASSOCIATION_POINTS,
     vtkDataSetAttributes::SCALARS, NULL, arrayType, numComponents, -1);
-  }
+}
 
 //----------------------------------------------------------------------------
 void vtkDataObject::DataHasBeenGenerated()
@@ -505,7 +502,7 @@ void vtkDataObject::ReleaseData()
 }
 
 //----------------------------------------------------------------------------
-unsigned long vtkDataObject::GetUpdateTime()
+vtkMTimeType vtkDataObject::GetUpdateTime()
 {
   return this->UpdateTime.GetMTime();
 }
@@ -521,31 +518,31 @@ unsigned long vtkDataObject::GetActualMemorySize()
 void vtkDataObject::ShallowCopy(vtkDataObject *src)
 {
   if (!src)
-    {
+  {
     vtkWarningMacro("Attempted to ShallowCopy from null.");
     return;
-    }
+  }
 
   this->InternalDataObjectCopy(src);
 
   if (!src->FieldData)
-    {
+  {
     this->SetFieldData(0);
-    }
+  }
   else
-    {
+  {
     if (this->FieldData)
-      {
+    {
       this->FieldData->ShallowCopy(src->FieldData);
-      }
+    }
     else
-      {
+    {
       vtkFieldData* fd = vtkFieldData::New();
       fd->ShallowCopy(src->FieldData);
       this->SetFieldData(fd);
       fd->FastDelete();
-      }
     }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -556,16 +553,16 @@ void vtkDataObject::DeepCopy(vtkDataObject *src)
   this->InternalDataObjectCopy(src);
 
   if (srcFieldData)
-    {
+  {
     vtkFieldData *newFieldData = vtkFieldData::New();
     newFieldData->DeepCopy(srcFieldData);
     this->SetFieldData(newFieldData);
     newFieldData->FastDelete();
-    }
+  }
   else
-    {
+  {
     this->SetFieldData(NULL);
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -596,13 +593,9 @@ void vtkDataObject::InternalDataObjectCopy(vtkDataObject *src)
     }
   */
   if(src->Information->Has(DATA_TIME_STEP()))
-    {
+  {
     this->Information->CopyEntry(src->Information, DATA_TIME_STEP(), 1);
-    }
-  if(src->Information->Has(DATA_RESOLUTION()))
-    {
-    this->Information->CopyEntry(src->Information, DATA_RESOLUTION(), 1);
-    }
+  }
 
   // This also caused a pipeline problem.
   // An input pipelineMTime was copied to output.  Pipeline did not execute...
@@ -634,10 +627,10 @@ vtkDataObject* vtkDataObject::GetData(vtkInformationVector* v, int i)
 const char* vtkDataObject::GetAssociationTypeAsString(int associationType)
 {
   if (associationType < 0 || associationType >= NUMBER_OF_ASSOCIATIONS)
-    {
+  {
     vtkGenericWarningMacro("Bad association type.");
     return NULL;
-    }
+  }
   return FieldAssociationsNames[associationType];
 }
 
@@ -645,28 +638,28 @@ const char* vtkDataObject::GetAssociationTypeAsString(int associationType)
 int vtkDataObject::GetAssociationTypeFromString(const char* associationName)
 {
   if (!associationName)
-    {
+  {
     vtkGenericWarningMacro("NULL association name.");
     return -1;
-    }
+  }
 
   // check for the name in the FieldAssociations enum
   for(int i = 0; i < NUMBER_OF_ASSOCIATIONS; i++)
-    {
+  {
     if(!strcmp(associationName, FieldAssociationsNames[i]))
-      {
+    {
       return i;
-      }
     }
+  }
 
   // check for the name in the AttributeTypes enum
   for(int i = 0; i < NUMBER_OF_ATTRIBUTE_TYPES; i++)
-    {
+  {
     if(!strcmp(associationName, AttributeTypesNames[i]))
-      {
+    {
       return i;
-      }
     }
+  }
 
   vtkGenericWarningMacro("Bad association name \"" << associationName << "\".");
   return -1;
@@ -682,11 +675,10 @@ vtkDataSetAttributes* vtkDataObject::GetAttributes(int type)
 vtkFieldData* vtkDataObject::GetAttributesAsFieldData(int type)
 {
   switch (type)
-    {
+  {
     case FIELD:
       return this->FieldData;
-      break;
-    }
+  }
   return 0;
 }
 
@@ -694,19 +686,19 @@ vtkFieldData* vtkDataObject::GetAttributesAsFieldData(int type)
 int vtkDataObject::GetAttributeTypeForArray(vtkAbstractArray* arr)
 {
   for (int i = 0; i < NUMBER_OF_ATTRIBUTE_TYPES; ++i)
-    {
+  {
     vtkFieldData* data = this->GetAttributesAsFieldData(i);
     if (data)
-      {
+    {
       for (int j = 0; j < data->GetNumberOfArrays(); ++j)
-        {
+      {
         if (data->GetAbstractArray(j) == arr)
-          {
+        {
           return i;
-          }
         }
       }
     }
+  }
   return -1;
 }
 
@@ -714,10 +706,9 @@ int vtkDataObject::GetAttributeTypeForArray(vtkAbstractArray* arr)
 vtkIdType vtkDataObject::GetNumberOfElements(int type)
 {
   switch (type)
-    {
+  {
     case FIELD:
       return this->FieldData->GetNumberOfTuples();
-      break;
-    }
+  }
   return 0;
 }
