@@ -46,12 +46,12 @@ vtkDataObjectToDataSetFilter::vtkDataObjectToDataSetFilter()
   output->Delete();
 
   for (i=0; i < 3; i++)
-    {
+  {
     this->PointArrays[i] = NULL;
     this->PointArrayComponents[i] = -1; //uninitialized
     this->PointComponentRange[i][0] = this->PointComponentRange[i][1] = -1;
     this->PointNormalize[i] = 1; //yes, normalize
-    }
+  }
 
   this->VertsArray = NULL;
   this->VertsArrayComponent = -1;
@@ -100,63 +100,31 @@ vtkDataObjectToDataSetFilter::vtkDataObjectToDataSetFilter()
 //----------------------------------------------------------------------------
 vtkDataObjectToDataSetFilter::~vtkDataObjectToDataSetFilter()
 {
-  int i;
-
-  for (i=0; i<3; i++)
-    {
-    if ( this->PointArrays[i] != NULL )
-      {
-      delete [] this->PointArrays[i];
-      }
-    }
-  if ( this->VertsArray != NULL )
-    {
-    delete [] this->VertsArray;
-    }
-  if ( this->LinesArray != NULL )
-    {
-    delete [] this->LinesArray;
-    }
-  if ( this->PolysArray != NULL )
-    {
-    delete [] this->PolysArray;
-    }
-  if ( this->StripsArray != NULL )
-    {
-    delete [] this->StripsArray;
-    }
-  if ( this->CellTypeArray != NULL )
-    {
-    delete [] this->CellTypeArray;
-    }
-  if ( this->CellConnectivityArray != NULL )
-    {
-    delete [] this->CellConnectivityArray;
-    }
-  if ( this->DimensionsArray != NULL )
-    {
-    delete [] this->DimensionsArray;
-    }
-  if ( this->SpacingArray != NULL )
-    {
-    delete [] this->SpacingArray;
-    }
-  if ( this->OriginArray != NULL )
-    {
-    delete [] this->OriginArray;
-    }
+  for (int i=0; i<3; i++)
+  {
+    delete [] this->PointArrays[i];
+  }
+  delete [] this->VertsArray;
+  delete [] this->LinesArray;
+  delete [] this->PolysArray;
+  delete [] this->StripsArray;
+  delete [] this->CellTypeArray;
+  delete [] this->CellConnectivityArray;
+  delete [] this->DimensionsArray;
+  delete [] this->SpacingArray;
+  delete [] this->OriginArray;
 }
 
 void vtkDataObjectToDataSetFilter::SetDataSetType(int dt)
 {
   if (dt == this->DataSetType)
-    {
+  {
     return;
-    }
+  }
 
   vtkDataSet *output;
   switch (dt)
-    {
+  {
     case VTK_POLY_DATA:
       output = vtkPolyData::New();
       this->GetExecutive()->SetOutputData(0,output);
@@ -184,7 +152,7 @@ void vtkDataObjectToDataSetFilter::SetDataSetType(int dt)
       break;
     default:
       vtkWarningMacro("unknown type in SetDataSetType");
-    }
+  }
   this->DataSetType = dt;
   this->Modified();
 }
@@ -193,9 +161,9 @@ void vtkDataObjectToDataSetFilter::SetDataSetType(int dt)
 vtkDataObject *vtkDataObjectToDataSetFilter::GetInput()
 {
   if (this->GetNumberOfInputConnections(0) < 1)
-    {
+  {
     return NULL;
-    }
+  }
 
   return this->GetExecutive()->GetInputData(0, 0);
 }
@@ -215,7 +183,7 @@ int vtkDataObjectToDataSetFilter::RequestInformation(
     vtkExecutive::PRODUCER()->GetExecutive(inInfo);
 
   switch (this->DataSetType)
-    {
+  {
     case VTK_POLY_DATA:
       break;
 
@@ -256,7 +224,7 @@ int vtkDataObjectToDataSetFilter::RequestInformation(
 
     default:
       vtkErrorMacro(<<"Unsupported dataset type!");
-    }
+  }
 
   return 1;
 }
@@ -281,17 +249,17 @@ int vtkDataObjectToDataSetFilter::RequestData(
   vtkDebugMacro(<<"Generating dataset from field data");
 
   switch (this->DataSetType)
-    {
+  {
     case VTK_POLY_DATA:
       if ( (npts=this->ConstructPoints(input,
                                        vtkPolyData::SafeDownCast(output))) )
-        {
+      {
         this->ConstructCells(input, vtkPolyData::SafeDownCast(output));
-        }
+      }
       else
-        {
+      {
         vtkErrorMacro(<<"Couldn't create any points");
-        }
+      }
       break;
 
     case VTK_STRUCTURED_POINTS:
@@ -309,54 +277,54 @@ int vtkDataObjectToDataSetFilter::RequestData(
     case VTK_STRUCTURED_GRID:
       if ( (npts=this->ConstructPoints(input,
                                        this->GetStructuredGridOutput())) )
-        {
+      {
         this->ConstructDimensions(input);
         if ( npts == (this->Dimensions[0] * this->Dimensions[1] *
                       this->Dimensions[2]) )
-          {
+        {
           vtkStructuredGrid *sg = vtkStructuredGrid::SafeDownCast(output);
           sg->SetDimensions(this->Dimensions);
-          }
-        else
-          {
-          vtkErrorMacro(<<"Number of points don't match dimensions");
-          }
         }
+        else
+        {
+          vtkErrorMacro(<<"Number of points don't match dimensions");
+        }
+      }
       break;
 
     case VTK_RECTILINEAR_GRID:
       if ( (npts=this->ConstructPoints(input,
                                        this->GetRectilinearGridOutput())) )
-        {
+      {
         this->ConstructDimensions(input);
         if ( npts == (this->Dimensions[0] * this->Dimensions[1] *
                       this->Dimensions[2]) )
-          {
+        {
           vtkRectilinearGrid *rg = vtkRectilinearGrid::SafeDownCast(output);
           rg->SetDimensions(this->Dimensions);
-          }
-        else
-          {
-          vtkErrorMacro(<<"Number of points don't match dimensions");
-          }
         }
+        else
+        {
+          vtkErrorMacro(<<"Number of points don't match dimensions");
+        }
+      }
       break;
 
     case VTK_UNSTRUCTURED_GRID:
       if ( this->ConstructPoints(input,
                                  vtkUnstructuredGrid::SafeDownCast(output)) )
-        {
+      {
         this->ConstructCells(input, vtkUnstructuredGrid::SafeDownCast(output));
-        }
+      }
       else
-        {
+      {
         vtkErrorMacro(<<"Couldn't create any points");
-        }
+      }
       break;
 
     default:
       vtkErrorMacro(<<"Unsupported dataset type!");
-    }
+  }
 
   vtkFieldData *inFD = input->GetFieldData();
   vtkFieldData *outFD = output->GetFieldData();
@@ -376,9 +344,9 @@ vtkPolyData *vtkDataObjectToDataSetFilter::GetPolyDataOutput()
 vtkDataSet *vtkDataObjectToDataSetFilter::GetOutput()
 {
   if (this->GetNumberOfOutputPorts() < 1)
-    {
+  {
     return NULL;
-    }
+  }
 
   return vtkDataSet::SafeDownCast(
     this->GetExecutive()->GetOutputData(0));
@@ -432,25 +400,25 @@ void vtkDataObjectToDataSetFilter::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "Data Set Type: ";
   if ( this->DataSetType == VTK_POLY_DATA )
-    {
+  {
     os << "vtkPolyData\n";
-    }
+  }
   else if ( this->DataSetType == VTK_STRUCTURED_POINTS )
-    {
+  {
     os << "vtkStructuredPoints\n";
-    }
+  }
   else if ( this->DataSetType == VTK_STRUCTURED_GRID )
-    {
+  {
     os << "vtkStructuredGrid\n";
-    }
+  }
   else if ( this->DataSetType == VTK_RECTILINEAR_GRID )
-    {
+  {
     os << "vtkRectilinearGrid\n";
-    }
+  }
   else // if ( this->DataSetType == VTK_UNSTRUCTURED_GRID )
-    {
+  {
     os << "vtkUnstructuredGrid\n";
-    }
+  }
 
   os << indent << "Dimensions: (" << this->Dimensions[0] << ", "
                                   << this->Dimensions[1] << ", "
@@ -478,33 +446,33 @@ void vtkDataObjectToDataSetFilter::SetPointComponent(int comp,
                                                      int normalize)
 {
   if ( comp < 0 || comp > 2 )
-    {
+  {
     vtkErrorMacro(<<"Point component must be between (0,2)");
     return;
-    }
+  }
 
   vtkFieldDataToAttributeDataFilter::SetArrayName(
     this, this->PointArrays[comp], arrayName);
   if ( this->PointArrayComponents[comp] != arrayComp )
-    {
+  {
     this->PointArrayComponents[comp] = arrayComp;
     this->Modified();
-    }
+  }
   if ( this->PointComponentRange[comp][0] != min )
-    {
+  {
     this->PointComponentRange[comp][0] = min;
     this->Modified();
-    }
+  }
   if ( this->PointComponentRange[comp][1] != max )
-    {
+  {
     this->PointComponentRange[comp][1] = max;
     this->Modified();
-    }
+  }
   if ( this->PointNormalize[comp] != normalize )
-    {
+  {
     this->PointNormalize[comp] = normalize;
     this->Modified();
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -552,30 +520,30 @@ vtkIdType vtkDataObjectToDataSetFilter::ConstructPoints(vtkDataObject *input,
   vtkFieldData *fd=input->GetFieldData();
 
   for ( i=0; i < 3; i++ )
-    {
+  {
     fieldArray[i] = vtkFieldDataToAttributeDataFilter::GetFieldArray(
       fd, this->PointArrays[i],
       this->PointArrayComponents[i]);
 
     if ( fieldArray[i] == NULL )
-      {
+    {
       vtkErrorMacro(<<"Can't find array requested");
       return 0;
-      }
+    }
     updated |= vtkFieldDataToAttributeDataFilter::UpdateComponentRange(
       fieldArray[i],
       this->PointComponentRange[i]);
-    }
+  }
 
   npts = this->PointComponentRange[0][1] - this->PointComponentRange[0][0] + 1;
   if ( npts != (this->PointComponentRange[1][1] -
                 this->PointComponentRange[1][0] + 1) ||
        npts != (this->PointComponentRange[2][1] -
                 this->PointComponentRange[2][0] + 1) )
-    {
+  {
     vtkErrorMacro(<<"Number of point components not consistent");
     return 0;
-    }
+  }
 
   // Try using the arrays directly if possible; otherwise copy data
   vtkPoints *newPts = vtkPoints::New();
@@ -584,38 +552,38 @@ vtkIdType vtkDataObjectToDataSetFilter::ConstructPoints(vtkDataObject *input,
        fieldArray[0]->GetNumberOfTuples() == npts &&
        !this->PointNormalize[0] && !this->PointNormalize[1] &&
        !this->PointNormalize[2] )
-    {
+  {
     newPts->SetData(fieldArray[0]);
-    }
+  }
   else //have to copy data into created array
-    {
+  {
     newPts->SetDataType(
       vtkFieldDataToAttributeDataFilter::GetComponentsType(3, fieldArray));
     newPts->SetNumberOfPoints(npts);
 
     for ( i=0; i < 3; i++ )
-      {
+    {
       if ( vtkFieldDataToAttributeDataFilter::ConstructArray(
         newPts->GetData(), i, fieldArray[i], this->PointArrayComponents[i],
         this->PointComponentRange[i][0],
         this->PointComponentRange[i][1],
         this->PointNormalize[i]) == 0 )
-        {
+      {
         newPts->Delete();
         return 0;
-        }
       }
     }
+  }
 
   ps->SetPoints(newPts);
   newPts->Delete();
   if ( updated ) //reset for next execution pass
-    {
+  {
     for (i=0; i < 3; i++)
-      {
+    {
       this->PointComponentRange[i][0] = this->PointComponentRange[i][1] = -1;
-      }
     }
+  }
 
   return npts;
 }
@@ -630,23 +598,23 @@ vtkIdType vtkDataObjectToDataSetFilter::ConstructPoints(vtkDataObject *input,
   vtkFieldData *fd=input->GetFieldData();
 
   for ( i=0; i < 3; i++ )
-    {
+  {
     fieldArray[i] = vtkFieldDataToAttributeDataFilter::GetFieldArray(
       fd, this->PointArrays[i],
       this->PointArrayComponents[i]);
 
     if ( fieldArray[i] == NULL )
-      {
+    {
       vtkErrorMacro(<<"Can't find array requested");
       return 0;
-      }
     }
+  }
 
   for (i=0; i<3; i++)
-    {
+  {
     updated |= vtkFieldDataToAttributeDataFilter::UpdateComponentRange(fieldArray[i],
                                                             this->PointComponentRange[i]);
-    }
+  }
 
   nXpts = this->PointComponentRange[0][1] - this->PointComponentRange[0][0] + 1;
   nYpts = this->PointComponentRange[1][1] - this->PointComponentRange[1][0] + 1;
@@ -663,12 +631,12 @@ vtkIdType vtkDataObjectToDataSetFilter::ConstructPoints(vtkDataObject *input,
   if ( fieldArray[0]->GetNumberOfComponents() == 1 &&
        fieldArray[0]->GetNumberOfTuples() == nXpts &&
        !this->PointNormalize[0] )
-    {
+  {
     XPts = fieldArray[0];
     XPts->Register(this);
-    }
+  }
   else //have to copy data into created array
-    {
+  {
     XPts = vtkDataArray::CreateDataArray(
       vtkFieldDataToAttributeDataFilter::GetComponentsType(1, fieldArray));
     XPts->SetNumberOfComponents(1);
@@ -679,22 +647,22 @@ vtkIdType vtkDataObjectToDataSetFilter::ConstructPoints(vtkDataObject *input,
       this->PointComponentRange[0][0],
       this->PointComponentRange[0][1],
       this->PointNormalize[0]) == 0 )
-      {
+    {
       XPts->Delete();
       return 0;
-      }
     }
+  }
 
   // Look at the y-coordinates
   if ( fieldArray[1]->GetNumberOfComponents() == 1 &&
        fieldArray[1]->GetNumberOfTuples() == nYpts &&
        !this->PointNormalize[1] )
-    {
+  {
     YPts = fieldArray[1];
     YPts->Register(this);
-    }
+  }
   else //have to copy data into created array
-    {
+  {
     YPts = vtkDataArray::CreateDataArray(
       vtkFieldDataToAttributeDataFilter::GetComponentsType(1, fieldArray+1));
     YPts->SetNumberOfComponents(1);
@@ -705,22 +673,22 @@ vtkIdType vtkDataObjectToDataSetFilter::ConstructPoints(vtkDataObject *input,
       this->PointComponentRange[1][0],
       this->PointComponentRange[1][1],
       this->PointNormalize[1]) == 0 )
-      {
+    {
       XPts->Delete(); YPts->Delete();
       return 0;
-      }
     }
+  }
 
   // Look at the z-coordinates
   if ( fieldArray[2]->GetNumberOfComponents() == 1 &&
        fieldArray[2]->GetNumberOfTuples() == nZpts &&
        !this->PointNormalize[2] )
-    {
+  {
     ZPts = fieldArray[2];
     ZPts->Register(this);
-    }
+  }
   else //have to copy data into created array
-    {
+  {
     ZPts = vtkDataArray::CreateDataArray(
       vtkFieldDataToAttributeDataFilter::GetComponentsType(1, fieldArray+2));
     ZPts->SetNumberOfComponents(1);
@@ -731,11 +699,11 @@ vtkIdType vtkDataObjectToDataSetFilter::ConstructPoints(vtkDataObject *input,
       this->PointComponentRange[2][0],
       this->PointComponentRange[2][1],
       this->PointNormalize[2]) == 0 )
-      {
+    {
       XPts->Delete(); YPts->Delete(); ZPts->Delete();
       return 0;
-      }
     }
+  }
 
   rg->SetXCoordinates(XPts);
   rg->SetYCoordinates(YPts);
@@ -743,12 +711,12 @@ vtkIdType vtkDataObjectToDataSetFilter::ConstructPoints(vtkDataObject *input,
   XPts->Delete(); YPts->Delete(); ZPts->Delete();
 
   if ( updated ) //reset for next execution pass
-    {
+  {
     for (i=0; i < 3; i++)
-      {
+    {
       this->PointComponentRange[i][0] = this->PointComponentRange[i][1] = -1;
-      }
     }
+  }
 
   return npts;
 }
@@ -763,20 +731,20 @@ void vtkDataObjectToDataSetFilter::SetVertsComponent(char *arrayName,
   vtkFieldDataToAttributeDataFilter::SetArrayName(
     this, this->VertsArray, arrayName);
   if ( this->VertsArrayComponent != arrayComp )
-    {
+  {
     this->VertsArrayComponent = arrayComp;
     this->Modified();
-    }
+  }
   if ( this->VertsComponentRange[0] != min )
-    {
+  {
     this->VertsComponentRange[0] = min;
     this->Modified();
-    }
+  }
   if ( this->VertsComponentRange[1] != max )
-    {
+  {
     this->VertsComponentRange[1] = max;
     this->Modified();
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -811,20 +779,20 @@ void vtkDataObjectToDataSetFilter::SetLinesComponent(char *arrayName,
   vtkFieldDataToAttributeDataFilter::SetArrayName(
     this, this->LinesArray, arrayName);
   if ( this->LinesArrayComponent != arrayComp )
-    {
+  {
     this->LinesArrayComponent = arrayComp;
     this->Modified();
-    }
+  }
   if ( this->LinesComponentRange[0] != min )
-    {
+  {
     this->LinesComponentRange[0] = min;
     this->Modified();
-    }
+  }
   if ( this->LinesComponentRange[1] != max )
-    {
+  {
     this->LinesComponentRange[1] = max;
     this->Modified();
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -859,20 +827,20 @@ void vtkDataObjectToDataSetFilter::SetPolysComponent(char *arrayName,
   vtkFieldDataToAttributeDataFilter::SetArrayName(
     this, this->PolysArray, arrayName);
   if ( this->PolysArrayComponent != arrayComp )
-    {
+  {
     this->PolysArrayComponent = arrayComp;
     this->Modified();
-    }
+  }
   if ( this->PolysComponentRange[0] != min )
-    {
+  {
     this->PolysComponentRange[0] = min;
     this->Modified();
-    }
+  }
   if ( this->PolysComponentRange[1] != max )
-    {
+  {
     this->PolysComponentRange[1] = max;
     this->Modified();
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -907,20 +875,20 @@ void vtkDataObjectToDataSetFilter::SetStripsComponent(char *arrayName,
   vtkFieldDataToAttributeDataFilter::SetArrayName(
     this, this->StripsArray, arrayName);
   if ( this->StripsArrayComponent != arrayComp )
-    {
+  {
     this->StripsArrayComponent = arrayComp;
     this->Modified();
-    }
+  }
   if ( this->StripsComponentRange[0] != min )
-    {
+  {
     this->StripsComponentRange[0] = min;
     this->Modified();
-    }
+  }
   if ( this->StripsComponentRange[1] != max )
-    {
+  {
     this->StripsComponentRange[1] = max;
     this->Modified();
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -955,20 +923,20 @@ void vtkDataObjectToDataSetFilter::SetCellTypeComponent(char *arrayName, int arr
   vtkFieldDataToAttributeDataFilter::SetArrayName(
     this, this->CellTypeArray, arrayName);
   if ( this->CellTypeArrayComponent != arrayComp )
-    {
+  {
     this->CellTypeArrayComponent = arrayComp;
     this->Modified();
-    }
+  }
   if ( this->CellTypeComponentRange[0] != min )
-    {
+  {
     this->CellTypeComponentRange[0] = min;
     this->Modified();
-    }
+  }
   if ( this->CellTypeComponentRange[1] != max )
-    {
+  {
     this->CellTypeComponentRange[1] = max;
     this->Modified();
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -1002,20 +970,20 @@ void vtkDataObjectToDataSetFilter::SetCellConnectivityComponent(
   vtkFieldDataToAttributeDataFilter::SetArrayName(
     this, this->CellConnectivityArray, arrayName);
   if ( this->CellConnectivityArrayComponent != arrayComp )
-    {
+  {
     this->CellConnectivityArrayComponent = arrayComp;
     this->Modified();
-    }
+  }
   if ( this->CellConnectivityComponentRange[0] != min )
-    {
+  {
     this->CellConnectivityComponentRange[0] = min;
     this->Modified();
-    }
+  }
   if ( this->CellConnectivityComponentRange[1] != max )
-    {
+  {
     this->CellConnectivityComponentRange[1] = max;
     this->Modified();
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -1054,96 +1022,96 @@ int vtkDataObjectToDataSetFilter::ConstructCells(vtkDataObject *input,
   fieldArray[0] = vtkFieldDataToAttributeDataFilter::GetFieldArray(
     fd, this->VertsArray, this->VertsArrayComponent);
   if ( this->VertsArray && fieldArray[0] == NULL )
-    {
+  {
     vtkErrorMacro(<<"Can't find array requested for vertices");
     return 0;
-    }
+  }
 
   fieldArray[1] = vtkFieldDataToAttributeDataFilter::GetFieldArray(
     fd, this->LinesArray, this->LinesArrayComponent);
   if ( this->LinesArray && fieldArray[1] == NULL )
-    {
+  {
     vtkErrorMacro(<<"Can't find array requested for lines");
     return 0;
-    }
+  }
 
   fieldArray[2] = vtkFieldDataToAttributeDataFilter::GetFieldArray(
     fd, this->PolysArray, this->PolysArrayComponent);
   if ( this->PolysArray && fieldArray[2] == NULL )
-    {
+  {
     vtkErrorMacro(<<"Can't find array requested for polygons");
     return 0;
-    }
+  }
 
   fieldArray[3] = vtkFieldDataToAttributeDataFilter::GetFieldArray(
     fd, this->StripsArray, this->StripsArrayComponent);
   if ( this->StripsArray && fieldArray[3] == NULL )
-    {
+  {
     vtkErrorMacro(<<"Can't find array requested for triangle strips");
     return 0;
-    }
+  }
 
   if ( fieldArray[0] )
-    {
+  {
     vtkFieldDataToAttributeDataFilter::UpdateComponentRange(
       fieldArray[0], this->VertsComponentRange);
     vtkCellArray *verts = this->ConstructCellArray(
       fieldArray[0], this->VertsArrayComponent,
       this->VertsComponentRange);
     if ( verts != NULL )
-      {
+    {
       pd->SetVerts(verts);
       ncells += verts->GetNumberOfCells();
       verts->Delete();
-      }
-    this->VertsComponentRange[0] = this->VertsComponentRange[1] = -1;
     }
+    this->VertsComponentRange[0] = this->VertsComponentRange[1] = -1;
+  }
 
   if ( fieldArray[1] )
-    {
+  {
     vtkFieldDataToAttributeDataFilter::UpdateComponentRange(
       fieldArray[1], this->LinesComponentRange);
     vtkCellArray *lines = this->ConstructCellArray(
       fieldArray[1], this->LinesArrayComponent, this->LinesComponentRange);
     if ( lines != NULL )
-      {
+    {
       pd->SetLines(lines);
       ncells += lines->GetNumberOfCells();
       lines->Delete();
-      }
-    this->LinesComponentRange[0] = this->LinesComponentRange[1] = -1;
     }
+    this->LinesComponentRange[0] = this->LinesComponentRange[1] = -1;
+  }
 
   if ( fieldArray[2] )
-    {
+  {
     vtkFieldDataToAttributeDataFilter::UpdateComponentRange(
       fieldArray[2], this->PolysComponentRange);
     vtkCellArray *polys = this->ConstructCellArray(
       fieldArray[2], this->PolysArrayComponent,
       this->PolysComponentRange);
     if ( polys != NULL )
-      {
+    {
       pd->SetPolys(polys);
       ncells += polys->GetNumberOfCells();
       polys->Delete();
-      }
-    this->PolysComponentRange[0] = this->PolysComponentRange[1] = -1;
     }
+    this->PolysComponentRange[0] = this->PolysComponentRange[1] = -1;
+  }
 
   if ( fieldArray[3] )
-    {
+  {
     vtkFieldDataToAttributeDataFilter::UpdateComponentRange(
       fieldArray[3], this->StripsComponentRange);
     vtkCellArray *triStrips = this->ConstructCellArray(fieldArray[3],
                        this->StripsArrayComponent, this->StripsComponentRange);
     if ( triStrips != NULL )
-      {
+    {
       pd->SetStrips(triStrips);
       ncells += triStrips->GetNumberOfCells();
       triStrips->Delete();
-      }
-    this->StripsComponentRange[0] = this->StripsComponentRange[1] = -1;
     }
+    this->StripsComponentRange[0] = this->StripsComponentRange[1] = -1;
+  }
 
   return ncells;
 }
@@ -1162,10 +1130,10 @@ int vtkDataObjectToDataSetFilter::ConstructCells(vtkDataObject *input,
     this->CellTypeArrayComponent);
 
    if ( fieldArray[0] == NULL )
-    {
+   {
     vtkErrorMacro(<<"Can't find array requested for cell types");
     return 0;
-    }
+   }
 
   vtkFieldDataToAttributeDataFilter::UpdateComponentRange(
     fieldArray[0],
@@ -1178,14 +1146,14 @@ int vtkDataObjectToDataSetFilter::ConstructCells(vtkDataObject *input,
     this->CellConnectivityArray,
     this->CellConnectivityArrayComponent);
   if ( fieldArray[1] == NULL )
-    {
+  {
     vtkErrorMacro(<<"Can't find array requested for cell connectivity");
     return 0;
-    }
+  }
 
   // Okay, let's piece it together
   if ( fieldArray[0] ) //cell types defined
-    {
+  {
     // first we create the integer array of types
     vtkDataArray *da=fieldArray[0];
 
@@ -1193,26 +1161,26 @@ int vtkDataObjectToDataSetFilter::ConstructCells(vtkDataObject *input,
          this->CellTypeArrayComponent == 0 &&
          this->CellTypeComponentRange[0] == 0 &&
          this->CellTypeComponentRange[1] == da->GetMaxId() )
-      {
+    {
       types = static_cast<vtkIntArray *>(da)->GetPointer(0);
-      }
+    }
     // Otherwise, we'll copy the data by inserting it into a vtkCellArray
     else
-      {
+    {
       typesAllocated = 1;
       types = new int[ncells];
       for (i=this->CellTypeComponentRange[0];
            i <= this->CellTypeComponentRange[1]; i++)
-        {
+      {
         types[i] =
           static_cast<int>(da->GetComponent(i,this->CellTypeArrayComponent));
-        }
       }
+    }
     this->CellTypeComponentRange[0] = this->CellTypeComponentRange[1] = -1;
 
     // create connectivity
     if ( fieldArray[1] ) //cell connectivity defined
-      {
+    {
       vtkFieldDataToAttributeDataFilter::UpdateComponentRange(fieldArray[1],
                                          this->CellConnectivityComponentRange);
       vtkCellArray *carray = this->ConstructCellArray(
@@ -1220,18 +1188,18 @@ int vtkDataObjectToDataSetFilter::ConstructCells(vtkDataObject *input,
         this->CellConnectivityArrayComponent,
         this->CellConnectivityComponentRange);
       if ( carray != NULL ) //insert into unstructured grid
-        {
+      {
         ug->SetCells(types,carray);
         carray->Delete();
-        }
+      }
       this->CellConnectivityComponentRange[0]
         = this->CellConnectivityComponentRange[1] = -1;
-      }
-    if ( typesAllocated )
-      {
-      delete [] types;
-      }
     }
+    if ( typesAllocated )
+    {
+      delete [] types;
+    }
+  }
 
   return ncells;
 }
@@ -1250,10 +1218,10 @@ vtkCellArray *vtkDataObjectToDataSetFilter::ConstructCellArray(
   max = da->GetMaxId();
 
   if ( comp < 0 || comp >= numComp )
-    {
+  {
     vtkErrorMacro(<<"Bad component specification");
     return NULL;
-    }
+  }
 
   carray = vtkCellArray::New();
 
@@ -1262,38 +1230,38 @@ vtkCellArray *vtkDataObjectToDataSetFilter::ConstructCellArray(
   // figure out how many cells we have.
   if ( da->GetDataType() == VTK_ID_TYPE && da->GetNumberOfComponents() == 1
     && comp == 0 && compRange[0] == 0 && compRange[1] == max )
-    {
+  {
     vtkIdTypeArray *ia = static_cast<vtkIdTypeArray *>(da);
     for (ncells=i=0; i<ia->GetMaxId(); i+=(npts+1))
-      {
+    {
       ncells++;
       npts = ia->GetValue(i);
-      }
-    carray->SetCells(ncells,ia);
     }
+    carray->SetCells(ncells,ia);
+  }
   // Otherwise, we'll copy the data by inserting it into a vtkCellArray
   else
-    {
+  {
     for (i=min; i<max; i+=(npts+1))
-      {
+    {
       npts = static_cast<int>(da->GetComponent(i,comp));
       if ( npts <= 0 )
-        {
+      {
         vtkErrorMacro(<<"Error constructing cell array");
         carray->Delete();
         return NULL;
-        }
+      }
       else
-        {
+      {
         carray->InsertNextCell(npts);
         for (j=1; j<=npts; j++)
-          {
+        {
           carray->InsertCellPoint(static_cast<int>(
                                     da->GetComponent(i+j,comp)));
-          }
         }
       }
     }
+  }
 
   return carray;
 }
@@ -1308,20 +1276,20 @@ void vtkDataObjectToDataSetFilter::SetDimensionsComponent(char *arrayName,
   vtkFieldDataToAttributeDataFilter::SetArrayName(this, this->DimensionsArray,
                                                   arrayName);
   if ( this->DimensionsArrayComponent != arrayComp )
-    {
+  {
     this->DimensionsArrayComponent = arrayComp;
     this->Modified();
-    }
+  }
   if ( this->DimensionsComponentRange[0] != min )
-    {
+  {
     this->DimensionsComponentRange[0] = min;
     this->Modified();
-    }
+  }
   if ( this->DimensionsComponentRange[1] != max )
-    {
+  {
     this->DimensionsComponentRange[1] = max;
     this->Modified();
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -1332,20 +1300,20 @@ void vtkDataObjectToDataSetFilter::SetSpacingComponent(char *arrayName,
   vtkFieldDataToAttributeDataFilter::SetArrayName(this, this->SpacingArray,
                                                   arrayName);
   if ( this->SpacingArrayComponent != arrayComp )
-    {
+  {
     this->SpacingArrayComponent = arrayComp;
     this->Modified();
-    }
+  }
   if ( this->SpacingComponentRange[0] != min )
-    {
+  {
     this->SpacingComponentRange[0] = min;
     this->Modified();
-    }
+  }
   if ( this->SpacingComponentRange[1] != max )
-    {
+  {
     this->SpacingComponentRange[1] = max;
     this->Modified();
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -1356,51 +1324,51 @@ void vtkDataObjectToDataSetFilter::SetOriginComponent(char *arrayName,
   vtkFieldDataToAttributeDataFilter::SetArrayName(this, this->OriginArray,
                                                   arrayName);
   if ( this->OriginArrayComponent != arrayComp )
-    {
+  {
     this->OriginArrayComponent = arrayComp;
     this->Modified();
-    }
+  }
   if ( this->OriginComponentRange[0] != min )
-    {
+  {
     this->OriginComponentRange[0] = min;
     this->Modified();
-    }
+  }
   if ( this->OriginComponentRange[1] != max )
-    {
+  {
     this->OriginComponentRange[1] = max;
     this->Modified();
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
 void vtkDataObjectToDataSetFilter::ConstructDimensions(vtkDataObject *input)
 {
   if ( this->DimensionsArray == NULL || this->DimensionsArrayComponent < 0 )
-    {
+  {
     return; //assume dimensions have been set
-    }
+  }
   else
-    {
+  {
     vtkFieldData *fd=input->GetFieldData();
     vtkDataArray *fieldArray
       = vtkFieldDataToAttributeDataFilter::GetFieldArray(
         fd, this->DimensionsArray, this->DimensionsArrayComponent);
     if ( fieldArray == NULL )
-      {
+    {
       vtkErrorMacro(<<"Can't find array requested for dimensions");
       return;
-      }
+    }
 
     vtkFieldDataToAttributeDataFilter::UpdateComponentRange(
       fieldArray, this->DimensionsComponentRange);
 
     for (int i=0; i<3; i++)
-      {
+    {
       this->Dimensions[i] = static_cast<int>(
         fieldArray->GetComponent(this->DimensionsComponentRange[0]+i,
                                  this->DimensionsArrayComponent));
-      }
     }
+  }
 
   this->DimensionsComponentRange[0] = this->DimensionsComponentRange[1] = -1;
 }
@@ -1409,31 +1377,31 @@ void vtkDataObjectToDataSetFilter::ConstructDimensions(vtkDataObject *input)
 void vtkDataObjectToDataSetFilter::ConstructSpacing(vtkDataObject *input)
 {
   if ( this->SpacingArray == NULL || this->SpacingArrayComponent < 0 )
-    {
+  {
     return; //assume Spacing have been set
-    }
+  }
   else
-    {
+  {
     vtkFieldData *fd=input->GetFieldData();
     vtkDataArray *fieldArray
       = vtkFieldDataToAttributeDataFilter::GetFieldArray(
         fd, this->SpacingArray, this->SpacingArrayComponent);
     if ( fieldArray == NULL )
-      {
+    {
       vtkErrorMacro(<<"Can't find array requested for Spacing");
       return;
-      }
+    }
 
     vtkFieldDataToAttributeDataFilter::UpdateComponentRange(
       fieldArray, this->SpacingComponentRange);
 
     for (int i=0; i<3; i++)
-      {
+    {
       this->Spacing[i] = fieldArray->GetComponent(
         this->SpacingComponentRange[0]+i,
         this->SpacingArrayComponent);
-      }
     }
+  }
   this->SpacingComponentRange[0] = this->SpacingComponentRange[1] = -1;
 }
 
@@ -1447,32 +1415,32 @@ vtkDataSet *vtkDataObjectToDataSetFilter::GetOutput(int idx)
 void vtkDataObjectToDataSetFilter::ConstructOrigin(vtkDataObject *input)
 {
   if ( this->OriginArray == NULL || this->OriginArrayComponent < 0 )
-    {
+  {
     return; //assume Origin have been set
-    }
+  }
   else
-    {
+  {
     vtkFieldData *fd=input->GetFieldData();
     vtkDataArray *fieldArray
       = vtkFieldDataToAttributeDataFilter::GetFieldArray(
         fd, this->OriginArray, this->OriginArrayComponent);
     if ( fieldArray == NULL )
-      {
+    {
       vtkErrorMacro(<<"Can't find array requested for Origin");
       return;
-      }
+    }
 
     vtkFieldDataToAttributeDataFilter::UpdateComponentRange(
       fieldArray,
       this->OriginComponentRange);
 
     for (int i=0; i<3; i++)
-      {
+    {
       this->Origin[i] = fieldArray->GetComponent(
         this->OriginComponentRange[0]+i,
         this->OriginArrayComponent);
-      }
     }
+  }
 
   this->OriginComponentRange[0] = this->OriginComponentRange[1] = -1;
 }
@@ -1495,9 +1463,9 @@ int vtkDataObjectToDataSetFilter::RequestDataObject(
   vtkDataSet *output = vtkDataSet::SafeDownCast(
     outInfo->Get(vtkDataObject::DATA_OBJECT()));
   if (!output || (output->GetDataObjectType() != this->DataSetType))
-    {
+  {
     switch (this->DataSetType)
-      {
+    {
       case VTK_POLY_DATA:
         output = vtkPolyData::New();
         break;
@@ -1515,12 +1483,12 @@ int vtkDataObjectToDataSetFilter::RequestDataObject(
         break;
       default:
         vtkWarningMacro("unknown DataSetType");
-      }
+    }
     if (output)
-      {
+    {
       outInfo->Set(vtkDataObject::DATA_OBJECT(), output);
       output->Delete();
-      }
     }
+  }
   return 1;
 }
