@@ -27,6 +27,8 @@
 #include "vtkTriangleStrip.h"
 #include "vtkPriorityQueue.h"
 
+#include "vtkNew.h"
+
 vtkStandardNewMacro(vtkPolyDataNormals);
 
 // Construct with feature angle=30, splitting and consistency turned on,
@@ -44,6 +46,15 @@ vtkPolyDataNormals::vtkPolyDataNormals()
   // some internal data
   this->NumFlips = 0;
   this->OutputPointsPrecision = vtkAlgorithm::DEFAULT_PRECISION;
+  this->Wave = 0;
+  this->Wave2 = 0;
+  this->CellIds = 0;
+  this->Map = 0;
+  this->OldMesh = 0;
+  this->NewMesh = 0;
+  this->Visited = 0;
+  this->PolyNormals = 0;
+  this->CosAngle = 0.0;
 }
 
 #define VTK_CELL_NOT_VISITED     0
@@ -65,12 +76,9 @@ int vtkPolyDataNormals::RequestData(
   vtkPolyData *output = vtkPolyData::SafeDownCast(
     outInfo->Get(vtkDataObject::DATA_OBJECT()));
 
-  int j;
   vtkIdType npts = 0;
-  vtkIdType i;
   vtkIdType *pts = 0;
   vtkIdType numNewPts;
-  double polyNormal[3], vertNormal[3], length;
   double flipDirection=1.0;
   vtkIdType numPolys, numStrips;
   vtkIdType cellId;
@@ -80,7 +88,7 @@ int vtkPolyDataNormals::RequestData(
   vtkPoints *newPts = NULL;
   vtkFloatArray *newNormals;
   vtkPointData *pd, *outPD;
-  vtkCellData *outCD;
+  vtkDataSetAttributes* outCD = output->GetCellData();
   double n[3];
   vtkCellArray *newPolys;
   vtkIdType ptId, oldId;
@@ -90,23 +98,26 @@ int vtkPolyDataNormals::RequestData(
   numPolys=input->GetNumberOfPolys();
   numStrips=input->GetNumberOfStrips();
   if ( (numPts=input->GetNumberOfPoints()) < 1 )
-    {
+  {
     vtkDebugMacro(<<"No data to generate normals for!");
     return 1;
-    }
+  }
 
 
   // If there is nothing to do, pass the data through
   if ( (this->ComputePointNormals == 0 && this->ComputeCellNormals == 0) ||
        (numPolys < 1 && numStrips < 1) )
-    { //don't do anything! pass data through
+  { //don't do anything! pass data through
     output->CopyStructure(input);
     output->GetPointData()->PassData(input->GetPointData());
     output->GetCellData()->PassData(input->GetCellData());
     return 1;
-    }
-  output->GetCellData()->PassData(input->GetCellData());
-  output->SetFieldData(input->GetFieldData());
+  }
+
+  if (numStrips < 1)
+  {
+    output->GetCellData()->PassData(input->GetCellData());
+  }
 
   // Load data into cell structure.  We need two copies: one is a
   // non-writable mesh used to perform topological queries.  The other
@@ -119,38 +130,56 @@ int vtkPolyDataNormals::RequestData(
   this->OldMesh = vtkPolyData::New();
   this->OldMesh->SetPoints(inPts);
   if ( numStrips > 0 ) //have to decompose strips into triangles
-    {
+  {
+    vtkDataSetAttributes* inCD = input->GetCellData();
+    // When we have triangle strips, make sure to create and copy
+    // the cell data appropriately. Since strips are broken into
+    // triangles, cell data cannot be passed as it is and needs to
+    // be copied tuple by tuple.
+    outCD->CopyAllocate(inCD);
     if ( numPolys > 0 )
-      {
+    {
       polys = vtkCellArray::New();
       polys->DeepCopy(inPolys);
-      }
-    else
+      vtkNew<vtkIdList> ids;
+      ids->SetNumberOfIds(numPolys);
+      for (vtkIdType i=0; i<numPolys; i++)
       {
+        ids->SetId(i, i);
+      }
+      outCD->CopyData(inCD, ids.GetPointer(), ids.GetPointer());
+    }
+    else
+    {
       polys = vtkCellArray::New();
       polys->Allocate(polys->EstimateSize(numStrips,5));
-      }
-    for ( inStrips->InitTraversal(); inStrips->GetNextCell(npts,pts); )
-      {
+    }
+    vtkIdType inCellIdx = numPolys;
+    vtkIdType outCellIdx = numPolys;
+    for ( inStrips->InitTraversal(); inStrips->GetNextCell(npts,pts); inCellIdx++)
+    {
       vtkTriangleStrip::DecomposeStrip(npts, pts, polys);
+      // Copy the cell data for the strip to each triangle.
+      for (vtkIdType i=0; i<npts-2; i++)
+      {
+        outCD->CopyData(inCD, inCellIdx, outCellIdx++);
       }
+    }
     this->OldMesh->SetPolys(polys);
     polys->Delete();
     numPolys = polys->GetNumberOfCells();//added some new triangles
-    }
+  }
   else
-    {
+  {
     this->OldMesh->SetPolys(inPolys);
     polys = inPolys;
-    }
+  }
   this->OldMesh->BuildLinks();
   this->UpdateProgress(0.10);
 
   pd = input->GetPointData();
   outPD = output->GetPointData();
 
-  outCD = output->GetCellData();
-
   this->NewMesh = vtkPolyData::New();
   this->NewMesh->SetPoints(inPts);
   // create a copy because we're modifying it
@@ -162,16 +191,16 @@ int vtkPolyDataNormals::RequestData(
   // The visited array keeps track of which polygons have been visited.
   //
   if ( this->Consistency || this->Splitting || this->AutoOrientNormals )
-    {
+  {
     this->Visited = new int[numPolys];
     memset(this->Visited, VTK_CELL_NOT_VISITED, numPolys*sizeof(int));
     this->CellIds = vtkIdList::New();
     this->CellIds->Allocate(VTK_CELL_SIZE);
-    }
+  }
   else
-    {
+  {
     this->Visited = NULL;
-    }
+  }
 
   //  Traverse all polygons insuring proper direction of ordering.  This
   //  works by propagating a wave from a seed polygon to the polygon's
@@ -180,7 +209,7 @@ int vtkPolyDataNormals::RequestData(
   //
   this->NumFlips = 0;
   if (this->AutoOrientNormals)
-    {
+  {
     // No need to check this->Consistency. It's implied.
 
     // Ok, here's the basic idea: the "left-most" polygon should
@@ -210,16 +239,16 @@ int vtkPolyDataNormals::RequestData(
     // So that we can find leftmost point
     leftmostPoints->Allocate(numPts);
     for (ptId=0; ptId < numPts; ptId++)
-      {
+    {
       leftmostPoints->Insert(inPts->GetPoint(ptId)[0],ptId);
-      }
+    }
 
     // Repeat this while loop as long as the queue is not empty,
     // because there may be multiple connected components, each of
     // which needs to be seeded independently with a correctly
     // oriented polygon.
     while (leftmostPoints->GetNumberOfItems())
-      {
+    {
       foundLeftmostCell = 0;
       // Keep iterating through leftmost points and cells located at
       // those points until I've got a leftmost point with
@@ -231,81 +260,81 @@ int vtkPolyDataNormals::RequestData(
         bestNormalAbsXComponent = 0.0;
         bestReverseFlag = 0;
         for (cIdx = 0; cIdx < nleftmostCells; cIdx++)
-          {
+        {
           currentCellID = leftmostCells[cIdx];
           if (this->Visited[currentCellID] == VTK_CELL_VISITED)
-            {
+          {
             continue;
-            }
+          }
           this->OldMesh->GetCellPoints(currentCellID, nCellPts, cellPts);
           vtkPolygon::ComputeNormal(inPts, nCellPts, cellPts, n);
           // Ok, see if this leftmost cell candidate is the best
           // so far
           if (fabs(n[0]) > bestNormalAbsXComponent)
-            {
+          {
             bestNormalAbsXComponent = fabs(n[0]);
             leftmostCellID = currentCellID;
             // If the current leftmost cell's normal is pointing to the
             // right, then the vertex ordering is wrong
             bestReverseFlag = (n[0] > 0);
             foundLeftmostCell = 1;
-            } // if this normal is most x-aligned so far
-          } // for each cell at current leftmost point
-        } while (leftmostPoints->GetNumberOfItems() && !foundLeftmostCell);
+          } // if this normal is most x-aligned so far
+        } // for each cell at current leftmost point
+      } while (leftmostPoints->GetNumberOfItems() && !foundLeftmostCell);
       if (foundLeftmostCell)
-        {
+      {
         // We've got the seed for a connected component! But do
         // we need to flip it first? We do, if it was pointed the wrong
         // way to begin with, or if the user requested flipping all
         // normals, but if both are true, then we leave it as it is.
         if (bestReverseFlag ^ this->FlipNormals)
-          {
+        {
           this->NewMesh->ReverseCell(leftmostCellID);
           this->NumFlips++;
-          }
+        }
         this->Wave->InsertNextId(leftmostCellID);
         this->Visited[leftmostCellID] = VTK_CELL_VISITED;
         this->TraverseAndOrder();
         this->Wave->Reset();
         this->Wave2->Reset();
-        } // if found leftmost cell
-      } // Still some points in the queue
+      } // if found leftmost cell
+    } // Still some points in the queue
     this->Wave->Delete();
     this->Wave2->Delete();
     leftmostPoints->Delete();
     vtkDebugMacro(<<"Reversed ordering of " << this->NumFlips << " polygons");
-    } // automatically orient normals
+  } // automatically orient normals
   else
-    {
+  {
     if ( this->Consistency )
-      {
+    {
       this->Wave = vtkIdList::New();
       this->Wave->Allocate(numPolys/4+1,numPolys);
       this->Wave2 = vtkIdList::New();
       this->Wave2->Allocate(numPolys/4+1,numPolys);
       for (cellId=0; cellId < numPolys; cellId++)
-        {
+      {
         if ( this->Visited[cellId] == VTK_CELL_NOT_VISITED)
-          {
+        {
           if ( this->FlipNormals )
-            {
+          {
             this->NumFlips++;
             this->NewMesh->ReverseCell(cellId);
-            }
+          }
           this->Wave->InsertNextId(cellId);
           this->Visited[cellId] = VTK_CELL_VISITED;
           this->TraverseAndOrder();
-          }
+        }
 
         this->Wave->Reset();
         this->Wave2->Reset();
-        }
+      }
 
       this->Wave->Delete();
       this->Wave2->Delete();
       vtkDebugMacro(<<"Reversed ordering of " << this->NumFlips << " polygons");
-      }//Consistent ordering
-    } // don't automatically orient normals
+    }//Consistent ordering
+  } // don't automatically orient normals
 
   this->UpdateProgress(0.333);
 
@@ -319,22 +348,22 @@ int vtkPolyDataNormals::RequestData(
 
   for (cellId=0, newPolys->InitTraversal(); newPolys->GetNextCell(npts,pts);
        cellId++ )
-    {
+  {
     if ((cellId % 1000) == 0)
-      {
+    {
       this->UpdateProgress (0.333 + 0.333 * (double) cellId / (double) numPolys);
       if (this->GetAbortExecute())
-        {
+      {
         break;
-        }
       }
+    }
     vtkPolygon::ComputeNormal(inPts, npts, pts, n);
     this->PolyNormals->SetTuple(cellId,n);
-    }
+  }
 
   // Split mesh if sharp features
   if ( this->Splitting )
-    {
+  {
     //  Traverse all nodes; evaluate loops and feature edges.  If feature
     //  edges found, split mesh creating new nodes.  Update polygon
     // connectivity.
@@ -345,15 +374,15 @@ int vtkPolyDataNormals::RequestData(
     //
     this->Map = vtkIdList::New();
     this->Map->SetNumberOfIds(numPts);
-    for (i=0; i < numPts; i++)
-      {
+    for (vtkIdType i=0; i < numPts; i++)
+    {
       this->Map->SetId(i,i);
-      }
+    }
 
     for (ptId=0; ptId < numPts; ptId++)
-      {
+    {
       this->MarkAndSplit(ptId);
-      }//for all input points
+    }//for all input points
 
     numNewPts = this->Map->GetNumberOfIds();
 
@@ -368,44 +397,48 @@ int vtkPolyDataNormals::RequestData(
 
     // set precision for the points in the output
     if(this->OutputPointsPrecision == vtkAlgorithm::DEFAULT_PRECISION)
-      {
+    {
       vtkPointSet *inputPointSet = vtkPointSet::SafeDownCast(input);
       if(inputPointSet)
-        {
+      {
         newPts->SetDataType(inputPointSet->GetPoints()->GetDataType());
-        }
       }
+      else
+      {
+        newPts->SetDataType(VTK_FLOAT);
+      }
+    }
     else if(this->OutputPointsPrecision == vtkAlgorithm::SINGLE_PRECISION)
-      {
+    {
       newPts->SetDataType(VTK_FLOAT);
-      }
+    }
     else if(this->OutputPointsPrecision == vtkAlgorithm::DOUBLE_PRECISION)
-      {
+    {
       newPts->SetDataType(VTK_DOUBLE);
-      }
+    }
 
     newPts->SetNumberOfPoints(numNewPts);
     for (ptId=0; ptId < numNewPts; ptId++)
-      {
+    {
       oldId = this->Map->GetId(ptId);
       newPts->SetPoint(ptId,inPts->GetPoint(oldId));
       outPD->CopyData(pd,oldId,ptId);
-      }
+    }
     this->Map->Delete();
-    } //splitting
+  } //splitting
 
   else //no splitting, so no new points
-    {
+  {
     numNewPts = numPts;
     outPD->CopyNormalsOff();
     outPD->PassData(pd);
-    }
+  }
 
   if ( this->Consistency || this->Splitting )
-    {
+  {
     delete [] this->Visited;
     this->CellIds->Delete();
-    }
+  }
 
   this->UpdateProgress(0.80);
 
@@ -413,79 +446,73 @@ int vtkPolyDataNormals::RequestData(
   //  accumulating them at the vertices.
   //
   if ( this->FlipNormals && ! this->Consistency )
-    {
+  {
     flipDirection = -1.0;
-    }
+  }
 
   newNormals = vtkFloatArray::New();
   newNormals->SetNumberOfComponents(3);
   newNormals->SetNumberOfTuples(numNewPts);
   newNormals->SetName("Normals");
-  n[0] = n[1] = n[2] = 0.0;
-  for (i=0; i < numNewPts; i++)
-    {
-    newNormals->SetTuple(i,n);
-    }
+  float *fNormals = newNormals->WritePointer(0, 3 * numNewPts);
+  std::fill_n(fNormals, 3 * numNewPts, 0);
+
+  float *fPolyNormals = this->PolyNormals->WritePointer(0, 3 * numPolys);
 
   if (this->ComputePointNormals)
+  {
+    for (cellId=0, newPolys->InitTraversal(); newPolys->GetNextCell(npts, pts);
+         ++cellId)
     {
-    for (cellId=0, newPolys->InitTraversal(); newPolys->GetNextCell(npts,pts);
-          cellId++ )
+      for (vtkIdType i = 0; i < npts; ++i)
       {
-      this->PolyNormals->GetTuple(cellId, polyNormal);
-
-      for (i=0; i < npts; i++)
-        {
-        newNormals->GetTuple(pts[i], vertNormal);
-        for (j=0; j < 3; j++)
-          {
-          n[j] = vertNormal[j] + polyNormal[j];
-          }
-        newNormals->SetTuple(pts[i],n);
-        }
-      }
-
-    for (i=0; i < numNewPts; i++)
-      {
-      newNormals->GetTuple(i, vertNormal);
-      length = vtkMath::Norm(vertNormal);
-      if (length != 0.0)
-        {
-        for (j=0; j < 3; j++)
-          {
-          n[j] = vertNormal[j] / length * flipDirection;
-          }
-        }
-      newNormals->SetTuple(i,n);
+        fNormals[3 * pts[i]] += fPolyNormals[3 * cellId];
+        fNormals[3 * pts[i] + 1] += fPolyNormals[3 * cellId + 1];
+        fNormals[3 * pts[i] + 2] += fPolyNormals[3 * cellId + 2];
       }
     }
 
+    for (vtkIdType i = 0; i < numNewPts; ++i)
+    {
+      const double length = sqrt(fNormals[3 * i] * fNormals[3 * i] +
+                                 fNormals[3 * i + 1] * fNormals[3 * i + 1] +
+                                 fNormals[3 * i + 2] * fNormals[3 * i + 2]
+                                 ) * flipDirection;
+      if (length != 0.0)
+      {
+        fNormals[3 * i] /= length;
+        fNormals[3 * i + 1] /= length;
+        fNormals[3 * i + 2] /= length;
+      }
+    }
+  }
+
   //  Update ourselves.  If no new nodes have been created (i.e., no
   //  splitting), we can simply pass data through.
   //
   if ( ! this->Splitting )
-    {
+  {
     output->SetPoints(inPts);
-    }
+  }
 
   //  If there is splitting, then have to send down the new data.
   //
   else
-    {
+  {
     output->SetPoints(newPts);
     newPts->Delete();
-    }
+  }
 
   if (this->ComputeCellNormals)
-    {
+  {
     outCD->SetNormals(this->PolyNormals);
-    }
+  }
   this->PolyNormals->Delete();
 
   if (this->ComputePointNormals)
-    {
+  {
     outPD->SetNormals(newNormals);
-    }
+  }
   newNormals->Delete();
 
   output->SetPolys(newPolys);
@@ -505,8 +532,8 @@ int vtkPolyDataNormals::RequestData(
 //
 void vtkPolyDataNormals::TraverseAndOrder (void)
 {
-  vtkIdType p1, p2, i, k;
-  int j, l;
+  vtkIdType i, k;
+  int j, l, j1;
   vtkIdType numIds, cellId;
   vtkIdType *pts, *neiPts, npts, numNeiPts;
   vtkIdType neighbor;
@@ -514,61 +541,58 @@ void vtkPolyDataNormals::TraverseAndOrder (void)
 
   // propagate wave until nothing left in wave
   while ( (numIds=this->Wave->GetNumberOfIds()) > 0 )
-    {
+  {
     for ( i=0; i < numIds; i++ )
-      {
+    {
       cellId = this->Wave->GetId(i);
 
       this->NewMesh->GetCellPoints(cellId, npts, pts);
 
-      for (j=0; j < npts; j++) //for each edge neighbor
-        {
-        p1 = pts[j];
-        p2 = pts[(j+1)%npts];
-
-        this->OldMesh->GetCellEdgeNeighbors(cellId, p1, p2, this->CellIds);
+      for (j = 0, j1 = 1; j < npts; ++j, (j1 = (++j1 < npts) ? j1 : 0)) //for each edge neighbor
+      {
+        this->OldMesh->GetCellEdgeNeighbors(cellId, pts[j], pts[j1], this->CellIds);
 
         //  Check the direction of the neighbor ordering.  Should be
         //  consistent with us (i.e., if we are n1->n2,
         // neighbor should be n2->n1).
         if ( this->CellIds->GetNumberOfIds() == 1 ||
              this->NonManifoldTraversal )
-          {
+        {
           for (k=0; k < this->CellIds->GetNumberOfIds(); k++)
-            {
+          {
             if (this->Visited[this->CellIds->GetId(k)]==VTK_CELL_NOT_VISITED)
-              {
+            {
               neighbor = this->CellIds->GetId(k);
               this->NewMesh->GetCellPoints(neighbor,numNeiPts,neiPts);
               for (l=0; l < numNeiPts; l++)
+              {
+                if (neiPts[l] == pts[j1])
                 {
-                if (neiPts[l] == p2)
-                  {
                   break;
-                  }
                 }
+              }
 
               //  Have to reverse ordering if neighbor not consistent
               //
-              if ( neiPts[(l+1)%numNeiPts] != p1 )
-                {
+              if ( neiPts[(l+1)%numNeiPts] != pts[j] )
+              {
                 this->NumFlips++;
                 this->NewMesh->ReverseCell(neighbor);
-                }
+              }
               this->Visited[neighbor] = VTK_CELL_VISITED;
               this->Wave2->InsertNextId(neighbor);
-              }// if cell not visited
-            } // for each edge neighbor
-          } //for manifold or non-manifold traversal allowed
-        } // for all edges of this polygon
-      } //for all cells in wave
+            }// if cell not visited
+          } // for each edge neighbor
+        } //for manifold or non-manifold traversal allowed
+      } // for all edges of this polygon
+    } //for all cells in wave
 
     //swap wave and proceed with propagation
     tmpWave = this->Wave;
     this->Wave = this->Wave2;
     this->Wave2 = tmpWave;
     this->Wave2->Reset();
-    } //while wave still propagating
+  } //while wave still propagating
 
   return;
 }
@@ -586,9 +610,9 @@ void vtkPolyDataNormals::MarkAndSplit (vtkIdType ptId)
   vtkIdType *cells;
   this->OldMesh->GetPointCells(ptId,ncells,cells);
   if ( ncells <= 1 )
-    {
+  {
     return; //point does not need to be further disconnected
-    }
+  }
 
   // Start moving around the "cycle" of points using the point. Label
   // each point as requiring a visit. Then label each subregion of cells
@@ -599,9 +623,9 @@ void vtkPolyDataNormals::MarkAndSplit (vtkIdType ptId)
   //
   // Start by initializing the cells as unvisited
   for (i=0; i<ncells; i++)
-    {
+  {
     this->Visited[cells[i]] = -1;
-    }
+  }
 
   // Loop over all cells and mark the region that each is in.
   //
@@ -611,99 +635,99 @@ void vtkPolyDataNormals::MarkAndSplit (vtkIdType ptId)
   vtkIdType spot, neiPt[2], nei, cellId, neiCellId;
   double thisNormal[3], neiNormal[3];
   for (j=0; j<ncells; j++) //for all cells connected to point
-    {
+  {
     if ( this->Visited[cells[j]] < 0 ) //for all unvisited cells
-      {
+    {
       this->Visited[cells[j]] = numRegions;
       //okay, mark all the cells connected to this seed cell and using ptId
       this->OldMesh->GetCellPoints(cells[j],numPts,pts);
 
       //find the two edges
       for (spot=0; spot < numPts; spot++)
-        {
+      {
         if ( pts[spot] == ptId )
-          {
+        {
           break;
-          }
         }
+      }
 
       if ( spot == 0 )
-        {
+      {
         neiPt[0] = pts[spot+1];
         neiPt[1] = pts[numPts-1];
-        }
+      }
       else if ( spot == (numPts-1) )
-        {
+      {
         neiPt[0] = pts[spot-1];
         neiPt[1] = pts[0];
-        }
+      }
       else
-        {
+      {
         neiPt[0] = pts[spot+1];
         neiPt[1] = pts[spot-1];
-        }
+      }
 
       for (i=0; i<2; i++) //for each of the two edges of the seed cell
-        {
+      {
         cellId = cells[j];
         nei = neiPt[i];
         while ( cellId >= 0 ) //while we can grow this region
-          {
+        {
           this->OldMesh->GetCellEdgeNeighbors(cellId,ptId,nei,this->CellIds);
           if ( this->CellIds->GetNumberOfIds() == 1 &&
                this->Visited[(neiCellId=this->CellIds->GetId(0))] < 0 )
-            {
+          {
             this->PolyNormals->GetTuple(cellId, thisNormal);
             this->PolyNormals->GetTuple(neiCellId, neiNormal);
 
             if ( vtkMath::Dot(thisNormal,neiNormal) > CosAngle )
-              {
+            {
               //visit and arrange to visit next edge neighbor
               this->Visited[neiCellId] = numRegions;
               cellId = neiCellId;
               this->OldMesh->GetCellPoints(cellId,numPts,pts);
 
               for (spot=0; spot < numPts; spot++)
-                {
+              {
                 if ( pts[spot] == ptId )
-                  {
+                {
                   break;
-                  }
                 }
+              }
 
               if (spot == 0)
-                {
-                nei = (pts[spot+1] != nei ? pts[spot+1] : pts[numPts-1]);
-                }
-              else if (spot == (numPts-1))
-                {
-                nei = (pts[spot-1] != nei ? pts[spot-1] : pts[0]);
-                }
-              else
-                {
-                nei = (pts[spot+1] != nei ? pts[spot+1] : pts[spot-1]);
-                }
-
-              }//if not separated by edge angle
-            else
               {
-              cellId = -1; //separated by edge angle
+                nei = (pts[spot+1] != nei ? pts[spot+1] : pts[numPts-1]);
               }
-            }//if can move to edge neighbor
-          else
+              else if (spot == (numPts-1))
+              {
+                nei = (pts[spot-1] != nei ? pts[spot-1] : pts[0]);
+              }
+              else
+              {
+                nei = (pts[spot+1] != nei ? pts[spot+1] : pts[spot-1]);
+              }
+
+            }//if not separated by edge angle
+            else
             {
-            cellId = -1;//separated by previous visit, boundary, or non-manifold
+              cellId = -1; //separated by edge angle
             }
-          }//while visit wave is propagating
-        }//for each of the two edges of the starting cell
+          }//if can move to edge neighbor
+          else
+          {
+            cellId = -1;//separated by previous visit, boundary, or non-manifold
+          }
+        }//while visit wave is propagating
+      }//for each of the two edges of the starting cell
       numRegions++;
-      }//if cell is unvisited
-    }//for all cells connected to point ptId
+    }//if cell is unvisited
+  }//for all cells connected to point ptId
 
   if ( numRegions <=1 )
-    {
+  {
     return; //a single region, no splitting ever required
-    }
+  }
 
   // Okay, for all cells not in the first region, the ptId is
   // replaced with a new ptId, which is a duplicate of the first
@@ -712,24 +736,24 @@ void vtkPolyDataNormals::MarkAndSplit (vtkIdType ptId)
   vtkIdType lastId = this->Map->GetNumberOfIds();
   vtkIdType replacementPoint;
   for (j=0; j<ncells; j++)
-    {
+  {
     if (this->Visited[cells[j]] > 0 ) //replace point if splitting needed
-      {
+    {
       replacementPoint = lastId + this->Visited[cells[j]] - 1;
 
       this->Map->InsertId(replacementPoint, ptId);
 
       this->NewMesh->GetCellPoints(cells[j],numPts,pts);
       for (i=0; i < numPts; i++)
-        {
+      {
         if ( pts[i] == ptId )
-          {
+        {
           pts[i] = replacementPoint; // this is very nasty! direct write!
           break;
-          }
-        }//replace ptId with split point
-      }//if not in first regions and requiring splitting
-    }//for all cells connected to ptId
+        }
+      }//replace ptId with split point
+    }//if not in first regions and requiring splitting
+  }//for all cells connected to ptId
 
   return;
 }
