@@ -14,6 +14,8 @@
 =========================================================================*/
 #include "vtkStreamer.h"
 
+#ifndef VTK_LEGACY_REMOVE
+
 #include "vtkCell.h"
 #include "vtkDataSet.h"
 #include "vtkDoubleArray.h"
@@ -56,14 +58,14 @@ vtkStreamer::StreamPoint *vtkStreamer::StreamArray::Resize(vtkIdType sz)
   vtkIdType newSize;
 
   if (sz >= this->Size)
-    {
+  {
     newSize = this->Size +
       this->Extend*(((sz-this->Size)/this->Extend)+1);
-    }
+  }
   else
-    {
+  {
     newSize = sz;
-    }
+  }
 
   newArray = new vtkStreamer::StreamPoint[newSize];
 
@@ -106,19 +108,18 @@ vtkStreamer::vtkStreamer()
   this->SavePointInterval = 0.00001;
 
   this->SetNumberOfInputPorts(2);
+
+  VTK_LEGACY_BODY(vtkStreamer::vtkStreamer, "VTK 6.3");
 }
 
 vtkStreamer::~vtkStreamer()
 {
-  if( this->Streamers )
-    {
-    delete [] this->Streamers;
-    }
+  delete [] this->Streamers;
 
   if (this->Threader)
-    {
+  {
     this->Threader->Delete();
-    }
+  }
   this->SetIntegrator(0);
 }
 
@@ -135,9 +136,9 @@ void vtkStreamer::SetSourceData(vtkDataSet *source)
 vtkDataSet *vtkStreamer::GetSource()
 {
   if (this->GetNumberOfInputConnections(1) < 1)
-    {
+  {
     return NULL;
-    }
+  }
   return vtkDataSet::SafeDownCast(
     this->GetExecutive()->GetInputData(1, 0));
 }
@@ -151,7 +152,7 @@ void vtkStreamer::SetStartLocation(vtkIdType cellId, int subId,
        pcoords[0] !=  this->StartPCoords[0] ||
        pcoords[1] !=  this->StartPCoords[1] ||
        pcoords[2] !=  this->StartPCoords[2] )
-    {
+  {
     this->Modified();
     this->StartFrom = VTK_START_FROM_LOCATION;
 
@@ -160,7 +161,7 @@ void vtkStreamer::SetStartLocation(vtkIdType cellId, int subId,
     this->StartPCoords[0] = pcoords[0];
     this->StartPCoords[1] = pcoords[1];
     this->StartPCoords[2] = pcoords[2];
-    }
+  }
 }
 
 // Specify the start of the streamline in the cell coordinate system. That is,
@@ -192,14 +193,14 @@ void vtkStreamer::SetStartPosition(double x[3])
 {
   if ( x[0] != this->StartPosition[0] || x[1] != this->StartPosition[1] ||
        x[2] != this->StartPosition[2] )
-    {
+  {
     this->Modified();
     this->StartFrom = VTK_START_FROM_POSITION;
 
     this->StartPosition[0] = x[0];
     this->StartPosition[1] = x[1];
     this->StartPosition[2] = x[2];
-    }
+  }
 }
 
 // Specify the start of the streamline in the global coordinate system. Search
@@ -266,21 +267,21 @@ VTK_THREAD_RETURN_TYPE vtkStreamer::ThreadedIntegrate( void *arg )
   cellVectors->SetNumberOfComponents(3);
   cellVectors->Allocate(3*VTK_CELL_SIZE);
   if (inScalars)
-    {
+  {
     cellScalars = inScalars->NewInstance();
     cellScalars->SetNumberOfComponents(inScalars->GetNumberOfComponents());
     cellScalars->Allocate(inScalars->GetNumberOfComponents()*VTK_CELL_SIZE);
-    }
+  }
 
   // Set the function set to be integrated
   vtkInterpolatedVelocityField* func = vtkInterpolatedVelocityField::New();
   func->AddDataSet(input);
 
   if (self->GetIntegrator() == 0)
-    {
+  {
     vtkGenericWarningMacro("No integrator is specified.");
     return VTK_THREAD_RETURN_VALUE;
-    }
+  }
 
   double *w = new double[input->GetMaxCellSize()];
 
@@ -298,16 +299,16 @@ VTK_THREAD_RETURN_TYPE vtkStreamer::ThreadedIntegrate( void *arg )
   // For each streamer, integrate in appropriate direction
   // Do only the streamers that this thread should handle.
   for (ptId=0; ptId < self->GetNumberOfStreamers(); ptId++)
-    {
+  {
     if ( ptId % thread_count == thread_id )
-      {
+    {
       // Get starting step
       streamer = self->GetStreamers() + ptId;
       sPtr = streamer->GetStreamPoint(0);
       if ( sPtr->cellId < 0 )
-        {
+      {
         continue;
-        }
+      }
       // Set the last cell id in the vtkInterpolatedVelocityField
       // object to speed up FindCell calls
       func->SetLastCellId(sPtr->cellId);
@@ -321,22 +322,22 @@ VTK_THREAD_RETURN_TYPE vtkStreamer::ThreadedIntegrate( void *arg )
 
       //integrate until time has been exceeded
       while ( pt1.cellId >= 0 && pt1.speed > termspeed && pt1.t <  maxtime )
-        {
+      {
 
         if ( counter++ % 1000 == 0 )
-          {
+        {
           if (!thread_id)
-            {
+          {
             self->UpdateProgress(
               static_cast<double>(ptId)
               /static_cast<double>(self->GetNumberOfStreamers())
               +pt1.t/maxtime/static_cast<double>(self->GetNumberOfStreamers()));
-            }
-          if (self->GetAbortExecute())
-            {
-            break;
-            }
           }
+          if (self->GetAbortExecute())
+          {
+            break;
+          }
+        }
 
         // Set the integration step to be characteristic cell length
         // time IntegrationStepLength
@@ -347,30 +348,30 @@ VTK_THREAD_RETURN_TYPE vtkStreamer::ThreadedIntegrate( void *arg )
         // Calculate the next step using the integrator provided
         if (integrator->ComputeNextStep(pt1.x, pt1.v, xNext, 0, step, 0, err)
             != 0)
-          {
+        {
           break;
-          }
+        }
 
         for(i=0; i<3; i++)
-          {
+        {
           coords[i] = xNext[i];
-          }
+        }
 
         // Interpolate the velocity field at coords
         if ( !func->FunctionValues(coords, vel) )
-          {
+        {
           break;
-          }
+        }
 
         for(i=0; i<3; i++)
-          {
+        {
           pt2.v[i] = vel[i];
-          }
+        }
 
         for (i=0; i<3; i++)
-          {
+        {
           pt2.x[i] = xNext[i];
-          }
+        }
 
         pt2.cellId = func->GetLastCellId();
         func->GetLastWeights(w);
@@ -378,14 +379,14 @@ VTK_THREAD_RETURN_TYPE vtkStreamer::ThreadedIntegrate( void *arg )
         input->GetCell(pt2.cellId, cell);
 
         if ( inScalars )
-          {
+        {
           // Interpolate scalars
           inScalars->GetTuples(cell->PointIds, cellScalars);
           for (pt2.s=0.0, i=0; i < cell->GetNumberOfPoints(); i++)
-            {
+          {
             pt2.s += cellScalars->GetComponent(i,0) * w[i];
-            }
           }
+        }
 
         pt2.speed = vtkMath::Norm(pt2.v);
 
@@ -394,14 +395,14 @@ VTK_THREAD_RETURN_TYPE vtkStreamer::ThreadedIntegrate( void *arg )
         pt2.d = pt1.d + d;
         // If at stagnation region, stop the integration
         if ( d <= self->Epsilon || (pt1.speed + pt2.speed) <= self->Epsilon)
-          {
+        {
           pt2.t = pt1.t;
           break;
-          }
+        }
         pt2.t = pt1.t + (2.0 * d / (pt1.speed + pt2.speed));
 
         if (self->GetVorticity() && inVectors)
-          {
+        {
           // compute vorticity
           inVectors->GetTuples(cell->PointIds, cellVectors);
           cellVel = cellVectors->GetPointer(0);
@@ -413,48 +414,48 @@ VTK_THREAD_RETURN_TYPE vtkStreamer::ThreadedIntegrate( void *arg )
           pt2.omega = vtkMath::Dot(vort, pt2.v);
           pt2.omega /= pt2.speed;
           pt2.theta += (pt1.omega+pt2.omega)/2 * (pt2.t - pt1.t);
-          }
+        }
 
 
         // Store only points which have a point to be displayed
         // between them
         if (tOffset >= pt1.t && tOffset <= pt2.t)
-          {
+        {
           // Do not store if same as the last point.
           // To avoid storing some points twice.
           if ( !sNext || sNext->x[0] != pt1.x[0] || sNext->x[1] != pt1.x[1]
                || sNext->x[2] != pt1.x[2] )
-            {
+          {
             idxNext = streamer->InsertNextStreamPoint();
             sNext = streamer->GetStreamPoint(idxNext);
             *sNext = pt1;
-            }
+          }
           idxNext = streamer->InsertNextStreamPoint();
           sNext = streamer->GetStreamPoint(idxNext);
           *sNext = pt2;
-          }
+        }
         if (tOffset < pt2.t)
-          {
+        {
           tOffset += (static_cast<int>(
                         ( pt2.t - tOffset) / savePointInterval)
                       + 1) * savePointInterval;
-          }
+        }
         pt1 = pt2;
 
-        }
+      }
       // Store the last point anyway.
       if ( !sNext || sNext->x[0] != pt2.x[0] || sNext->x[1] != pt2.x[1]
            || sNext->x[2] != pt2.x[2] )
-        {
+      {
         idxNext = streamer->InsertNextStreamPoint();
         sNext = streamer->GetStreamPoint(idxNext);
         *sNext = pt2;
-        }
+      }
       // Clear the last cell to avoid starting a search from
       // the last point in the streamline
       func->ClearLastCellId();
-      }
     }
+  }
 
   integrator->Delete();
   func->Delete();
@@ -462,9 +463,9 @@ VTK_THREAD_RETURN_TYPE vtkStreamer::ThreadedIntegrate( void *arg )
   cell->Delete();
   cellVectors->Delete();
   if (cellScalars)
-    {
+  {
     cellScalars->Delete();
-    }
+  }
   delete[] w;
 
   return VTK_THREAD_RETURN_VALUE;
@@ -490,18 +491,15 @@ void vtkStreamer::Integrate(vtkDataSet *input, vtkDataSet *source)
   this->NumberOfStreamers = 0;
 
   // reexecuting - delete old stuff
-  if( this->Streamers )
-    {
-    delete [] this->Streamers;
-    }
+  delete [] this->Streamers;
   this->Streamers = NULL;
 
   if ( ! (inVectors=pd->GetVectors()) )
-    {
+  {
     delete [] w;
     vtkErrorMacro(<<"No vector data defined!");
     return;
-    }
+  }
 
   cellVectors = vtkDoubleArray::New();
   cellVectors->SetNumberOfComponents(3);
@@ -510,11 +508,11 @@ void vtkStreamer::Integrate(vtkDataSet *input, vtkDataSet *source)
   inScalars = pd->GetScalars();
 
   if (inScalars)
-    {
+  {
     cellScalars = inScalars->NewInstance();
     cellScalars->SetNumberOfComponents(inScalars->GetNumberOfComponents());
     cellScalars->Allocate(cellScalars->GetNumberOfComponents()*VTK_CELL_SIZE);
-    }
+  }
 
   tol2 = input->GetLength()/1000;
   tol2 = tol2*tol2;
@@ -524,57 +522,57 @@ void vtkStreamer::Integrate(vtkDataSet *input, vtkDataSet *source)
   //
   this->NumberOfStreamers = numSourcePts = offset = 1;
   if ( source )
-    {
+  {
     this->NumberOfStreamers = numSourcePts = source->GetNumberOfPoints();
-    }
+  }
 
   if ( this->IntegrationDirection == VTK_INTEGRATE_BOTH_DIRECTIONS )
-    {
+  {
     offset = 2;
     this->NumberOfStreamers *= 2;
-    }
+  }
 
   this->Streamers = new vtkStreamer::StreamArray[this->NumberOfStreamers];
 
   if ( this->StartFrom == VTK_START_FROM_POSITION && !source )
-    {
+  {
     idx = this->Streamers[0].InsertNextStreamPoint();
     sPtr = this->Streamers[0].GetStreamPoint(idx);
     sPtr->subId = 0;
     for (i=0; i<3; i++)
-      {
+    {
       sPtr->x[i] = this->StartPosition[i];
-      }
+    }
     sPtr->cellId = input->FindCell(this->StartPosition, NULL, -1, 0.0,
                                    sPtr->subId, sPtr->p, w);
-    }
+  }
 
   else if ( this->StartFrom == VTK_START_FROM_LOCATION && !source )
-    {
+  {
     idx = this->Streamers[0].InsertNextStreamPoint();
     sPtr = this->Streamers[0].GetStreamPoint(idx);
     sPtr->subId = 0;
     cell =  input->GetCell(sPtr->cellId);
     cell->EvaluateLocation(sPtr->subId, sPtr->p, sPtr->x, w);
-    }
+  }
 
   else //VTK_START_FROM_SOURCE
-    {
+  {
     for (ptId=0; ptId < numSourcePts; ptId++)
-      {
+    {
       idx = this->Streamers[offset*ptId].InsertNextStreamPoint();
       sPtr = this->Streamers[offset*ptId].GetStreamPoint(idx);
       sPtr->subId = 0;
       source->GetPoint(ptId,sPtr->x);
       sPtr->cellId = input->FindCell(sPtr->x, NULL, -1, tol2,
                                      sPtr->subId, sPtr->p, w);
-      }
     }
+  }
 
   // Finish initializing each streamer
   //
   for (idx=0, ptId=0; ptId < numSourcePts; ptId++)
-    {
+  {
     this->Streamers[offset*ptId].Direction = 1.0;
     sPtr = this->Streamers[offset*ptId].GetStreamPoint(idx);
     sPtr->d = 0.0;
@@ -584,25 +582,25 @@ void vtkStreamer::Integrate(vtkDataSet *input, vtkDataSet *source)
     sPtr->omega = 0.0;
 
     if ( sPtr->cellId >= 0 ) //starting point in dataset
-      {
+    {
       cell = input->GetCell(sPtr->cellId);
       cell->EvaluateLocation(sPtr->subId, sPtr->p, xNext, w);
 
       inVectors->GetTuples(cell->PointIds, cellVectors);
       sPtr->v[0]  = sPtr->v[1] = sPtr->v[2] = 0.0;
       for (i=0; i < cell->GetNumberOfPoints(); i++)
-        {
+      {
         cellVectors->GetTuple(i, v);
         for (j=0; j<3; j++)
-          {
+        {
           sPtr->v[j] += v[j] * w[i];
-          }
         }
+      }
 
       sPtr->speed = vtkMath::Norm(sPtr->v);
 
       if (this->GetVorticity() && inVectors)
-        {
+      {
           // compute vorticity
         inVectors->GetTuples(cell->PointIds, cellVectors);
         cellVel = cellVectors->GetPointer(0);
@@ -614,42 +612,42 @@ void vtkStreamer::Integrate(vtkDataSet *input, vtkDataSet *source)
         sPtr->omega = vtkMath::Dot(vort, sPtr->v);
         sPtr->omega /= sPtr->speed;
         sPtr->theta = 0;
-        }
+      }
 
       if ( inScalars )
-        {
+      {
         inScalars->GetTuples(cell->PointIds, cellScalars);
         for (sPtr->s=0, i=0; i < cell->GetNumberOfPoints(); i++)
-          {
+        {
           sPtr->s += cellScalars->GetComponent(i,0) * w[i];
-          }
         }
       }
+    }
     else
-      {
+    {
       for (j=0; j<3; j++)
-        {
+      {
         sPtr->p[j] = 0.0;
         sPtr->v[j] = 0.0;
-        }
-      sPtr->speed = 0;
       }
+      sPtr->speed = 0;
+    }
 
     if ( this->IntegrationDirection == VTK_INTEGRATE_BOTH_DIRECTIONS )
-      {
+    {
       this->Streamers[offset*ptId+1].Direction = -1.0;
       idxNext = this->Streamers[offset*ptId+1].InsertNextStreamPoint();
       sNext = this->Streamers[offset*ptId+1].GetStreamPoint(idxNext);
       sPtr = this->Streamers[offset*ptId].GetStreamPoint(idx);
       *sNext = *sPtr;
-      }
+    }
     else if ( this->IntegrationDirection == VTK_INTEGRATE_BACKWARD )
-      {
+    {
       this->Streamers[offset*ptId].Direction = -1.0;
-      }
+    }
 
 
-    } //for each streamer
+  } //for each streamer
 
   // Some data access methods must be called once from a single thread before they
   // can safely be used. Call those now
@@ -670,36 +668,36 @@ void vtkStreamer::Integrate(vtkDataSet *input, vtkDataSet *source)
   // Now create appropriate representation
   //
   if ( this->OrientationScalars && !this->SpeedScalars)
-    {
+  {
     for (ptId=0; ptId < this->NumberOfStreamers; ptId++)
-      {
+    {
       for ( sPtr=this->Streamers[ptId].GetStreamPoint(0), i=0;
             i < this->Streamers[ptId].GetNumberOfPoints() && sPtr->cellId >= 0;
             i++, sPtr=this->Streamers[ptId].GetStreamPoint(i) )
-        {
+      {
         sPtr->s = sPtr->theta;
-        }
       }
     }
+  }
 
   if ( this->SpeedScalars )
-    {
+  {
     for (ptId=0; ptId < this->NumberOfStreamers; ptId++)
-      {
+    {
       for ( sPtr=this->Streamers[ptId].GetStreamPoint(0), i=0;
             i < this->Streamers[ptId].GetNumberOfPoints() && sPtr->cellId >= 0;
             i++, sPtr=this->Streamers[ptId].GetStreamPoint(i) )
-        {
+      {
         sPtr->s = sPtr->speed;
-        }
       }
     }
+  }
   delete [] w;
   cellVectors->Delete();
   if (cellScalars)
-    {
+  {
     cellScalars->Delete();
-    }
+  }
 }
 
 int vtkStreamer::FillInputPortInformation(int port, vtkInformation *info)
@@ -707,9 +705,9 @@ int vtkStreamer::FillInputPortInformation(int port, vtkInformation *info)
   info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkDataSet");
 
   if (port == 1)
-    {
+  {
     info->Set(vtkAlgorithm::INPUT_IS_OPTIONAL(), 1);
-    }
+  }
   return 1;
 }
 
@@ -718,39 +716,39 @@ void vtkStreamer::PrintSelf(ostream& os, vtkIndent indent)
   this->Superclass::PrintSelf(os,indent);
 
   if ( this->StartFrom == VTK_START_FROM_POSITION && !this->GetSource())
-    {
+  {
     os << indent << "Starting Position: (" << this->StartPosition[0] << ","
        << this->StartPosition[1] << ", " << this->StartPosition[2] << ")\n";
-    }
+  }
   else if ( this->StartFrom == VTK_START_FROM_LOCATION && !this->GetSource())
-    {
+  {
     os << indent << "Starting Location:\n\tCell: " << this->StartCell
        << "\n\tSubId: " << this->StartSubId << "\n\tP.Coordinates: ("
        << this->StartPCoords[0] << ", "
        << this->StartPCoords[1] << ", "
        << this->StartPCoords[2] << ")\n";
-    }
+  }
   else
-    {
+  {
     os << indent << "Starting Source: "
        << static_cast<void *>(this->GetSource()) << "\n";
-    }
+  }
 
   os << indent << "Maximum Propagation Time: "
      << this->MaximumPropagationTime << "\n";
 
   if ( this->IntegrationDirection == VTK_INTEGRATE_FORWARD )
-    {
+  {
     os << indent << "Integration Direction: FORWARD\n";
-    }
+  }
   else if ( this->IntegrationDirection == VTK_INTEGRATE_BACKWARD )
-    {
+  {
     os << indent << "Integration Direction: BACKWARD\n";
-    }
+  }
   else
-    {
+  {
     os << indent << "Integration Direction: FORWARD & BACKWARD\n";
-    }
+  }
 
   os << indent << "Integration Step Length: " << this->IntegrationStepLength << "\n";
 
@@ -771,3 +769,5 @@ void vtkStreamer::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Number Of Threads: " << this->NumberOfThreads << "\n";
   os << indent << "Epsilon: " << this->Epsilon << "\n";
 }
+
+#endif // VTK_LEGACY_REMOVE
