@@ -12,13 +12,15 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
-// .NAME vtkSubdivideTetra - subdivide one tetrahedron into twelve for every tetra
-// .SECTION Description
-// This filter subdivides tetrahedra in an unstructured grid into twelve tetrahedra.
+/**
+ * @class   vtkSubdivideTetra
+ * @brief   subdivide one tetrahedron into twelve for every tetra
+ *
+ * This filter subdivides tetrahedra in an unstructured grid into twelve tetrahedra.
+*/
 
-
-#ifndef __vtkSubdivideTetra_h
-#define __vtkSubdivideTetra_h
+#ifndef vtkSubdivideTetra_h
+#define vtkSubdivideTetra_h
 
 #include "vtkFiltersModelingModule.h" // For export macro
 #include "vtkUnstructuredGridAlgorithm.h"
@@ -38,8 +40,8 @@ protected:
   int RequestData(vtkInformation *, vtkInformationVector **, vtkInformationVector *);
 
 private:
-  vtkSubdivideTetra(const vtkSubdivideTetra&);  // Not implemented.
-  void operator=(const vtkSubdivideTetra&);  // Not implemented.
+  vtkSubdivideTetra(const vtkSubdivideTetra&) VTK_DELETE_FUNCTION;
+  void operator=(const vtkSubdivideTetra&) VTK_DELETE_FUNCTION;
 };
 
 #endif
