@@ -1,5 +1,5 @@
-#ifndef __vtkExodusIIReaderPrivate_h
-#define __vtkExodusIIReaderPrivate_h
+#ifndef vtkExodusIIReaderPrivate_h
+#define vtkExodusIIReaderPrivate_h
 
 // Do not include this file directly. It is only for use
 // from inside the ExodusII reader and its descendants.
@@ -83,11 +83,6 @@ public:
     */
   int GetNumberOfTimeSteps() { return (int) this->Times.size(); }
 
-  /// Return the current time step
-  vtkGetMacro(TimeStep,int);
-
-  /// Set the current time step for subsequent calls to RequestData().
-  vtkSetMacro(TimeStep,int);
 
   /// Return whether subsequent RequestData() calls will produce the minimal
   /// point set required to represent the output.
@@ -349,6 +344,7 @@ public:
     BlockSetInfoType(){this->CachedConnectivity=0;}
     BlockSetInfoType(const BlockSetInfoType& block);
     ~BlockSetInfoType();
+    BlockSetInfoType& operator=(const BlockSetInfoType& block);
   };
 
   /// A struct to hold information about Exodus blocks
@@ -415,6 +411,15 @@ public:
   virtual void SetParser( vtkExodusIIReaderParser* );
   vtkGetObjectMacro(Parser,vtkExodusIIReaderParser);
 
+  // BUG #15632: This method allows vtkPExodusIIReader to pass time information
+  // from one spatial file to another and avoiding have to read it for each of
+  // the files.
+  void SetTimesOverrides(const std::vector<double>& times)
+  {
+    this->Times = times;
+    this->SkipUpdateTimeInformation = true;
+  }
+
   // Because Parts, Materials, and assemblies are not stored as arrays,
   // but rather as maps to the element blocks they make up,
   // we cannot use the Get|SetObject__() methods directly.
@@ -569,6 +574,14 @@ protected:
     */
   int AssembleArraysOverTime(vtkMultiBlockDataSet* output);
 
+  /// Insert polyhedral cells (called from InsertBlockCells when a block is polyhedra)
+  void InsertBlockPolyhedra(
+    BlockInfoType* binfo,
+    vtkIntArray* facesPerCell,
+    vtkIntArray* pointsPerFace,
+    vtkIntArray* exoCellConn,
+    vtkIntArray* exoFaceConn);
+
   /// Insert cells from a specified block into a mesh
   void InsertBlockCells(
     int otyp, int obj, int conn_type, int timeStep, BlockInfoType* binfop );
@@ -760,9 +773,7 @@ protected:
 
   /// A list of time steps for which results variables are stored.
   std::vector<double> Times;
-
-  /// The current time step
-  int TimeStep;
+  bool SkipUpdateTimeInformation;
 
   /** The time value. This is used internally when HasModeShapes is true and
     * ignored otherwise.
@@ -819,9 +830,9 @@ protected:
 
   vtkMutableDirectedGraph* SIL;
 private:
-  vtkExodusIIReaderPrivate( const vtkExodusIIReaderPrivate& ); // Not implemented.
-  void operator = ( const vtkExodusIIReaderPrivate& ); // Not implemented.
+  vtkExodusIIReaderPrivate( const vtkExodusIIReaderPrivate& ) VTK_DELETE_FUNCTION;
+  void operator = ( const vtkExodusIIReaderPrivate& ) VTK_DELETE_FUNCTION;
 };
 
-#endif // __vtkExodusIIReaderPrivate_h
+#endif // vtkExodusIIReaderPrivate_h
 // VTK-HeaderTest-Exclude: vtkExodusIIReaderPrivate.h
