@@ -64,12 +64,12 @@ POSSIBILITY OF SUCH DAMAGES.
 #include "vtkMINC.h"
 #include "vtk_netcdf.h"
 
-#include <stdlib.h>
-#include <ctype.h>
-#include <float.h>
+#include <cstdlib>
+#include <cctype>
+#include <cfloat>
 #include <string>
 #include <map>
-#include <vtksys/ios/sstream>
+#include <sstream>
 
 //-------------------------------------------------------------------------
 // A container for mapping attribute names to arrays
@@ -161,45 +161,45 @@ vtkMINCImageAttributes::~vtkMINCImageAttributes()
   this->SetName(0);
 
   if (this->DimensionNames)
-    {
+  {
     this->DimensionNames->Delete();
     this->DimensionNames = 0;
-    }
+  }
   if (this->DimensionLengths)
-    {
+  {
     this->DimensionLengths->Delete();
     this->DimensionLengths = 0;
-    }
+  }
   if (this->VariableNames)
-    {
+  {
     this->VariableNames->Delete();
     this->VariableNames = 0;
-    }
+  }
   if (this->AttributeNames)
-    {
+  {
     this->AttributeNames->Delete();
     this->AttributeNames = 0;
-    }
+  }
   if (this->AttributeValues)
-    {
+  {
     this->AttributeValues->Delete();
     this->AttributeValues = 0;
-    }
+  }
   if (this->ImageMin)
-    {
+  {
     this->ImageMin->Delete();
     this->ImageMin = 0;
-    }
+  }
   if (this->ImageMax)
-    {
+  {
     this->ImageMax->Delete();
     this->ImageMax = 0;
-    }
+  }
   if (this->StringStore)
-    {
+  {
     this->StringStore->Delete();
     this->StringStore = 0;
-    }
+  }
 }
 
 //-------------------------------------------------------------------------
@@ -234,9 +234,9 @@ void vtkMINCImageAttributes::Reset()
   this->DimensionNames->Reset();
   this->DimensionLengths->Reset();
   if (this->StringStore)
-    {
+  {
     this->StringStore->Reset();
-    }
+  }
   this->NumberOfImageMinMaxDimensions = 0;
 
   // Add global attribute name array
@@ -259,31 +259,31 @@ void vtkMINCImageAttributes::AddDimension(const char *dimension,
                                           vtkIdType length)
 {
   // Check for duplicates
-  int n = this->DimensionNames->GetNumberOfValues();
-  for (int i = 0; i < n; i++)
-    {
+  vtkIdType n = this->DimensionNames->GetNumberOfValues();
+  for (vtkIdType i = 0; i < n; i++)
+  {
     if (strcmp(dimension, this->DimensionNames->GetValue(i)) == 0)
-      {
+    {
       vtkErrorMacro("The dimension " << dimension <<
                     " has already been created.");
       return;
-      }
     }
+  }
 
   // Ensure the dimension name is valid
   const char **tryname = 0;
   for (tryname = vtkMINCDimVarNames; *tryname != 0; tryname++)
-    {
+  {
     if (strcmp(dimension, *tryname) == 0)
-      {
-      break;
-      }
-    }
-  if (*tryname == 0 && strcmp(dimension, MIvector_dimension) != 0)
     {
+      break;
+    }
+  }
+  if (*tryname == 0 && strcmp(dimension, MIvector_dimension) != 0)
+  {
     vtkWarningMacro("The dimension name " << dimension <<
                     " is not recognized.");
-    }
+  }
 
   this->DimensionNames->InsertNextValue(dimension);
   this->DimensionLengths->InsertNextTuple1(length);
@@ -294,82 +294,100 @@ void vtkMINCImageAttributes::AddDimension(const char *dimension,
 const char *vtkMINCImageAttributes::ConvertDataArrayToString(
   vtkDataArray *array)
 {
+  const char *result = "";
+  vtkIdType n = array->GetNumberOfTuples();
+  if (n == 0)
+  {
+    return result;
+  }
+
   int dataType = array->GetDataType();
-
   if (dataType == VTK_CHAR)
+  {
+    vtkCharArray *charArray = vtkArrayDownCast<vtkCharArray>(array);
+    if (charArray)
     {
-    vtkCharArray *charArray = vtkCharArray::SafeDownCast(array);
-    return charArray->GetPointer(0);
+      result = charArray->GetPointer(0);
+      // Check to see if string has a terminal null (the null might be
+      // part of the attribute, or stored in the following byte)
+      if ((n > 0 && result[n-1] == '\0') ||
+          (charArray->GetSize() > n && result[n] == '\0'))
+      {
+        return result;
+      }
     }
+  }
 
-  vtksys_ios::ostringstream os;
+  std::ostringstream os;
 
-  int n = array->GetNumberOfTuples();
-  int i = 0;
-  for (i = 0; i < n; i++)
-    {
+  for (vtkIdType i = 0; i < n; i++)
+  {
     double val = array->GetComponent(i, 0);
     if (dataType == VTK_DOUBLE || dataType == VTK_FLOAT)
-      {
+    {
       // Use NetCDF's usual precision for printing the values
       char storage[128];
       if (dataType == VTK_DOUBLE)
-        {
-        sprintf(storage, "%0.15g", val);
-        }
+      {
+        snprintf(storage, 128, "%0.15g", val);
+      }
       else
-        {
-        sprintf(storage, "%0.7g", val);
-        }
+      {
+        snprintf(storage, 128, "%0.7g", val);
+      }
       // Add a decimal if there isn't one, to distinguish from int
       for (char *cp = storage; *cp != '.'; cp++)
-        {
+      {
         if (*cp == '\0')
-          {
+        {
           *cp++ = '.';
           *cp = '\0';
           break;
-          }
         }
+      }
       os << storage;
-      }
-    else
-      {
-      os << val;
-      }
-    if (i < n-1)
-      {
-      os << ", ";
-      }
     }
+    else if (dataType == VTK_CHAR)
+    {
+      os.put(static_cast<char>(val));
+    }
+    else
+    {
+      os << val;
+    }
+    if (i < n-1 && dataType != VTK_CHAR)
+    {
+      os << ", ";
+    }
+  }
 
-    // Store the string
-    std::string str = os.str();
-    const char *result = 0;
+  // Store the string
+  std::string str = os.str();
 
-    if (this->StringStore == 0)
-      {
-      this->StringStore = vtkStringArray::New();
-      }
+  if (this->StringStore == 0)
+  {
+    this->StringStore = vtkStringArray::New();
+  }
 
-    // See if the string is already stored
-    n = this->StringStore->GetNumberOfValues();
-    for (i = 0; i < n; i++)
-      {
-      result = this->StringStore->GetValue(i);
-      if (strcmp(str.c_str(), result) == 0)
-        {
-        break;
-        }
-      }
-    // If not, add it to the array.
-    if (i == n)
-      {
-      i = this->StringStore->InsertNextValue(str.c_str());
-      result = this->StringStore->GetValue(i);
-      }
+  // See if the string is already stored
+  vtkIdType m = this->StringStore->GetNumberOfValues();
+  vtkIdType j;
+  for (j = 0; j < m; j++)
+  {
+    result = this->StringStore->GetValue(j);
+    if (strcmp(str.c_str(), result) == 0)
+    {
+      break;
+    }
+  }
+  // If not, add it to the array.
+  if (j == m)
+  {
+    j = this->StringStore->InsertNextValue(str.c_str());
+    result = this->StringStore->GetValue(j);
+  }
 
-    return result;
+  return result;
 }
 
 //-------------------------------------------------------------------------
@@ -383,14 +401,14 @@ void vtkMINCImageAttributes::PrintFileHeader(ostream &os)
 {
   const char *name = "unknown";
   if (this->Name)
-    {
+  {
     name = this->Name;
-    }
+  }
 
   // Get the data type
   const char *imageDataType;
   switch (this->DataType)
-    {
+  {
     case VTK_CHAR:
     case VTK_SIGNED_CHAR:
     case VTK_UNSIGNED_CHAR:
@@ -412,118 +430,120 @@ void vtkMINCImageAttributes::PrintFileHeader(ostream &os)
       break;
     default:
       imageDataType = "void";
-    }
+  }
 
   os << "netcdf " << name << " {\n";
   os << "dimensions:\n";
 
-  int ndim = 0;
+  vtkIdType ndim = 0;
   if (this->DimensionNames)
-    {
+  {
     ndim = this->DimensionNames->GetNumberOfValues();
-    }
-  for (int idim = 0; idim < ndim; idim++)
-    {
+  }
+  for (vtkIdType idim = 0; idim < ndim; idim++)
+  {
     os << "\t" << this->DimensionNames->GetValue(idim) << " = "
        << this->DimensionLengths->GetValue(idim) << " ;\n";
-    }
+  }
 
   os << "variables:\n";
 
-  int nvar = 0;
-  int ivar = 0;
+  vtkIdType nvar = 0;
+  vtkIdType ivar = 0;
   if (this->VariableNames)
-    {
+  {
     nvar = this->VariableNames->GetNumberOfValues();
-    }
+  }
   for (ivar = 0; ivar < nvar+1; ivar++)
-    {
+  {
     const char *varname = MI_EMPTY_STRING;
     if (ivar == nvar)
-      {
+    {
       os << "\n// global attributes:\n";
-      }
+    }
     else
-      {
+    {
       varname = this->VariableNames->GetValue(ivar);
       if (strcmp(varname, MIimage) == 0 ||
           strcmp(varname, MIimagemax) == 0 ||
           strcmp(varname, MIimagemin) == 0)
-        {
-        os << "\t" << imageDataType << " " << varname;
-        int nvardim = this->DimensionNames->GetNumberOfValues();
+      {
+        vtkIdType nvardim = this->DimensionNames->GetNumberOfValues();
         // If this is image-min or image-max, only print the
         // dimensions for these variables
         if (varname[5] == '-')
-          {
+        {
           if (this->NumberOfImageMinMaxDimensions < nvardim)
-            {
+          {
             nvardim = this->NumberOfImageMinMaxDimensions;
-            }
           }
+          os << "\tdouble " << varname;
+        }
+        else
+        {
+          os << "\t" << imageDataType << " " << varname;
+        }
 
         if (nvardim > 0)
-          {
+        {
           os << "(";
           for (int ivardim = 0; ivardim < nvardim; ivardim++)
-            {
+          {
             os << this->DimensionNames->GetValue(ivardim);
             if (ivardim < nvardim - 1)
-              {
+            {
               os << ", ";
-              }
             }
-          os << ")";
           }
+          os << ")";
+        }
         os << " ;\n";
-        }
-      else
-        {
-        os << "\t" << "int " << varname << " ;\n";
-        }
       }
+      else
+      {
+        os << "\t" << "int " << varname << " ;\n";
+      }
+    }
     vtkStringArray *attArray =
       this->AttributeNames->GetStringArray(varname);
     if (attArray)
+    {
+      vtkIdType natt = attArray->GetNumberOfValues();
+      for (vtkIdType iatt = 0; iatt < natt; iatt++)
       {
-      int natt = attArray->GetNumberOfValues();
-      for (int iatt = 0; iatt < natt; iatt++)
-        {
         const char *attname = attArray->GetValue(iatt);
         vtkDataArray *array =
           this->GetAttributeValueAsArray(varname, attname);
         os << "\t\t" << varname << ":" << attname << " = ";
         if (array->GetDataType() == VTK_CHAR)
-          {
-          vtkCharArray *charArray =
-            vtkCharArray::SafeDownCast(array);
+        {
           os << "\"";
-          const char *cp = charArray->GetPointer(0);
-          const char *endcp = cp + charArray->GetNumberOfTuples();
+          const char *cp = this->ConvertDataArrayToString(array);
+          const char *endcp = cp + strlen(cp);
           char text[512];
           text[0] = '\0';
           while (cp < endcp)
-            {
+          {
             int c = 0;
             int j;
             for (j = 0; j < 508 && cp < endcp; j++, cp++)
-              {
+            {
               c = *cp;
               if (c == '\0' && (cp + 1) == endcp)
-                {
+              {
                 // break if at terminal null
                 cp++;
                 break;
-                }
+              }
               if (isprint(c) && c != '\\')
-                {
+              {
                 text[j] = c;
-                }
+              }
               else
-                {
+              {
                 // quote the non-printing characters
                 switch (c)
-                  {
+                {
                   case '\\':
                     text[j++] = '\\';
                     text[j] = '\\';
@@ -562,15 +582,15 @@ void vtkMINCImageAttributes::PrintFileHeader(ostream &os)
                     text[j++] = '0' + ((c & 0x38) >> 3);
                     text[j] = '0' + (c & 0x7);
                     break;
-                  }
                 }
+              }
               if (c == '\n')
-                {
+              {
                 j++;
                 cp++;
                 break;
-                }
               }
+            }
 
             text[j] = '\0';
             os << text;
@@ -579,65 +599,65 @@ void vtkMINCImageAttributes::PrintFileHeader(ostream &os)
             // Start a new string after each newline, unless this
             // newline is the final character.
             if (c == '\n' && cp < endcp)
-              {
+            {
               os << "\",\n\t\t\t\"";
-              }
             }
-          os << "\" ;\n";
           }
+          os << "\" ;\n";
+        }
         else
-          {
+        {
           // Use handy conversion method
           os << this->ConvertDataArrayToString(array) << " ;\n";
-          }
         }
       }
     }
+  }
 
   os << "data:\n";
 
   if (this->VariableNames)
-    {
+  {
     nvar = this->VariableNames->GetNumberOfValues();
-    }
+  }
   for (ivar = 0; ivar < nvar; ivar++)
-    {
+  {
     const char *varname = this->VariableNames->GetValue(ivar);
 
     if (strcmp(varname, MIimage) == 0)
-      {
+    {
       continue;
-      }
+    }
 
     os << "\n " << varname << " = ";
 
     if (strcmp(varname, MIimagemin) == 0)
-      {
+    {
       if (this->ImageMin)
-        {
+      {
         os << this->ConvertDataArrayToString(this->ImageMin) << " ;\n";
-        }
+      }
       else
-        {
+      {
         os << "0. ;\n";
-        }
-      }
-    else if (strcmp(varname, MIimagemax) == 0)
-      {
-      if (this->ImageMax)
-        {
-        os << this->ConvertDataArrayToString(this->ImageMax) << " ;\n";
-        }
-      else
-        {
-        os << "1. ;\n";
-        }
-      }
-    else
-      {
-      os << "_ ;\n";
       }
     }
+    else if (strcmp(varname, MIimagemax) == 0)
+    {
+      if (this->ImageMax)
+      {
+        os << this->ConvertDataArrayToString(this->ImageMax) << " ;\n";
+      }
+      else
+      {
+        os << "1. ;\n";
+      }
+    }
+    else
+    {
+      os << "_ ;\n";
+    }
+  }
 
   os << "}\n";
 }
@@ -648,9 +668,9 @@ vtkStringArray *vtkMINCImageAttributes::GetAttributeNames(
 {
   // If variable is null, use empty string to get global attributes
   if (variable == 0)
-    {
+  {
     variable = MI_EMPTY_STRING;
-    }
+  }
 
   return this->AttributeNames->GetStringArray(variable);
 }
@@ -670,10 +690,10 @@ vtkDataArray *vtkMINCImageAttributes::GetAttributeValueAsArray(
 {
   std::string path = MI_GRPNAME;
   if (variable && variable[0] != '\0')
-    {
+  {
     path += MI_GRP_SEP;
     path += variable;
-    }
+  }
   path += MI_ATT_SEP;
   path += attribute;
 
@@ -690,11 +710,11 @@ const char *vtkMINCImageAttributes::GetAttributeValueAsString(
 
   // Return NULL if not found
   if (array == 0)
-    {
+  {
     return 0;
-    }
+  }
 
-  // Convert any other array to a a string.
+  // Convert any other array to a string.
   return this->ConvertDataArrayToString(array);
 }
 
@@ -706,37 +726,36 @@ int vtkMINCImageAttributes::GetAttributeValueAsInt(
   vtkDataArray *array = this->GetAttributeValueAsArray(variable, attribute);
 
   if (array == 0)
-    {
+  {
     vtkErrorMacro("The attribute " << variable << ":"
                   << attribute << " was not found.");
     return 0;
-    }
+  }
 
   if (array->GetDataType() == VTK_CHAR)
-    {
-    char *text = vtkCharArray::SafeDownCast(array)->GetPointer(0);
-    char *endp = text;
+  {
+    const char *text = this->ConvertDataArrayToString(array);
+    char *endp = const_cast<char *>(text);
     long result = strtol(text, &endp, 10);
     // Check for complete conversion
     if (*endp == '\0' && *text != '\0')
-      {
-      return static_cast<int>(result);
-      }
-    }
-  else if (array->GetNumberOfTuples() == 1)
     {
+      return static_cast<int>(result);
+    }
+  }
+  else if (array->GetNumberOfTuples() == 1)
+  {
     switch(array->GetDataType())
-      {
+    {
       case VTK_SIGNED_CHAR:
       case VTK_UNSIGNED_CHAR:
       case VTK_SHORT:
       case VTK_INT:
         return static_cast<int>(array->GetComponent(0,0));
-        break;
       default:
         break;
-      }
     }
+  }
 
   vtkErrorMacro("GetAttributeValueAsInt() used on non-integer attribute "
                 << variable << ":" << attribute <<".");
@@ -749,34 +768,34 @@ double vtkMINCImageAttributes::GetAttributeValueAsDouble(
   const char *attribute)
 {
   if (variable == 0)
-    {
+  {
     variable = MI_EMPTY_STRING;
-    }
+  }
 
   vtkDataArray *array = this->GetAttributeValueAsArray(variable, attribute);
 
   if (array == 0)
-    {
+  {
     vtkErrorMacro("The attribute " << variable << ":"
                   << attribute << " was not found.");
     return 0;
-    }
+  }
 
   if (array->GetDataType() == VTK_CHAR)
-    {
-    char *text = vtkCharArray::SafeDownCast(array)->GetPointer(0);
-    char *endp = text;
+  {
+    const char *text = this->ConvertDataArrayToString(array);
+    char *endp = const_cast<char *>(text);
     double result = strtod(text, &endp);
     // Check for complete conversion
     if (*endp == '\0' && *text != '\0')
-      {
-      return result;
-      }
-    }
-  else if (array->GetNumberOfTuples() == 1)
     {
+      return result;
+    }
+  }
+  else if (array->GetNumberOfTuples() == 1)
+  {
     switch(array->GetDataType())
-      {
+    {
       case VTK_SIGNED_CHAR:
       case VTK_UNSIGNED_CHAR:
       case VTK_SHORT:
@@ -784,11 +803,10 @@ double vtkMINCImageAttributes::GetAttributeValueAsDouble(
       case VTK_FLOAT:
       case VTK_DOUBLE:
         return array->GetComponent(0,0);
-        break;
       default:
         break;
-      }
     }
+  }
 
   vtkErrorMacro("GetAttributeValueAsDouble() used on non-real attribute "
                 << variable << ":" << attribute <<".");
@@ -803,10 +821,10 @@ void vtkMINCImageAttributes::SetAttributeValueAsArray(
 {
   std::string path = MI_GRPNAME;
   if (variable && variable[0] != '\0')
-    {
+  {
     path += MI_GRP_SEP;
     path += variable;
-    }
+  }
   path += MI_ATT_SEP;
   path += attribute;
 
@@ -814,55 +832,55 @@ void vtkMINCImageAttributes::SetAttributeValueAsArray(
   this->AttributeValues->AddArray(array);
 
   // Add to variable to VariableNames
-  int n = this->VariableNames->GetNumberOfValues();
-  int i = 0;
+  vtkIdType n = this->VariableNames->GetNumberOfValues();
+  vtkIdType i = 0;
   for (i = 0; i < n; i++)
-    {
+  {
     if (strcmp(this->VariableNames->GetValue(i), variable) == 0)
-      {
-      break;
-      }
-    }
-  if (i == n && variable[0] != '\0')
     {
-    this->VariableNames->InsertNextValue(variable);
+      break;
     }
+  }
+  if (i == n && variable[0] != '\0')
+  {
+    this->VariableNames->InsertNextValue(variable);
+  }
 
   // Add to attribute to AttributeNames
   vtkStringArray *attribs = this->AttributeNames->GetStringArray(variable);
   // Create a new array if necessary
   if (attribs == 0)
-    {
+  {
     attribs = vtkStringArray::New();
     attribs->SetName(variable);
     this->AttributeNames->AddArray(attribs);
     attribs->Delete();
-    }
+  }
 
   n = attribs->GetNumberOfValues();
   for (i = 0; i < n; i++)
-    {
+  {
     if (strcmp(attribs->GetValue(i), attribute) == 0)
-      {
-      break;
-      }
-    }
-  if (i == n)
     {
-    attribs->InsertNextValue(attribute);
+      break;
     }
+  }
+  if (i == n)
+  {
+    attribs->InsertNextValue(attribute);
+  }
 
   if (this->ValidateAttributes)
-    {
+  {
     // Print warning if there is something wrong with the attribute
     int result = this->ValidateAttribute(variable, attribute, array);
 
     if (result > 1)
-      {
+    {
       vtkWarningMacro("Attribute " << variable << ":" << attribute
                       << " is not a valid attribute.");
-      }
     }
+  }
 }
 
 //-------------------------------------------------------------------------
@@ -871,12 +889,14 @@ void vtkMINCImageAttributes::SetAttributeValueAsString(
   const char *attribute,
   const char *value)
 {
-  size_t length = strlen(value)+1;
+  size_t length = strlen(value);
 
   vtkCharArray *array = vtkCharArray::New();
-  array->SetNumberOfValues(length);
-  strcpy(array->GetPointer(0), value);
-
+  // Allocate an extra byte to store a null terminator.
+  array->Resize(length + 1);
+  char *dest = array->WritePointer(0, length);
+  strncpy(dest, value, length);
+  dest[length] = '\0';
   this->SetAttributeValueAsArray(variable, attribute, array);
 
   array->Delete();
@@ -933,21 +953,21 @@ int vtkMINCImageAttributes::ValidateGlobalAttribute(
 
   int itry = 0;
   for (itry = 0; globalAttributes[itry] != 0; itry++)
-    {
+  {
     if (strcmp(attname, globalAttributes[itry]) == 0)
-      {
-      break;
-      }
-    }
-  if (itry < autoGlobalAttributes)
     {
+      break;
+    }
+  }
+  if (itry < autoGlobalAttributes)
+  {
     // Skip to the next attribute
     return 0;
-    }
+  }
   else if (globalAttributes[itry] == 0)
-    {
+  {
     return 2;
-    }
+  }
 
   return 1;
 }
@@ -973,31 +993,31 @@ int vtkMINCImageAttributes::ValidateGeneralAttribute(
   // Check to see if the attribute is one that we automatically generate.
   int itry = 0;
   for (itry = 0; generalAttributes[itry] != 0; itry++)
-    {
+  {
     if (strcmp(attname, generalAttributes[itry]) == 0)
-      {
-      break;
-      }
-    }
-  if (itry < autoGeneralAttributes)
     {
+      break;
+    }
+  }
+  if (itry < autoGeneralAttributes)
+  {
     // Skip to the next attribute
     return 0;
-    }
+  }
   else if (generalAttributes[itry] != 0)
-    {
+  {
     if (dataType != VTK_CHAR)
-      {
+    {
       vtkWarningMacro("The attribute " << varname << ":"
                       << attname << " has the wrong type ("
                       << dataType << ").");
       return 0;
-      }
     }
+  }
   else
-    {
+  {
     return 2;
-    }
+  }
 
   return 1;
 }
@@ -1025,51 +1045,51 @@ int vtkMINCImageAttributes::ValidateDimensionAttribute(
 
   int itry = 0;
   for (itry = 0; dimensionAttributes[itry] != 0; itry++)
-    {
+  {
     if (strcmp(attname, dimensionAttributes[itry]) == 0)
-      {
-      break;
-      }
-    }
-  if (itry < autoDimensionAttributes)
     {
+      break;
+    }
+  }
+  if (itry < autoDimensionAttributes)
+  {
     // Skip to the next attribute
     return 0;
-    }
+  }
   else if (strcmp(attname, MIdirection_cosines) == 0)
-    {
+  {
     if (varname[0] == 'x' || varname[0] == 'y' || varname[0] == 'z')
-      {
+    {
       if (dataType != VTK_DOUBLE || size != 3)
-        {
+      {
         vtkWarningMacro("The attribute " << varname << ":"
                         << attname << " has the wrong type ("
                         << dataType << ") or size ("
                         << size << ").");
         return 0;
-        }
       }
+    }
     else
-      {
+    {
       vtkWarningMacro("Dimension " << varname << " cannot have"
                       " a direction_cosines attribute");
       return 0;
-      }
     }
+  }
   else if (dimensionAttributes[itry] != 0)
-    {
+  {
     if (dataType != VTK_CHAR)
-      {
+    {
       vtkWarningMacro("The attribute " << varname << ":"
                       << attname << " has the wrong type ("
                       << dataType << ").");
       return 0;
-      }
     }
+  }
   else
-    {
+  {
     return 2;
-    }
+  }
 
   return 1;
 }
@@ -1092,21 +1112,21 @@ int vtkMINCImageAttributes::ValidateImageAttribute(
 
   int itry = 0;
   for (itry = 0; imageAttributes[itry] != 0; itry++)
-    {
+  {
     if (strcmp(attname, imageAttributes[itry]) == 0)
-      {
-      break;
-      }
-    }
-  if (itry < autoImageAttributes)
     {
+      break;
+    }
+  }
+  if (itry < autoImageAttributes)
+  {
     // Skip to the next attribute
     return 0;
-    }
+  }
   else if (imageAttributes[itry] == 0)
-    {
+  {
     return 2;
-    }
+  }
 
   return 1;
 }
@@ -1125,32 +1145,32 @@ int vtkMINCImageAttributes::ValidateImageMinMaxAttribute(
 
   int itry = 0;
   for (itry = 0; imageMinMaxAttributes[itry] != 0; itry++)
-    {
+  {
     if (strcmp(attname, imageMinMaxAttributes[itry]) == 0)
-      {
-      break;
-      }
-    }
-  if (itry < autoImageMinMaxAttributes)
     {
+      break;
+    }
+  }
+  if (itry < autoImageMinMaxAttributes)
+  {
     // Skip to the next attribute
     return 0;
-    }
+  }
   else if (imageMinMaxAttributes[itry] != 0)
-    {
+  {
     int dataType = array->GetDataType();
     if (dataType != VTK_CHAR)
-      {
+    {
       vtkWarningMacro("The attribute " << varname << ":"
                       << attname << " has the wrong type ("
                       << dataType << ").");
       return 0;
-      }
     }
+  }
   else
-    {
+  {
     return 2;
-    }
+  }
 
   return 1;
 }
@@ -1178,20 +1198,20 @@ int vtkMINCImageAttributes::ValidatePatientAttribute(
 
   int itry = 0;
   for (itry = 0; patientAttributes[itry] != 0; itry++)
-    {
+  {
     if (strcmp(attname, patientAttributes[itry]) == 0)
-      {
+    {
       break;
-      }
     }
+  }
   if (patientAttributes[itry] != 0)
-    {
+  {
     // Add checks for correct data type?
-    }
+  }
   else
-    {
+  {
     return 2;
-    }
+  }
 
   return 1;
 }
@@ -1229,20 +1249,20 @@ int vtkMINCImageAttributes::ValidateStudyAttribute(
 
   int itry = 0;
   for (itry = 0; studyAttributes[itry] != 0; itry++)
-    {
+  {
     if (strcmp(attname, studyAttributes[itry]) == 0)
-      {
+    {
       break;
-      }
     }
+  }
   if (studyAttributes[itry] != 0)
-    {
+  {
     // Add checks for correct data type?
-    }
+  }
   else
-    {
+  {
     return 2;
-    }
+  }
 
   return 1;
 }
@@ -1283,20 +1303,20 @@ int vtkMINCImageAttributes::ValidateAcquisitionAttribute(
 
   int itry = 0;
   for (itry = 0; acquisitionAttributes[itry] != 0; itry++)
-    {
+  {
     if (strcmp(attname, acquisitionAttributes[itry]) == 0)
-      {
+    {
       break;
-      }
     }
+  }
   if (acquisitionAttributes[itry] != 0)
-    {
+  {
     // Add checks for correct data type?
-    }
+  }
   else
-    {
+  {
     return 2;
-    }
+  }
 
   return 1;
 }
@@ -1317,65 +1337,65 @@ int vtkMINCImageAttributes::ValidateAttribute(
 
   const char **tryname = 0;
   for (tryname = stdVarNames; *tryname != 0; tryname++)
-    {
+  {
     if (strcmp(varname, *tryname) == 0)
-      {
+    {
       vartype = 1;
       break;
-      }
     }
+  }
   for (tryname = vtkMINCDimVarNames; *tryname != 0; tryname++)
-    {
+  {
     if (strcmp(varname, *tryname) == 0)
-      {
+    {
       vartype = 2;
       break;
-      }
     }
+  }
 
   if (strcmp(varname, MI_EMPTY_STRING) == 0)
-    {
+  {
     // Check global attributes
     result = this->ValidateGlobalAttribute(attname, array);
     // Allow users to create their own global attributes
     if (result == 2)
-      {
-      result = 1;
-      }
-    }
-  else if (vartype != 0)
     {
+      result = 1;
+    }
+  }
+  else if (vartype != 0)
+  {
     // Check general attributes
     result = this->ValidateGeneralAttribute(varname, attname, array);
-    }
+  }
   if (result == 2)
-    {
+  {
     if (vartype == 2)
-      {
+    {
       result = this->ValidateDimensionAttribute(varname, attname, array);
-      }
+    }
     else if (strcmp(varname, MIimage) == 0)
-      {
+    {
       result = this->ValidateImageAttribute(varname, attname, array);
-      }
+    }
     else if (strcmp(varname, MIimagemin) == 0 ||
              strcmp(varname, MIimagemax) == 0)
-      {
+    {
       result = this->ValidateImageMinMaxAttribute(varname, attname, array);
-      }
-    else if (strcmp(varname, MIpatient) == 0)
-      {
-      result = this->ValidatePatientAttribute(varname, attname, array);
-      }
-    else if (strcmp(varname, MIstudy) == 0)
-      {
-      result = this->ValidateStudyAttribute(varname, attname, array);
-      }
-    else if (strcmp(varname, MIacquisition) == 0)
-      {
-      result = this->ValidateAcquisitionAttribute(varname, attname, array);
-      }
     }
+    else if (strcmp(varname, MIpatient) == 0)
+    {
+      result = this->ValidatePatientAttribute(varname, attname, array);
+    }
+    else if (strcmp(varname, MIstudy) == 0)
+    {
+      result = this->ValidateStudyAttribute(varname, attname, array);
+    }
+    else if (strcmp(varname, MIacquisition) == 0)
+    {
+      result = this->ValidateAcquisitionAttribute(varname, attname, array);
+    }
+  }
 
   return result;
 }
@@ -1392,28 +1412,28 @@ void vtkMINCImageAttributes::FindValidRange(double range[2])
     vtkDoubleArray::SafeDownCast(this->GetAttributeValueAsArray(
                                    MIimage, MIvalid_range));
   if (rangearray)
-    {
+  {
     range[0] = rangearray->GetValue(0);
     range[1] = rangearray->GetValue(1);
     if (range[0] > range[1])
-      {
+    {
       double tmpval = range[0];
       range[0] = range[1];
       range[1] = tmpval;
-      }
+    }
 
     if (this->DataType == VTK_FLOAT)
-      {
-      // use float precision if VTK_FLOAT
-      range[0] = (float)range[0];
-      range[1] = (float)range[1];
-      }
-    }
-  else
     {
+      // use float precision if VTK_FLOAT
+      range[0] = static_cast<float>(range[0]);
+      range[1] = static_cast<float>(range[1]);
+    }
+  }
+  else
+  {
     // If there is no valid_range attribute, use maximum range.
     switch (this->DataType)
-      {
+    {
       case VTK_CHAR:
       case VTK_SIGNED_CHAR:
         range[0] = VTK_SIGNED_CHAR_MIN;
@@ -1447,27 +1467,27 @@ void vtkMINCImageAttributes::FindValidRange(double range[2])
         range[0] = -DBL_MAX;
         range[1] = DBL_MAX;
         break;
-      }
     }
+  }
 
   // If the valid_range is set to the full float range, replace
   // with the image range.
   if ((this->DataType == VTK_FLOAT && range[1] == FLT_MAX) ||
       (this->DataType == VTK_DOUBLE && range[1] == DBL_MAX))
-    {
+  {
     if (this->ImageMin && this->ImageMax &&
         this->ImageMin->GetNumberOfTuples() > 0 &&
         this->ImageMax->GetNumberOfTuples() > 0)
-      {
+    {
       range[0] = this->ImageMin->GetRange()[0];
       range[1] = this->ImageMax->GetRange()[1];
-      }
+    }
     else
-      {
+    {
       range[0] = 0.0;
       range[1] = 1.0;
-      }
     }
+  }
 }
 
 //-------------------------------------------------------------------------
@@ -1482,14 +1502,14 @@ void vtkMINCImageAttributes::FindImageRange(double range[2])
   if (this->ImageMin && this->ImageMax &&
       this->ImageMin->GetNumberOfTuples() > 0 &&
       this->ImageMax->GetNumberOfTuples() > 0)
-    {
+  {
     range[0] = this->ImageMin->GetRange()[0];
     range[1] = this->ImageMax->GetRange()[1];
-    }
+  }
   else
-    {
+  {
     this->FindValidRange(range);
-    }
+  }
 }
 
 //-------------------------------------------------------------------------
@@ -1511,28 +1531,27 @@ void vtkMINCImageAttributes::ShallowCopy(vtkMINCImageAttributes *source)
   this->AttributeNames->Clear();
 
   vtkStringArray *varnames = source->GetVariableNames();
-  int nvar = varnames->GetNumberOfValues();
-  for (int ivar = 0; ivar <= nvar; ivar++)
-    {
+  vtkIdType nvar = varnames->GetNumberOfValues();
+  for (vtkIdType ivar = 0; ivar <= nvar; ivar++)
+  {
     // set varname to emtpy last time around to get global attributes
     const char *varname = MI_EMPTY_STRING;
     if (ivar < nvar)
-      {
+    {
       varname = varnames->GetValue(ivar);
-      }
+    }
     vtkStringArray *attnames = source->GetAttributeNames(varname);
-    int natt = attnames->GetNumberOfValues();
-    for (int iatt = 0; iatt < natt; iatt++)
-      {
+    vtkIdType natt = attnames->GetNumberOfValues();
+    for (vtkIdType iatt = 0; iatt < natt; iatt++)
+    {
       const char *attname = attnames->GetValue(iatt);
       this->SetAttributeValueAsArray(
         varname, attname, source->GetAttributeValueAsArray(varname, attname));
-      }
     }
+  }
 
   if (this->StringStore)
-    {
+  {
     this->StringStore->Reset();
-    }
+  }
 }
-
