@@ -26,7 +26,6 @@
 #include "vtkObjectFactory.h"
 #include "vtkPointData.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
-#include "vtkTableExtentTranslator.h"
 #include "vtkToolkits.h"
 
 #include "vtkMultiProcessController.h"
@@ -84,15 +83,23 @@ vtkVPICReader::vtkVPICReader()
   this->MPIController = vtkMultiProcessController::GetGlobalController();
 
   if(this->MPIController)
-    {
+  {
     this->Rank = this->MPIController->GetLocalProcessId();
     this->TotalRank = this->MPIController->GetNumberOfProcesses();
-    }
+  }
   else
-    {
+  {
     this->Rank = 0;
     this->TotalRank = 1;
-    }
+  }
+
+  this->UsedRank = 0;
+
+  this->XExtent[0] = this->XExtent[1] = 0;
+  this->YExtent[0] = this->YExtent[1] = 0;
+  this->ZExtent[0] = this->ZExtent[1] = 0;
+
+  this->Stride[0] = this->Stride[1] = this->Stride[2] = 1;
 }
 
 //----------------------------------------------------------------------------
@@ -100,10 +107,7 @@ vtkVPICReader::vtkVPICReader()
 //----------------------------------------------------------------------------
 vtkVPICReader::~vtkVPICReader()
 {
-  if (this->FileName)
-    {
-    delete [] this->FileName;
-    }
+  delete [] this->FileName;
   this->PointDataArraySelection->Delete();
 
   delete this->vpicData;
@@ -112,20 +116,19 @@ vtkVPICReader::~vtkVPICReader()
   delete [] this->TimeSteps;
   delete [] this->dataLoaded;
 
-  if (this->exchanger)
-    delete this->exchanger;
+  delete this->exchanger;
 
   if (this->data)
-    {
+  {
     for (int var = 0; var < this->NumberOfVariables; var++)
-      {
+    {
       if (this->data[var])
-        {
+      {
         this->data[var]->Delete();
-        }
       }
-    delete [] this->data;
     }
+    delete [] this->data;
+  }
 
   this->SelectionObserver->Delete();
 
@@ -203,10 +206,8 @@ int vtkVPICReader::RequestInformation(
     this->YLayout[0] = 0;       this->YLayout[1] = layoutSize[1] - 1;
     this->ZLayout[0] = 0;       this->ZLayout[1] = layoutSize[2] - 1;
 
-    // Maximum number of pieces (processors) is number of files
-    this->NumberOfPieces = this->vpicData->getNumberOfParts();
-    outInfo->Set(vtkStreamingDemandDrivenPipeline::MAXIMUM_NUMBER_OF_PIECES(),
-                 this->NumberOfPieces);
+    outInfo->Set(CAN_HANDLE_PIECE_REQUEST(),
+     1);
 
     // Collect temporal information
     this->NumberOfTimeSteps = this->vpicData->getNumberOfTimeSteps();
@@ -264,31 +265,15 @@ int vtkVPICReader::RequestInformation(
     outInfo->Set(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT(),
                  this->WholeExtent, 6);
 
-    // Let the pipeline know how we want the data to be broken up
-    // Some processors might not get a piece of data to render
-    vtkTableExtentTranslator *extentTable = vtkTableExtentTranslator::New();
     int processorUsed = this->vpicData->getProcessorUsed();
 
     if(this->MPIController)
-      {
+    {
       this->MPIController->AllReduce(&processorUsed, &this->UsedRank,
                                      1, vtkCommunicator::SUM_OP);
-      }
-
-    extentTable->SetNumberOfPieces(this->UsedRank);
-
-    for (int piece = 0; piece < this->UsedRank; piece++) {
-      int subextent[6];
-      this->vpicData->getSubExtent(piece, subextent);
-      extentTable->SetExtentForPiece(piece, subextent);
     }
-    this->vpicData->getSubExtent(this->Rank, this->SubExtent);
-    extentTable->SetPiece(this->Rank);
-    extentTable->SetWholeExtent(this->WholeExtent);
-    extentTable->SetExtent(this->SubExtent);
 
-    vtkStreamingDemandDrivenPipeline::SetExtentTranslator(outInfo, extentTable);
-    extentTable->Delete();
+    this->vpicData->getSubExtent(this->Rank, this->SubExtent);
 
     // Reset the SubExtent on this processor to include ghost cells
     // Leave the subextents in the extent table as the size without ghosts
@@ -341,7 +326,7 @@ int vtkVPICReader::RequestInformation(
     }
 
     if (this->TotalRank>1)
-      {
+    {
       // Set up the GridExchange for sharing ghost cells on this view
       int decomposition[DIMENSION];
       this->vpicData->getDecomposition(decomposition);
@@ -351,7 +336,7 @@ int vtkVPICReader::RequestInformation(
       this->exchanger = new GridExchange
         (this->Rank, this->TotalRank, decomposition,
          this->GhostDimension, this->ghostLevel0, this->ghostLevel1);
-      }
+    }
   }
   return 1;
 }
@@ -369,10 +354,6 @@ int vtkVPICReader::RequestData(
   vtkImageData *output = vtkImageData::SafeDownCast(
     outInfo->Get(vtkDataObject::DATA_OBJECT()));
 
-  // Even if the pipeline asks for a smaller subextent, give it the
-  // full subextent with ghosts
-  vtkStreamingDemandDrivenPipeline::SetUpdateExtent(outInfo, this->SubExtent);
-
   // Set the subextent for this processor
   output->SetExtent(this->SubExtent);
 
@@ -500,9 +481,9 @@ void vtkVPICReader::LoadVariableData(int var, int timeStep)
 
     // Exchange the single component block retrieved from files to get ghosts
     if (this->TotalRank>1)
-      {
+    {
       this->exchanger->exchangeGrid(block);
-      }
+    }
 
     // Load the ghost component block into ParaView array
     if (this->VariableStruct[var] != TENSOR) {
@@ -587,13 +568,13 @@ vtkImageData* vtkVPICReader::GetOutput()
 vtkImageData* vtkVPICReader::GetOutput(int idx)
 {
   if (idx)
-    {
+  {
     return NULL;
-    }
+  }
   else
-    {
+  {
     return vtkImageData::SafeDownCast( this->GetOutputDataObject(idx) );
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
