@@ -12,13 +12,16 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
-// .NAME vtkImageShrink3D - Subsamples an image.
-// .SECTION Description
-// vtkImageShrink3D shrinks an image by sub sampling on a
-// uniform grid (integer multiples).
+/**
+ * @class   vtkImageShrink3D
+ * @brief   Subsamples an image.
+ *
+ * vtkImageShrink3D shrinks an image by sub sampling on a
+ * uniform grid (integer multiples).
+*/
 
-#ifndef __vtkImageShrink3D_h
-#define __vtkImageShrink3D_h
+#ifndef vtkImageShrink3D_h
+#define vtkImageShrink3D_h
 
 
 #include "vtkImagingCoreModule.h" // For export macro
@@ -31,25 +34,34 @@ public:
   vtkTypeMacro(vtkImageShrink3D,vtkThreadedImageAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent);
 
-  // Description:
-  // Set/Get the shrink factors
+  //@{
+  /**
+   * Set/Get the shrink factors
+   */
   vtkSetVector3Macro(ShrinkFactors,int);
   vtkGetVector3Macro(ShrinkFactors,int);
+  //@}
 
-  // Description:
-  // Set/Get the pixel to use as origin.
+  //@{
+  /**
+   * Set/Get the pixel to use as origin.
+   */
   vtkSetVector3Macro(Shift,int);
   vtkGetVector3Macro(Shift,int);
+  //@}
 
-  // Description:
-  // Choose Mean, Minimum, Maximum, Median or sub sampling.
-  // The neighborhood operations are not centered on the sampled pixel.
-  // This may cause a half pixel shift in your output image.
-  // You can changed "Shift" to get around this.
-  // vtkImageGaussianSmooth or vtkImageMean with strides.
+  //@{
+  /**
+   * Choose Mean, Minimum, Maximum, Median or sub sampling.
+   * The neighborhood operations are not centered on the sampled pixel.
+   * This may cause a half pixel shift in your output image.
+   * You can changed "Shift" to get around this.
+   * vtkImageGaussianSmooth or vtkImageMean with strides.
+   */
   void SetAveraging(int);
   int GetAveraging() {return this->GetMean();};
   vtkBooleanMacro(Averaging,int);
+  //@}
 
   void SetMean(int);
   vtkGetMacro(Mean,int);
@@ -90,8 +102,8 @@ protected:
   void InternalRequestUpdateExtent(int *inExt, int *outExt);
 
 private:
-  vtkImageShrink3D(const vtkImageShrink3D&);  // Not implemented.
-  void operator=(const vtkImageShrink3D&);  // Not implemented.
+  vtkImageShrink3D(const vtkImageShrink3D&) VTK_DELETE_FUNCTION;
+  void operator=(const vtkImageShrink3D&) VTK_DELETE_FUNCTION;
 };
 
 #endif
