@@ -17,16 +17,18 @@
   Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
   the U.S. Government retains certain rights in this software.
 -------------------------------------------------------------------------*/
-// .NAME vtkDirectedGraph*ToBoostAdapter - adapter to the boost graph library (www.boost.org)
-//
-// .SECTION Description
-// Including this header allows you to use a vtkDirectedGraph* in boost algorithms.
-// To do this, first wrap the class in a vtkDirectedGraph* or
-// vtkUndirectedGraph* depending on whether your graph is directed or undirected.
-// You may then use these objects directly in boost graph algorithms.
+/**
+ * @class   vtkDirectedGraph
+ *
+ *
+ * Including this header allows you to use a vtkDirectedGraph* in boost algorithms.
+ * To do this, first wrap the class in a vtkDirectedGraph* or
+ * vtkUndirectedGraph* depending on whether your graph is directed or undirected.
+ * You may then use these objects directly in boost graph algorithms.
+*/
 
-#ifndef __vtkBoostGraphAdapter_h
-#define __vtkBoostGraphAdapter_h
+#ifndef vtkBoostGraphAdapter_h
+#define vtkBoostGraphAdapter_h
 
 #include "vtkAbstractArray.h"
 #include "vtkDirectedGraph.h"
@@ -59,12 +61,12 @@ namespace boost {
 #define vtkPropertyMapMacro(T, V)                       \
   template <>                                           \
   struct property_traits<T*>                            \
-    {                                                   \
+  {                                                   \
     typedef V value_type;                               \
     typedef V reference;                                \
     typedef vtkIdType key_type;                         \
     typedef read_write_property_map_tag category;       \
-    };                                                  \
+  };                                                  \
                                                         \
   inline property_traits<T*>::reference                 \
   get(                                                  \
@@ -131,9 +133,15 @@ namespace boost {
   {
     arr->InsertVariantValue(key, value);
   }
+#if defined(_MSC_VER)
+  namespace detail {
+       using ::boost::get;
+       using ::boost::put;
+  }
+#endif
 }
 
-#include <vtksys/stl/utility> // STL Header
+#include <utility> // STL Header
 
 #include <boost/config.hpp>
 #include <boost/iterator/iterator_facade.hpp>
@@ -153,7 +161,7 @@ namespace boost {
                            bidirectional_traversal_tag,
                            vtkIdType,
                            vtkIdType>
-    {
+  {
     public:
       explicit vtk_vertex_iterator(vtkIdType i = 0) : index(i) {}
 
@@ -169,7 +177,7 @@ namespace boost {
       vtkIdType index;
 
       friend class iterator_core_access;
-    };
+  };
 
   class vtk_edge_iterator :
     public iterator_facade<vtk_edge_iterator,
@@ -177,36 +185,36 @@ namespace boost {
                            forward_traversal_tag,
                            vtkEdgeType,
                            vtkIdType>
-    {
+  {
     public:
       explicit vtk_edge_iterator(vtkGraph *g = 0, vtkIdType v = 0) :
         directed(false), vertex(v), lastVertex(v), iter(0), end(0), graph(g)
-        {
+      {
         if (graph)
-          {
+        {
           lastVertex = graph->GetNumberOfVertices();
-          }
+        }
 
         vtkIdType myRank = -1;
         vtkDistributedGraphHelper *helper
           = this->graph? this->graph->GetDistributedGraphHelper() : 0;
         if (helper)
-          {
+        {
           myRank = this->graph->GetInformation()->Get(vtkDataObject::DATA_PIECE_NUMBER());
           vertex = helper->MakeDistributedId(myRank, vertex);
           lastVertex = helper->MakeDistributedId(myRank, lastVertex);
-          }
+        }
 
         if (graph != 0)
-          {
+        {
           directed = (vtkDirectedGraph::SafeDownCast(graph) != 0);
           while (vertex < lastVertex && this->graph->GetOutDegree(vertex) == 0)
-            {
+          {
             ++vertex;
-            }
+          }
 
           if (vertex < lastVertex)
-            {
+          {
             // Get the outgoing edges of the first vertex that has outgoing
             // edges
             vtkIdType nedges;
@@ -214,7 +222,7 @@ namespace boost {
             end = iter + nedges;
 
             if (!directed)
-              {
+            {
               while(iter != 0
                     && (// Skip non-local edges
                         (helper && helper->GetEdgeOwner(iter->Id) != myRank)
@@ -223,17 +231,17 @@ namespace boost {
                               && myRank == helper->GetVertexOwner(iter->Target))
                              || !helper)
                             && vertex > iter->Target)))
-                {
+              {
                 this->inc();
-                }
               }
             }
+          }
           else
-            {
+          {
             iter = 0;
-            }
           }
         }
+      }
 
     private:
       vtkEdgeType dereference() const
@@ -243,17 +251,17 @@ namespace boost {
         { return vertex == other.vertex && iter == other.iter; }
 
       void increment()
-        {
+      {
         inc();
         if (!directed)
-          {
+        {
           vtkIdType myRank = -1;
           vtkDistributedGraphHelper *helper
             = this->graph? this->graph->GetDistributedGraphHelper() : 0;
           if (helper)
-            {
+          {
             myRank = this->graph->GetInformation()->Get(vtkDataObject::DATA_PIECE_NUMBER());
-            }
+          }
 
           while (iter != 0
                  && (// Skip non-local edges
@@ -263,36 +271,36 @@ namespace boost {
                            && myRank == helper->GetVertexOwner(iter->Target))
                           || !helper)
                          && vertex > iter->Target)))
-            {
+          {
             inc();
-            }
           }
         }
+      }
 
       void inc()
-        {
+      {
         ++iter;
         if (iter == end)
-          {
+        {
           // Find a vertex with nonzero out degree.
           ++vertex;
           while (vertex < lastVertex && this->graph->GetOutDegree(vertex) == 0)
-            {
+          {
             ++vertex;
-            }
+          }
 
           if (vertex < lastVertex)
-            {
+          {
             vtkIdType nedges;
             graph->GetOutEdges(vertex, iter, nedges);
             end = iter + nedges;
-            }
+          }
           else
-            {
+          {
             iter = 0;
-            }
           }
         }
+      }
 
       bool directed;
       vtkIdType vertex;
@@ -302,7 +310,7 @@ namespace boost {
       vtkGraph *graph;
 
       friend class iterator_core_access;
-    };
+  };
 
   class vtk_out_edge_pointer_iterator :
     public iterator_facade<vtk_out_edge_pointer_iterator,
@@ -310,20 +318,20 @@ namespace boost {
                            bidirectional_traversal_tag,
                            vtkEdgeType,
                            ptrdiff_t>
-    {
+  {
     public:
       explicit vtk_out_edge_pointer_iterator(vtkGraph *g = 0, vtkIdType v = 0, bool end = false) :
         vertex(v)
       {
         if (g)
-          {
+        {
           vtkIdType nedges;
           g->GetOutEdges(vertex, iter, nedges);
           if (end)
-            {
+          {
             iter += nedges;
-            }
           }
+        }
       }
 
     private:
@@ -339,7 +347,7 @@ namespace boost {
       const vtkOutEdgeType *iter;
 
       friend class iterator_core_access;
-    };
+  };
 
   class vtk_in_edge_pointer_iterator :
     public iterator_facade<vtk_in_edge_pointer_iterator,
@@ -347,20 +355,20 @@ namespace boost {
                            bidirectional_traversal_tag,
                            vtkEdgeType,
                            ptrdiff_t>
-    {
+  {
     public:
       explicit vtk_in_edge_pointer_iterator(vtkGraph *g = 0, vtkIdType v = 0, bool end = false) :
         vertex(v)
       {
         if (g)
-          {
+        {
           vtkIdType nedges;
           g->GetInEdges(vertex, iter, nedges);
           if (end)
-            {
+          {
             iter += nedges;
-            }
           }
+        }
       }
 
     private:
@@ -376,7 +384,7 @@ namespace boost {
       const vtkInEdgeType *iter;
 
       friend class iterator_core_access;
-    };
+  };
 
   //===========================================================================
   // vtkGraph
@@ -447,22 +455,22 @@ namespace boost {
   };
 
   inline bool has_no_edges(vtkGraph* g)
-    {
+  {
       return ((g->GetNumberOfEdges() > 0) ? false : true);
-    }
+  }
 
   inline void remove_edge(graph_traits<vtkGraph*>::edge_descriptor e,
                           vtkGraph* g)
-    {
+  {
     if(vtkMutableDirectedGraph::SafeDownCast(g))
-      {
+    {
       vtkMutableDirectedGraph::SafeDownCast(g)->RemoveEdge(e.Id);
-      }
-    else if(vtkMutableUndirectedGraph::SafeDownCast(g))
-      {
-      vtkMutableUndirectedGraph::SafeDownCast(g)->RemoveEdge(e.Id);
-      }
     }
+    else if(vtkMutableUndirectedGraph::SafeDownCast(g))
+    {
+      vtkMutableUndirectedGraph::SafeDownCast(g)->RemoveEdge(e.Id);
+    }
+  }
 
   //===========================================================================
   // vtkDirectedGraph
@@ -824,7 +832,7 @@ target(boost::graph_traits< vtkGraph* >::edge_descriptor e,
   return e.Target;
 }
 
-inline vtksys_stl::pair<
+inline std::pair<
   boost::graph_traits< vtkGraph* >::vertex_iterator,
   boost::graph_traits< vtkGraph* >::vertex_iterator >
 vertices(vtkGraph *g)
@@ -832,26 +840,26 @@ vertices(vtkGraph *g)
   typedef boost::graph_traits< vtkGraph* >::vertex_iterator Iter;
   vtkIdType start = 0;
   if (vtkDistributedGraphHelper *helper = g->GetDistributedGraphHelper())
-    {
+  {
     int rank =
       g->GetInformation()->Get(vtkDataObject::DATA_PIECE_NUMBER());
     start = helper->MakeDistributedId(rank, start);
-    }
+  }
 
-  return vtksys_stl::make_pair( Iter(start),
+  return std::make_pair( Iter(start),
                                 Iter(start + g->GetNumberOfVertices()) );
 }
 
-inline vtksys_stl::pair<
+inline std::pair<
   boost::graph_traits< vtkGraph* >::edge_iterator,
   boost::graph_traits< vtkGraph* >::edge_iterator >
 edges(vtkGraph *g)
 {
   typedef boost::graph_traits< vtkGraph* >::edge_iterator Iter;
-  return vtksys_stl::make_pair( Iter(g), Iter(g, g->GetNumberOfVertices()) );
+  return std::make_pair( Iter(g), Iter(g, g->GetNumberOfVertices()) );
 }
 
-inline vtksys_stl::pair<
+inline std::pair<
   boost::graph_traits< vtkGraph* >::out_edge_iterator,
   boost::graph_traits< vtkGraph* >::out_edge_iterator >
 out_edges(
@@ -859,11 +867,11 @@ out_edges(
   vtkGraph *g)
 {
   typedef boost::graph_traits< vtkGraph* >::out_edge_iterator Iter;
-  vtksys_stl::pair<Iter, Iter> p = vtksys_stl::make_pair( Iter(g, u), Iter(g, u, true) );
+  std::pair<Iter, Iter> p = std::make_pair( Iter(g, u), Iter(g, u, true) );
   return p;
 }
 
-inline vtksys_stl::pair<
+inline std::pair<
   boost::graph_traits< vtkGraph* >::in_edge_iterator,
   boost::graph_traits< vtkGraph* >::in_edge_iterator >
 in_edges(
@@ -871,11 +879,11 @@ in_edges(
   vtkGraph *g)
 {
   typedef boost::graph_traits< vtkGraph* >::in_edge_iterator Iter;
-  vtksys_stl::pair<Iter, Iter> p = vtksys_stl::make_pair( Iter(g, u), Iter(g, u, true) );
+  std::pair<Iter, Iter> p = std::make_pair( Iter(g, u), Iter(g, u, true) );
   return p;
 }
 
-inline vtksys_stl::pair<
+inline std::pair<
   boost::graph_traits< vtkGraph* >::adjacency_iterator,
   boost::graph_traits< vtkGraph* >::adjacency_iterator >
 adjacent_vertices(
@@ -884,8 +892,8 @@ adjacent_vertices(
 {
   typedef boost::graph_traits< vtkGraph* >::adjacency_iterator Iter;
   typedef boost::graph_traits< vtkGraph* >::out_edge_iterator OutEdgeIter;
-  vtksys_stl::pair<OutEdgeIter, OutEdgeIter> out = out_edges(u, g);
-  return vtksys_stl::make_pair( Iter(out.first, &g), Iter(out.second, &g) );
+  std::pair<OutEdgeIter, OutEdgeIter> out = out_edges(u, g);
+  return std::make_pair( Iter(out.first, &g), Iter(out.second, &g) );
 }
 
 inline boost::graph_traits< vtkGraph* >::vertices_size_type
@@ -930,7 +938,7 @@ add_vertex(vtkMutableDirectedGraph *g)
   return g->AddVertex();
 }
 
-inline vtksys_stl::pair<
+inline std::pair<
   boost::graph_traits< vtkMutableDirectedGraph* >::edge_descriptor,
   bool>
 add_edge(
@@ -939,7 +947,7 @@ add_edge(
   vtkMutableDirectedGraph *g)
 {
   boost::graph_traits< vtkMutableDirectedGraph* >::edge_descriptor e = g->AddEdge(u, v);
-  return vtksys_stl::make_pair(e, true);
+  return std::make_pair(e, true);
 }
 
 inline boost::graph_traits< vtkMutableUndirectedGraph* >::vertex_descriptor
@@ -948,7 +956,7 @@ add_vertex(vtkMutableUndirectedGraph *g)
   return g->AddVertex();
 }
 
-inline vtksys_stl::pair<
+inline std::pair<
   boost::graph_traits< vtkMutableUndirectedGraph* >::edge_descriptor,
   bool>
 add_edge(
@@ -957,7 +965,7 @@ add_edge(
   vtkMutableUndirectedGraph *g)
 {
   boost::graph_traits< vtkMutableUndirectedGraph* >::edge_descriptor e = g->AddEdge(u, v);
-  return vtksys_stl::make_pair(e, true);
+  return std::make_pair(e, true);
 }
 
 namespace boost {
@@ -969,12 +977,12 @@ namespace boost {
 
   template <>
   struct property_traits<vtkGraphEdgeMap>
-    {
+  {
     typedef vtkIdType value_type;
     typedef vtkIdType reference;
     typedef vtkEdgeType key_type;
     typedef readable_property_map_tag category;
-    };
+  };
 
   inline property_traits<vtkGraphEdgeMap>::reference
   get(
@@ -1027,12 +1035,12 @@ namespace boost {
 
   template <>
   struct property_traits<vtkGraphIndexMap>
-    {
+  {
     typedef vtkIdType value_type;
     typedef vtkIdType reference;
     typedef vtkIdType key_type;
     typedef readable_property_map_tag category;
-    };
+  };
 
   inline property_traits<vtkGraphIndexMap>::reference
   get(
@@ -1062,7 +1070,7 @@ namespace boost {
   inline typename property_traits<PMap>::reference
   get(
     vtkGraphPropertyMapMultiplier<PMap> multi,
-    const typename property_traits<PMap>::key_type key)
+    const typename property_traits<PMap>::key_type & key)
   {
     return multi.multiplier * get(multi.pmap, key);
   }
@@ -1071,7 +1079,7 @@ namespace boost {
   inline void
   put(
     vtkGraphPropertyMapMultiplier<PMap> multi,
-    const typename property_traits<PMap>::key_type key,
+    const typename property_traits<PMap>::key_type & key,
     const typename property_traits<PMap>::value_type & value)
   {
     put(multi.pmap, key, value);
@@ -1138,5 +1146,5 @@ namespace boost {
 #endif
 
 
-#endif // __vtkBoostGraphAdapter_h
+#endif // vtkBoostGraphAdapter_h
 // VTK-HeaderTest-Exclude: vtkBoostGraphAdapter.h
