@@ -37,7 +37,7 @@
 #include "vtkWidgetEventTranslator.h"
 #include "vtkWidgetEvent.h"
 
-char TestSliderWidget2DEventLog[] =
+const char TestSliderWidget2DEventLog[] =
   "# StreamVersion 1\n"
   "EnterEvent 285 73 0 0 0 0 0\n"
   "MouseMoveEvent 265 83 0 0 0 0 0\n"
@@ -506,7 +506,7 @@ class vtkSlider2DCallback : public vtkCommand
 public:
   static vtkSlider2DCallback *New()
   { return new vtkSlider2DCallback; }
-  virtual void Execute(vtkObject *caller, unsigned long, void*)
+  void Execute(vtkObject *caller, unsigned long, void*) VTK_OVERRIDE
   {
     vtkSliderWidget *sliderWidget =
       reinterpret_cast<vtkSliderWidget*>(caller);
