@@ -89,13 +89,13 @@ void vtkCellPicker::PrintSelf(ostream& os, vtkIndent indent)
      << this->PickNormal[1] << "," << this->PickNormal[2] << ")\n";
 
   if ( this->Texture )
-    {
+  {
     os << indent << "Texture: " << this->Texture << "\n";
-    }
+  }
   else
-    {
+  {
     os << indent << "Texture: (none)";
-    }
+  }
 
   os << indent << "PickTextureData: "
      << (this->PickTextureData ? "On" : "Off") << "\n";
@@ -177,9 +177,9 @@ void vtkCellPicker::ResetCellPickerInfo()
 void vtkCellPicker::AddLocator(vtkAbstractCellLocator *locator)
 {
   if (!this->Locators->IsItemPresent(locator))
-    {
+  {
     this->Locators->AddItem(locator);
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -202,31 +202,31 @@ int vtkCellPicker::Pick(double selectionX, double selectionY,
 
   if ( (pickResult = this->Superclass::Pick(selectionX, selectionY, selectionZ,
                                             renderer)) == 0)
-    {
+  {
     // If no pick, set the PickNormal so that it points at the camera
     vtkCamera *camera = renderer->GetActiveCamera();
     double cameraPos[3];
     camera->GetPosition(cameraPos);
 
     if (camera->GetParallelProjection())
-      {
+    {
       // For parallel projection, use -ve direction of projection
       double cameraFocus[3];
       camera->GetFocalPoint(cameraFocus);
       this->PickNormal[0] = cameraPos[0] - cameraFocus[0];
       this->PickNormal[1] = cameraPos[1] - cameraFocus[1];
       this->PickNormal[2] = cameraPos[2] - cameraFocus[2];
-      }
+    }
     else
-      {
+    {
       // Get the vector from pick position to the camera
       this->PickNormal[0] = cameraPos[0] - this->PickPosition[0];
       this->PickNormal[1] = cameraPos[1] - this->PickPosition[1];
       this->PickNormal[2] = cameraPos[2] - this->PickPosition[2];
-      }
+    }
 
     vtkMath::Normalize(this->PickNormal);
-    }
+  }
 
   return pickResult;
 }
@@ -254,42 +254,42 @@ double vtkCellPicker::IntersectWithLine(double p1[3], double p2[3],
   int clippingPlaneId = -1;
   if (m && !this->ClipLineWithPlanes(m, this->Transform->GetMatrix(),
                                      p1, p2, t1, t2, clippingPlaneId))
-    {
+  {
     return VTK_DOUBLE_MAX;
-    }
+  }
 
   // Initialize the pick position to the frontmost clipping plane
   if (this->PickClippingPlanes && clippingPlaneId >= 0)
-    {
+  {
     tMin = t1;
-    }
+  }
 
   // Volume
   else if ( (volumeMapper = vtkAbstractVolumeMapper::SafeDownCast(m)) )
-    {
+  {
     tMin = this->IntersectVolumeWithLine(p1, p2, t1, t2, prop, volumeMapper);
-    }
+  }
 
   // Image
   else if ( (imageMapper = vtkImageMapper3D::SafeDownCast(m)) )
-    {
+  {
     tMin = this->IntersectImageWithLine(p1, p2, t1, t2, prop, imageMapper);
-    }
+  }
 
   // Actor
   else if ( (mapper = vtkMapper::SafeDownCast(m)) )
-    {
+  {
     tMin = this->IntersectActorWithLine(p1, p2, t1, t2, tol, prop, mapper);
-    }
+  }
 
   // Unidentified Prop3D
   else
-    {
+  {
     tMin = this->IntersectProp3DWithLine(p1, p2, t1, t2, tol, prop, m);
-    }
+  }
 
   if (tMin < this->GlobalTMin)
-    {
+  {
     this->GlobalTMin = tMin;
     this->SetPath(path);
 
@@ -298,7 +298,7 @@ double vtkCellPicker::IntersectWithLine(double p1[3], double p2[3],
     // If tMin == t1, the pick didn't go past the first clipping plane,
     // so the position and normal will be set from the clipping plane.
     if (fabs(tMin - t1) < VTKCELLPICKER_PLANE_TOL && clippingPlaneId >= 0)
-      {
+    {
       this->MapperPosition[0] = p1[0]*(1.0-t1) + p2[0]*t1;
       this->MapperPosition[1] = p1[1]*(1.0-t1) + p2[1]*t1;
       this->MapperPosition[2] = p1[2]*(1.0-t1) + p2[2]*t1;
@@ -311,12 +311,12 @@ double vtkCellPicker::IntersectWithLine(double p1[3], double p2[3],
       this->MapperNormal[0] = -plane[0];
       this->MapperNormal[1] = -plane[1];
       this->MapperNormal[2] = -plane[2];
-      }
+    }
 
     // The position comes from the data, so put it into world coordinates
     this->Transform->TransformPoint(this->MapperPosition, this->PickPosition);
     this->Transform->TransformNormal(this->MapperNormal, this->PickNormal);
-    }
+  }
 
   return tMin;
 }
@@ -350,59 +350,59 @@ double vtkCellPicker::IntersectActorWithLine(const double p1[3],
   minXYZ[0] = minXYZ[1] = minXYZ[2] = 0.0;
 
   // Polydata has no 3D cells
-  int isPolyData = data->IsA("vtkPolyData");
+  vtkTypeBool isPolyData = data->IsA("vtkPolyData");
 
   vtkCollectionSimpleIterator iter;
   vtkAbstractCellLocator *locator = 0;
   this->Locators->InitTraversal(iter);
   while ( (locator = static_cast<vtkAbstractCellLocator *>(
            this->Locators->GetNextItemAsObject(iter))) )
-    {
+  {
     if (locator->GetDataSet() == data)
-      {
+    {
       break;
-      }
     }
+  }
 
   // Make a new p1 and p2 using the clipped t1 and t2
   double q1[3], q2[3];
   q1[0] = p1[0]; q1[1] = p1[1]; q1[2] = p1[2];
   q2[0] = p2[0]; q2[1] = p2[1]; q2[2] = p2[2];
   if (t1 != 0.0 || t2 != 1.0)
-    {
+  {
     for (int j = 0; j < 3; j++)
-      {
+    {
       q1[j] = p1[j]*(1.0 - t1) + p2[j]*t1;
       q2[j] = p1[j]*(1.0 - t2) + p2[j]*t2;
-      }
     }
+  }
 
   // Use the locator if one exists for this data
   if (locator)
-    {
+  {
     if (!locator->IntersectWithLine(q1, q2, tol, tMin, minXYZ,
                                     minPCoords, minSubId, minCellId,
                                     this->Cell))
-      {
+    {
       return VTK_DOUBLE_MAX;
-      }
+    }
 
     // Stretch tMin out to the original range
     if (t1 != 0.0 || t2 != 1.0)
-      {
+    {
       tMin = t1*(1.0 - tMin) + t2*tMin;
-      }
+    }
 
     // If cell is a strip, then replace cell with a sub-cell
     this->SubCellFromCell(this->Cell, minSubId);
-    }
+  }
   else
-    {
+  {
     vtkIdList *pointIds = this->PointIds;
     vtkIdType numCells = data->GetNumberOfCells();
 
     for (vtkIdType cellId = 0; cellId < numCells; cellId++)
-      {
+    {
       double t;
       double x[3];
       double pcoords[3];
@@ -414,35 +414,35 @@ double vtkCellPicker::IntersectActorWithLine(const double p1[3],
       int cellType = data->GetCellType(cellId);
       int useSubCells = this->HasSubCells(cellType);
       if (useSubCells)
-        {
+      {
         // Get the pointIds for the strip and the length of the strip
         data->GetCellPoints(cellId, pointIds);
         numSubIds = this->GetNumberOfSubCells(pointIds, cellType);
-        }
+      }
 
       // This will only loop once unless we need to deal with a strip
       for (int subId = 0; subId < numSubIds; subId++)
-        {
+      {
         if (useSubCells)
-          {
+        {
           // Get a sub-cell from a the strip
           this->GetSubCell(data, pointIds, subId, cellType, this->Cell);
-          }
+        }
         else
-          {
+        {
           data->GetCell(cellId, this->Cell);
-          }
+        }
 
         int cellPicked = 0;
         if (isPolyData)
-          {
+        {
           // Polydata can always be picked with original endpoints
           cellPicked = this->Cell->IntersectWithLine(
                          const_cast<double *>(p1), const_cast<double *>(p2),
                          tol, t, x, pcoords, newSubId);
-          }
+        }
         else
-          {
+        {
           // Any 3D cells need to be intersected with a line segment that
           // has been clipped with the clipping planes, in case one end is
           // actually inside the cell.
@@ -451,39 +451,39 @@ double vtkCellPicker::IntersectActorWithLine(const double p1[3],
 
           // Stretch t out to the original range
           if (t1 != 0.0 || t2 != 1.0)
-            {
+          {
             t = t1*(1.0 - t) + t2*t;
-            }
           }
+        }
 
         if (cellPicked && t <= (tMin + this->Tolerance) && t >= t1 && t <= t2)
-          {
+        {
           double pDist = this->Cell->GetParametricDistance(pcoords);
           if (pDist < pDistMin || (pDist == pDistMin && t < tMin))
-            {
+          {
             tMin = t;
             pDistMin = pDist;
             // save all of these
             minCellId = cellId;
             minSubId = newSubId;
             if (useSubCells)
-              {
+            {
               minSubId = subId;
-              }
+            }
             for (int k = 0; k < 3; k++)
-              {
+            {
               minXYZ[k] = x[k];
               minPCoords[k] = pcoords[k];
-              }
-            } // for all subIds
-          } // if minimum, maximum
-        } // if a close cell
-      } // for all cells
-    }
+            }
+          } // for all subIds
+        } // if minimum, maximum
+      } // if a close cell
+    } // for all cells
+  }
 
   // Do this if a cell was intersected
   if (minCellId >= 0 && tMin < this->GlobalTMin)
-    {
+  {
     this->ResetPickInfo();
 
     // Get the cell, convert to triangle if it is a strip
@@ -491,27 +491,27 @@ double vtkCellPicker::IntersectActorWithLine(const double p1[3],
 
     // If we used a locator, we already have the picked cell
     if (!locator)
-      {
+    {
       int cellType = data->GetCellType(minCellId);
 
       if (this->HasSubCells(cellType))
-        {
+      {
         data->GetCellPoints(minCellId, this->PointIds);
         this->GetSubCell(data, this->PointIds, minSubId, cellType, cell);
-        }
-      else
-        {
-        data->GetCell(minCellId, cell);
-        }
       }
+      else
+      {
+        data->GetCell(minCellId, cell);
+      }
+    }
 
     // Get the cell weights
     vtkIdType numPoints = cell->GetNumberOfPoints();
     double *weights = new double[numPoints];
     for (vtkIdType i = 0; i < numPoints; i++)
-      {
+    {
       weights[i] = 0;
-      }
+    }
 
     // Get the interpolation weights (point is thrown away)
     double point[3];
@@ -523,17 +523,17 @@ double vtkCellPicker::IntersectActorWithLine(const double p1[3],
     vtkActor *actor = 0;
     vtkLODProp3D *lodActor = 0;
     if ( (actor = vtkActor::SafeDownCast(prop)) )
-      {
+    {
       this->Texture = actor->GetTexture();
-      }
+    }
     else if ( (lodActor = vtkLODProp3D::SafeDownCast(prop)) )
-      {
+    {
       int lodId = lodActor->GetPickLODID();
       lodActor->GetLODTexture(lodId, &this->Texture);
-      }
+    }
 
     if (this->PickTextureData && this->Texture)
-      {
+    {
       // Return the texture's image data to the user
       vtkImageData *image = this->Texture->GetInput();
       this->DataSet = image;
@@ -544,16 +544,16 @@ double vtkCellPicker::IntersectActorWithLine(const double p1[3],
       int dimensionsAreValid = 1;
       int dimensions[3];
       for (int i = 0; i < 3; i++)
-        {
+      {
         dimensions[i] = extent[2*i + 1] - extent[2*i] + 1;
         dimensionsAreValid = (dimensionsAreValid && dimensions[i] > 0);
-        }
+      }
 
       // Use the texture coord to set the information
       double tcoord[3];
       if (dimensionsAreValid &&
           this->ComputeSurfaceTCoord(data, cell, weights, tcoord))
-        {
+      {
         // Take the border into account when computing coordinates
         double x[3];
         x[0] = extent[0] + tcoord[0]*dimensions[0] - 0.5;
@@ -561,10 +561,10 @@ double vtkCellPicker::IntersectActorWithLine(const double p1[3],
         x[2] = extent[4] + tcoord[2]*dimensions[2] - 0.5;
 
         this->SetImageDataPickInfo(x, extent);
-        }
       }
+    }
     else
-      {
+    {
       // Return the polydata to the user
       this->DataSet = data;
       this->CellId = minCellId;
@@ -577,19 +577,20 @@ double vtkCellPicker::IntersectActorWithLine(const double p1[3],
       double maxWeight = 0;
       vtkIdType iMaxWeight = -1;
       for (vtkIdType i = 0; i < numPoints; i++)
-        {
+      {
         if (weights[i] > maxWeight)
-          {
+        {
           iMaxWeight = i;
-          }
+          maxWeight = weights[i];
         }
+      }
 
       // If maximum weight is found, use it to get the PointId
       if (iMaxWeight != -1)
-        {
+      {
         this->PointId = cell->PointIds->GetId(iMaxWeight);
-        }
       }
+    }
 
     // Set the mapper position
     this->MapperPosition[0] = minXYZ[0];
@@ -598,16 +599,16 @@ double vtkCellPicker::IntersectActorWithLine(const double p1[3],
 
     // Compute the normal
     if (!this->ComputeSurfaceNormal(data, cell, weights, this->MapperNormal))
-      {
+    {
       // By default, the normal points back along view ray
       this->MapperNormal[0] = p1[0] - p2[0];
       this->MapperNormal[1] = p1[1] - p2[1];
       this->MapperNormal[2] = p1[2] - p2[2];
       vtkMath::Normalize(this->MapperNormal);
-      }
+    }
 
     delete [] weights;
-    }
+  }
 
   return tMin;
 }
@@ -628,10 +629,10 @@ double vtkCellPicker::IntersectVolumeWithLine(const double p1[3],
   vtkImageData *data = vtkImageData::SafeDownCast(mapper->GetDataSetInput());
 
   if (data == 0)
-    {
+  {
     // This picker only works with image inputs
     return VTK_DOUBLE_MAX;
-    }
+  }
 
   // Convert ray to structured coordinates
   double spacing[3], origin[3];
@@ -642,40 +643,40 @@ double vtkCellPicker::IntersectVolumeWithLine(const double p1[3],
 
   double x1[3], x2[3];
   for (int i = 0; i < 3; i++)
-    {
+  {
     x1[i] = (p1[i] - origin[i])/spacing[i];
     x2[i] = (p2[i] - origin[i])/spacing[i];
-    }
+  }
 
   // Clip the ray with the extent, results go in s1 and s2
   int planeId;
   double s1, s2;
   if (!this->ClipLineWithExtent(extent, x1, x2, s1, s2, planeId))
-    {
+  {
     return VTK_DOUBLE_MAX;
-    }
+  }
   if (s1 >= t1) { t1 = s1; }
   if (s2 <= t2) { t2 = s2; }
 
   // Sanity check
   if (t2 < t1)
-    {
+  {
     return VTK_DOUBLE_MAX;
-    }
+  }
 
   // Get the property from the volume or the LOD
   vtkVolumeProperty *property = 0;
   vtkVolume *volume = 0;
   vtkLODProp3D *lodVolume = 0;
   if ( (volume = vtkVolume::SafeDownCast(prop)) )
-    {
+  {
     property = volume->GetProperty();
-    }
+  }
   else if ( (lodVolume = vtkLODProp3D::SafeDownCast(prop)) )
-    {
+  {
     int lodId = lodVolume->GetPickLODID();
     lodVolume->GetLODProperty(lodId, &property);
-    }
+  }
 
   // Get the theshold for the opacity
   double opacityThreshold = this->VolumeOpacityIsovalue;
@@ -688,12 +689,16 @@ double vtkCellPicker::IntersectVolumeWithLine(const double p1[3],
 
   // Find out whether there are multiple components in the volume
   int numComponents = data->GetNumberOfScalarComponents();
-  int independentComponents = property->GetIndependentComponents();
+  int independentComponents = 0;
+  if (property)
+  {
+    independentComponents = property->GetIndependentComponents();
+  }
   int numIndependentComponents = 1;
   if (independentComponents)
-    {
+  {
     numIndependentComponents = numComponents;
-    }
+  }
 
   // Create a scalar array, it will be needed later
   vtkDataArray *scalars = vtkDataArray::CreateDataArray(data->GetScalarType());
@@ -705,23 +710,23 @@ double vtkCellPicker::IntersectVolumeWithLine(const double p1[3],
   // Go through each volume component separately
   double tMin = VTK_DOUBLE_MAX;
   for (int component = 0; component < numIndependentComponents; component++)
-    {
+  {
     vtkPiecewiseFunction *scalarOpacity =
-      property->GetScalarOpacity(component);
+      (property ? property->GetScalarOpacity(component) : 0);
     int disableGradientOpacity =
-      property->GetDisableGradientOpacity(component);
+      (property ? property->GetDisableGradientOpacity(component) : 1);
     vtkPiecewiseFunction *gradientOpacity = 0;
     if (!disableGradientOpacity && this->UseVolumeGradientOpacity)
-      {
+    {
       gradientOpacity = property->GetGradientOpacity(component);
-      }
+    }
 
     // This is the component used to compute the opacity
     int oComponent = component;
     if (!independentComponents)
-      {
+    {
       oComponent = numComponents - 1;
-      }
+    }
 
     // Make a new array, shifted to the desired component
     scalars->SetVoidArray(static_cast<void *>(static_cast<char *>(scalarPtr)
@@ -739,9 +744,9 @@ double vtkCellPicker::IntersectVolumeWithLine(const double p1[3],
     // Ray cast loop
     double t = t1;
     while (t <= t2)
-      {
+    {
       for (int j = 0; j < 3; j++)
-        {
+      {
         // "t" is the fractional distance between endpoints x1 and x2
         x[j] = x1[j]*(1.0 - t) + x2[j]*t;
 
@@ -751,16 +756,16 @@ double vtkCellPicker::IntersectVolumeWithLine(const double p1[3],
 
         xi[j] = vtkMath::Floor(x[j]);
         pcoords[j] = x[j] - xi[j];
-        }
+      }
 
       opacity = this->ComputeVolumeOpacity(xi, pcoords, data, scalars,
                                            scalarOpacity, gradientOpacity);
 
       // If the ray has crossed the isosurface, then terminate the loop
       if (opacity > opacityThreshold)
-        {
+      {
         break;
-        }
+      }
 
       lastT = t;
       lastOpacity = opacity;
@@ -768,10 +773,10 @@ double vtkCellPicker::IntersectVolumeWithLine(const double p1[3],
       // Compute the next "t" value that crosses a voxel boundary
       t = 1.0;
       for (int k = 0; k < 3; k++)
-        {
+      {
         // Skip dimension "k" if it is perpendicular to ray
         if (fabs(x2[k] - x1[k]) > VTKCELLPICKER_VOXEL_TOL*rayLength)
-          {
+        {
           // Compute the previous coord along dimension "k"
           double lastX = x1[k]*(1.0 - lastT) + x2[k]*lastT;
 
@@ -780,45 +785,52 @@ double vtkCellPicker::IntersectVolumeWithLine(const double p1[3],
           // where lastX is just less than an integer value.
           double nextX = 0;
           if (x2[k] > x1[k])
-            {
+          {
             nextX = vtkMath::Floor(lastX + VTKCELLPICKER_VOXEL_TOL) + 1;
-            }
+          }
           else
-            {
+          {
             nextX = vtkMath::Ceil(lastX - VTKCELLPICKER_VOXEL_TOL) - 1;
-            }
+          }
 
           // Compute the "t" value for this slice boundary
           double ttry = lastT + (nextX - lastX)/(x2[k] - x1[k]);
           if (ttry > lastT + tTol && ttry < t)
-            {
+          {
             t = ttry;
-            }
           }
         }
-      } // End of "while (t <= t2)"
+      }
+
+      // Break if far clipping plane has been reached
+      if (t >= 1.0)
+      {
+        t = 1.0;
+        break;
+      }
+    } // End of "while (t <= t2)"
 
     // If the ray hit the isosurface, compute the isosurface position
     if (opacity > opacityThreshold)
-      {
+    {
       // Backtrack to the actual surface position unless this was first step
       if (t > t1)
-        {
+      {
         double f = (opacityThreshold - lastOpacity)/(opacity - lastOpacity);
         t = lastT*(1.0 - f) + t*f;
         for (int j = 0; j < 3; j++)
-          {
+        {
           x[j] = x1[j]*(1.0 - t) + x2[j]*t;
           if (x[j] < extent[2*j]) { x[j] = extent[2*j]; }
           else if (x[j] > extent[2*j + 1]) { x[j] = extent[2*j+1]; }
           xi[j] = vtkMath::Floor(x[j]);
           pcoords[j] = x[j] - xi[j];
-          }
         }
+      }
 
       // Check to see if this is the new global minimum
       if (t < tMin && t < this->GlobalTMin)
-        {
+      {
         this->ResetPickInfo();
         tMin = t;
 
@@ -842,18 +854,18 @@ double vtkCellPicker::IntersectVolumeWithLine(const double p1[3],
         // is the boundary of the volume.  If this is the case, use the
         // normal of the boundary.
         if (t == t1 && planeId >= 0 && xi[planeId/2] == extent[planeId])
-          {
+        {
           this->MapperNormal[0] = 0.0;
           this->MapperNormal[1] = 0.0;
           this->MapperNormal[2] = 0.0;
           this->MapperNormal[planeId/2] = 2.0*(planeId%2) - 1.0;
           if (spacing[planeId/2] < 0)
-            {
-            this->MapperNormal[planeId/2] = - this->MapperNormal[planeId/2];
-            }
-          }
-        else
           {
+            this->MapperNormal[planeId/2] = - this->MapperNormal[planeId/2];
+          }
+        }
+        else
+        {
           // Set the normal from the direction of the gradient
           int *ci = this->CellIJK;
           double weights[8];
@@ -862,24 +874,24 @@ double vtkCellPicker::IntersectVolumeWithLine(const double p1[3],
                                  this->Gradients);
           double v[3]; v[0] = v[1] = v[2] = 0.0;
           for (int k = 0; k < 8; k++)
-            {
+          {
             double *pg = this->Gradients->GetTuple(k);
             v[0] += pg[0]*weights[k];
             v[1] += pg[1]*weights[k];
             v[2] += pg[2]*weights[k];
-            }
+          }
 
           double norm = vtkMath::Norm(v);
           if (norm > 0)
-            {
+          {
             this->MapperNormal[0] = v[0]/norm;
             this->MapperNormal[1] = v[1]/norm;
             this->MapperNormal[2] = v[2]/norm;
-            }
           }
-        } // End of "if (opacity > opacityThreshold)"
-      } // End of "if (t < tMin && t < this->GlobalTMin)"
-    } // End of loop over volume components
+        }
+      } // End of "if (opacity > opacityThreshold)"
+    } // End of "if (t < tMin && t < this->GlobalTMin)"
+  } // End of loop over volume components
 
   scalars->Delete();
 
@@ -909,12 +921,12 @@ double vtkCellPicker::IntersectImageWithLine(const double p1[3],
   if (normal[0]*(p1[0] - p2[0]) +
       normal[1]*(p1[1] - p2[1]) +
       normal[2]*(p1[2] - p2[2]) < 0)
-    {
+  {
     normal[0] = -normal[0];
     normal[1] = -normal[1];
     normal[2] = -normal[2];
     normal[3] = -normal[3];
-    }
+  }
 
   // And finally convert normal to structured coords
   double xnormal[4];
@@ -931,10 +943,10 @@ double vtkCellPicker::IntersectImageWithLine(const double p1[3],
   // Also convert ray to structured coords
   double x1[3], x2[3];
   for (int i = 0; i < 3; i++)
-    {
+  {
     x1[i] = (p1[i] - origin[i])/spacing[i];
     x2[i] = (p2[i] - origin[i])/spacing[i];
-    }
+  }
 
   // Get the bounds to discover any cropping that has been applied
   double bounds[6];
@@ -942,73 +954,80 @@ double vtkCellPicker::IntersectImageWithLine(const double p1[3],
 
   // Convert bounds to structured coords
   for (int k = 0; k < 3; k++)
-    {
+  {
     bounds[2*k] = (bounds[2*k] - origin[k])/spacing[k];
     bounds[2*k+1] = (bounds[2*k+1] - origin[k])/spacing[k];
     // It should be a multiple of 0.5, so round to closest multiple of 0.5
     // (this reduces the impact of roundoff error from the above computation)
     bounds[2*k] = 0.5*vtkMath::Round(2.0*(bounds[2*k]));
     bounds[2*k+1] = 0.5*vtkMath::Round(2.0*(bounds[2*k+1]));
+    // Reverse if spacing is negative
+    if (spacing[k] < 0)
+    {
+      double bt = bounds[2*k];
+      bounds[2*k] = bounds[2*k+1];
+      bounds[2*k+1] = bt;
     }
+  }
 
   // Clip the ray with the extent
   int planeId, plane2Id;
   double tMin, tMax;
   if (!vtkBox::IntersectWithLine(bounds, x1, x2, tMin, tMax, 0, 0,
         planeId, plane2Id))
-    {
+  {
     return VTK_DOUBLE_MAX;
-    }
+  }
 
   if (tMin != tMax)
-    {
+  {
     // Intersect the ray with the slice plane
     double w1 = vtkMath::Dot(x1, xnormal) + xnormal[3];
     double w2 = vtkMath::Dot(x2, xnormal) + xnormal[3];
     if (w1*w2 > VTKCELLPICKER_VOXEL_TOL)
-      {
+    {
       return VTK_DOUBLE_MAX;
-      }
-    if (w1*w2 < 0)
-      {
-      tMin = w1/(w1 - w2);
-      }
     }
+    if (w1*w2 < 0)
+    {
+      tMin = w1/(w1 - w2);
+    }
+  }
 
   // Make sure that intersection is within clipping planes
   if (tMin < t1 || tMin > t2)
-    {
+  {
     return VTK_DOUBLE_MAX;
-    }
+  }
 
   if (tMin < this->GlobalTMin)
-    {
+  {
     // Compute the pick position in structured coords
     double x[3];
     for (int j = 0; j < 3; j++)
-      {
+    {
       x[j] = x1[j]*(1.0 - tMin) + x2[j]*tMin;
 
       // Do a bounds check.  If beyond tolerance of bound, then
       // pick failed, but if within tolerance, clamp the coord
       // to the bound for robustness against roundoff errors.
       if (x[j] < bounds[2*j])
-        {
+      {
         if (x[j] < bounds[2*j] - VTKCELLPICKER_VOXEL_TOL)
-          {
-          return VTK_DOUBLE_MAX;
-          }
-        x[j] = bounds[2*j];
-        }
-      else if (x[j] > bounds[2*j+1])
         {
-        if (x[j] > bounds[2*j+1] + VTKCELLPICKER_VOXEL_TOL)
-          {
           return VTK_DOUBLE_MAX;
-          }
-        x[j] = bounds[2*j + 1];
         }
+        x[j] = bounds[2*j];
       }
+      else if (x[j] > bounds[2*j+1])
+      {
+        if (x[j] > bounds[2*j+1] + VTKCELLPICKER_VOXEL_TOL)
+        {
+          return VTK_DOUBLE_MAX;
+        }
+        x[j] = bounds[2*j + 1];
+      }
+    }
 
     this->ResetPickInfo();
     this->Mapper = imageMapper;
@@ -1025,7 +1044,7 @@ double vtkCellPicker::IntersectImageWithLine(const double p1[3],
     this->MapperNormal[0] = normal[0];
     this->MapperNormal[1] = normal[1];
     this->MapperNormal[2] = normal[2];
-    }
+  }
 
   return tMin;
 }
@@ -1063,7 +1082,7 @@ int vtkCellPicker::ClipLineWithPlanes(vtkAbstractMapper3D *mapper,
   double plane[4];
   int numClipPlanes = mapper->GetNumberOfClippingPlanes();
   for (int i = 0; i < numClipPlanes; i++)
-    {
+  {
     mapper->GetClippingPlaneInDataCoords(mat, i, plane);
 
     double d1 = plane[0]*p1[0] + plane[1]*p1[1] + plane[2]*p1[2] + plane[3];
@@ -1071,47 +1090,47 @@ int vtkCellPicker::ClipLineWithPlanes(vtkAbstractMapper3D *mapper,
 
     // If both distances are negative, both points are outside
     if (d1 < 0 && d2 < 0)
-      {
+    {
       return 0;
-      }
+    }
     // If only one of the distances is negative, the line crosses the plane
     else if (d1 < 0 || d2 < 0)
-      {
+    {
       // Compute fractional distance "t" of the crossing between p1 & p2
       double t = 0.0;
 
       // The "if" here just avoids an expensive division when possible
       if (d1 != 0)
-        {
+      {
         // We will never have d1==d2 since they have different signs
         t = d1/(d1 - d2);
-        }
+      }
 
       // If point p1 was clipped, adjust t1
       if (d1 < 0)
-        {
+      {
         if (t >= t1)
-          {
+        {
           t1 = t;
           planeId = i;
-          }
         }
+      }
       // else point p2 was clipped, so adjust t2
       else
-        {
+      {
         if (t <= t2)
-          {
+        {
           t2 = t;
-          }
         }
+      }
 
       // If this happens, there's no line left
       if (t1 > t2)
-        {
+      {
         return 0;
-        }
       }
     }
+  }
 
   return 1;
 }
@@ -1147,27 +1166,27 @@ int vtkCellPicker::ComputeSurfaceNormal(vtkDataSet *data, vtkCell *cell,
   vtkDataArray *normals = data->GetPointData()->GetNormals();
 
   if (normals)
-    {
+  {
     normal[0] = normal[1] = normal[2] = 0.0;
     double pointNormal[3];
     vtkIdType numPoints = cell->GetNumberOfPoints();
     for (vtkIdType k = 0; k < numPoints; k++)
-      {
+    {
       normals->GetTuple(cell->PointIds->GetId(k), pointNormal);
       normal[0] += pointNormal[0]*weights[k];
       normal[1] += pointNormal[1]*weights[k];
       normal[2] += pointNormal[2]*weights[k];
-      }
+    }
     vtkMath::Normalize(normal);
-    }
+  }
   else if (cell->GetCellDimension() == 2)
-    {
+  {
     vtkPolygon::ComputeNormal(cell->Points, normal);
-    }
+  }
   else
-    {
+  {
     return 0;
-    }
+  }
 
   return 1;
 }
@@ -1182,23 +1201,23 @@ int vtkCellPicker::ComputeSurfaceTCoord(vtkDataSet *data, vtkCell *cell,
   vtkDataArray *tcoords = data->GetPointData()->GetTCoords();
 
   if (tcoords)
-    {
+  {
     tcoord[0] = tcoord[1] = tcoord[2] = 0.0;
     double pointTCoord[3];
 
     int numComponents = tcoords->GetNumberOfComponents();
     vtkIdType numPoints = cell->GetNumberOfPoints();
     for (vtkIdType k = 0; k < numPoints; k++)
-      {
+    {
       tcoords->GetTuple(cell->PointIds->GetId(k), pointTCoord);
       for (int i = 0; i < numComponents; i++)
-        {
+      {
         tcoord[i] += pointTCoord[i]*weights[k];
-        }
       }
+    }
 
     return 1;
-    }
+  }
 
   return 0;
 }
@@ -1208,9 +1227,9 @@ int vtkCellPicker::ComputeSurfaceTCoord(vtkDataSet *data, vtkCell *cell,
 void vtkCellPicker::SubCellFromCell(vtkGenericCell *cell, int subId)
 {
   switch(cell->GetCellType())
-    {
+  {
     case VTK_TRIANGLE_STRIP:
-      {
+    {
       static int idx[2][3]={{0,1,2},{1,0,2}};
       int *order = idx[subId & 1];
       vtkIdType pointIds[3];
@@ -1233,11 +1252,11 @@ void vtkCellPicker::SubCellFromCell(vtkGenericCell *cell, int subId)
       cell->Points->SetPoint(0, points[0]);
       cell->Points->SetPoint(1, points[1]);
       cell->Points->SetPoint(2, points[2]);
-      }
+    }
       break;
 
     case VTK_POLY_LINE:
-      {
+    {
       vtkIdType pointIds[2];
       double points[2][3];
 
@@ -1254,11 +1273,11 @@ void vtkCellPicker::SubCellFromCell(vtkGenericCell *cell, int subId)
 
       cell->Points->SetPoint(0, points[0]);
       cell->Points->SetPoint(1, points[1]);
-      }
+    }
       break;
 
     case VTK_POLY_VERTEX:
-      {
+    {
       double point[3];
 
       vtkIdType pointId = cell->PointIds->GetId(subId);
@@ -1268,22 +1287,21 @@ void vtkCellPicker::SubCellFromCell(vtkGenericCell *cell, int subId)
 
       cell->PointIds->SetId(0, pointId);
       cell->Points->SetPoint(0, point);
-      }
+    }
       break;
-   }
+  }
 }
 
 //----------------------------------------------------------------------------
 int vtkCellPicker::HasSubCells(int cellType)
 {
   switch (cellType)
-    {
+  {
     case VTK_TRIANGLE_STRIP:
     case VTK_POLY_LINE:
     case VTK_POLY_VERTEX:
       return 1;
-      break;
-    }
+  }
 
   return 0;
 }
@@ -1293,19 +1311,16 @@ int vtkCellPicker::HasSubCells(int cellType)
 int vtkCellPicker::GetNumberOfSubCells(vtkIdList *pointIds, int cellType)
 {
   switch (cellType)
-    {
+  {
     case VTK_TRIANGLE_STRIP:
       return pointIds->GetNumberOfIds() - 2;
-      break;
 
     case VTK_POLY_LINE:
       return pointIds->GetNumberOfIds() - 1;
-      break;
 
     case VTK_POLY_VERTEX:
       return pointIds->GetNumberOfIds();
-      break;
-    }
+  }
 
   return 0;
 }
@@ -1317,9 +1332,9 @@ void vtkCellPicker::GetSubCell(vtkDataSet *data, vtkIdList *ptIds, int subId,
                                int cellType, vtkGenericCell *cell)
 {
   switch(cellType)
-    {
+  {
     case VTK_TRIANGLE_STRIP:
-      {
+    {
       static int idx[2][3]={{0,1,2},{1,0,2}};
       int *order = idx[subId & 1];
       vtkIdType pointIds[3];
@@ -1342,11 +1357,11 @@ void vtkCellPicker::GetSubCell(vtkDataSet *data, vtkIdList *ptIds, int subId,
       cell->Points->SetPoint(0, points[0]);
       cell->Points->SetPoint(1, points[1]);
       cell->Points->SetPoint(2, points[2]);
-      }
+    }
       break;
 
     case VTK_POLY_LINE:
-      {
+    {
       vtkIdType pointIds[2];
       double points[2][3];
 
@@ -1363,11 +1378,11 @@ void vtkCellPicker::GetSubCell(vtkDataSet *data, vtkIdList *ptIds, int subId,
 
       cell->Points->SetPoint(0, points[0]);
       cell->Points->SetPoint(1, points[1]);
-      }
+    }
       break;
 
     case VTK_POLY_VERTEX:
-      {
+    {
       double point[3];
 
       vtkIdType pointId = ptIds->GetId(subId);
@@ -1377,9 +1392,9 @@ void vtkCellPicker::GetSubCell(vtkDataSet *data, vtkIdList *ptIds, int subId,
 
       cell->PointIds->SetId(0, pointId);
       cell->Points->SetPoint(0, point);
-      }
-      break;
     }
+      break;
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -1390,7 +1405,7 @@ void vtkCellPicker::SetImageDataPickInfo(const double x[3],
                                             const int extent[6])
 {
   for (int j = 0; j < 3; j++)
-    {
+  {
     double xj = x[j];
     if (xj < extent[2*j]) { xj = extent[2*j]; }
     if (xj > extent[2*j+1]) { xj = extent[2*j+1]; }
@@ -1400,12 +1415,12 @@ void vtkCellPicker::SetImageDataPickInfo(const double x[3],
     // Keep the cell in-bounds if it is on the edge
     if (this->CellIJK[j] == extent[2*j+1] &&
         this->CellIJK[j] > extent[2*j])
-      {
+    {
       this->CellIJK[j] -= 1;
       this->PCoords[j] = 1.0;
-      }
-    this->PointIJK[j] = this->CellIJK[j] + (this->PCoords[j] >= 0.5);
     }
+    this->PointIJK[j] = this->CellIJK[j] + (this->PCoords[j] >= 0.5);
+  }
 
   // Stupid const/non-const, and I hate const_cast
   int ext[6];
@@ -1454,43 +1469,41 @@ double vtkCellPicker::ComputeVolumeOpacity(
   vtkIdType ptId = data->ComputePointId(const_cast<int *>(xi));
   double val = 0.0;
   for (int j = 0; j < 8; j++)
-    {
+  {
     vtkIdType ptInc = (j & 1)*xInc + ((j>>1) & 1)*yInc + ((j>>2) & 1)*zInc;
     val += weights[j]*scalars->GetComponent(ptId + ptInc, 0);
-    }
+  }
 
   // Compute the ScalarOpacity
   if (scalarOpacity)
-    {
+  {
     opacity *= scalarOpacity->GetValue(val);
-    }
+  }
   else if (scalarType == VTK_FLOAT || scalarType == VTK_DOUBLE)
-    {
+  {
     opacity *= val;
-    }
+  }
   else
-    {
+  {
     // Assume unsigned char
     opacity *= val/255.0;
-    }
+  }
 
   // Compute gradient and GradientOpacity
   if (gradientOpacity)
-    {
+  {
     data->GetVoxelGradient(xi[0], xi[1], xi[2], scalars, this->Gradients);
     double v[3]; v[0] = v[1] = v[2] = 0.0;
     for (int k = 0; k < 8; k++)
-      {
+    {
       double *pg = this->Gradients->GetTuple(k);
       v[0] += pg[0]*weights[k];
       v[1] += pg[1]*weights[k];
       v[2] += pg[2]*weights[k];
-      }
+    }
     double grad = sqrt(v[0]*v[0] + v[1]*v[1] + v[2]*v[2]);
     opacity *= gradientOpacity->GetValue(grad);
-    }
+  }
 
   return opacity;
 }
-
-
