@@ -47,6 +47,8 @@ vtkHeatmapItem::vtkHeatmapItem() : PositionVector(0, 0)
   this->Interactive = true;
   this->HeatmapBuildTime = 0;
   this->Table = vtkSmartPointer<vtkTable>::New();
+  this->NameColumn = "name";
+  this->RowNames = NULL;
 
   this->CollapsedRowsArray = NULL;
   this->CollapsedColumnsArray = NULL;
@@ -100,11 +102,30 @@ vtkVector2f vtkHeatmapItem::GetPositionVector()
 void vtkHeatmapItem::SetTable(vtkTable *table)
 {
   if (table == NULL || table->GetNumberOfRows() == 0)
-    {
+  {
     this->Table = vtkSmartPointer<vtkTable>::New();
     return;
-    }
+  }
   this->Table = table;
+
+  // get the row names for this table
+  vtkStringArray *rowNames = vtkArrayDownCast<vtkStringArray>(
+    this->Table->GetColumnByName(this->NameColumn));
+  if (rowNames == NULL)
+  {
+    rowNames = vtkArrayDownCast<vtkStringArray>(
+      this->Table->GetColumn(0));
+  }
+  if (rowNames == NULL)
+  {
+    vtkWarningMacro("Could not determine row name column."
+      "Try calling vtkHeatmapItem::SetNameColumn(vtkStdString)");
+    this->RowNames = NULL;
+  }
+  else
+  {
+    this->RowNames = rowNames;
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -113,18 +134,24 @@ vtkTable * vtkHeatmapItem::GetTable()
   return this->Table;
 }
 
+//-----------------------------------------------------------------------------
+vtkStringArray * vtkHeatmapItem::GetRowNames()
+{
+  return this->RowNames;
+}
+
 //-----------------------------------------------------------------------------
 bool vtkHeatmapItem::Paint(vtkContext2D *painter)
 {
   if (this->Table->GetNumberOfRows() == 0)
-    {
+  {
     return true;
-    }
+  }
 
   if (this->IsDirty())
-    {
+  {
     this->RebuildBuffers();
-    }
+  }
 
   this->PaintBuffers(painter);
   this->PaintChildren(painter);
@@ -135,13 +162,13 @@ bool vtkHeatmapItem::Paint(vtkContext2D *painter)
 bool vtkHeatmapItem::IsDirty()
 {
   if (this->Table->GetNumberOfRows() == 0)
-    {
+  {
     return false;
-    }
+  }
   if (this->Table->GetMTime() > this->HeatmapBuildTime)
-    {
+  {
     return true;
-    }
+  }
   return false;
 }
 
@@ -149,15 +176,15 @@ bool vtkHeatmapItem::IsDirty()
 void vtkHeatmapItem::RebuildBuffers()
 {
   if (this->Table->GetNumberOfRows() == 0)
-    {
+  {
     return;
-    }
+  }
 
   this->InitializeLookupTables();
 
-  this->CollapsedRowsArray = vtkBitArray::SafeDownCast(
+  this->CollapsedRowsArray = vtkArrayDownCast<vtkBitArray>(
     this->Table->GetFieldData()->GetArray("collapsed rows"));
-  this->CollapsedColumnsArray = vtkBitArray::SafeDownCast(
+  this->CollapsedColumnsArray = vtkArrayDownCast<vtkBitArray>(
     this->Table->GetFieldData()->GetArray("collapsed columns"));
 
   this->HeatmapBuildTime = this->Table->GetMTime();
@@ -169,30 +196,34 @@ void vtkHeatmapItem::InitializeLookupTables()
   this->ColumnRanges.clear();
   this->CategoricalDataValues->Reset();
 
-  for (vtkIdType column = 1; column < this->Table->GetNumberOfColumns();
+  for (vtkIdType column = 0; column < this->Table->GetNumberOfColumns();
        ++column)
+  {
+    if (this->Table->GetColumn(column) == this->GetRowNames())
     {
+      continue;
+    }
     if (this->Table->GetValue(0, column).IsString())
-      {
+    {
       this->AccumulateProminentCategoricalDataValues(column);
       continue;
-      }
+    }
     double min = VTK_DOUBLE_MAX;
     double max = VTK_DOUBLE_MIN;
     for (vtkIdType row = 0; row < this->Table->GetNumberOfRows(); ++row)
-      {
+    {
       double value = this->Table->GetValue(row, column).ToDouble();
       if (value > max)
-        {
+      {
         max = value;
-        }
-      if (value < min)
-        {
-        min = value;
-        }
       }
-    this->ColumnRanges[column] = std::pair<double, double>(min, max);
+      if (value < min)
+      {
+        min = value;
+      }
     }
+    this->ColumnRanges[column] = std::pair<double, double>(min, max);
+  }
 
   this->GenerateCategoricalDataLookupTable();
   this->GenerateContinuousDataLookupTable();
@@ -208,24 +239,24 @@ void vtkHeatmapItem::GenerateContinuousDataLookupTable()
 
   // black to red
   for (int i = 0; i < 85; ++i)
-    {
+  {
     float f = static_cast<float>(i) / 84.0;
     this->ContinuousDataLookupTable->SetTableValue(i, f, 0, 0);
-    }
+  }
 
  // red to yellow
   for (int i = 0; i < 85; ++i)
-    {
+  {
     float f = static_cast<float>(i) / 84.0;
     this->ContinuousDataLookupTable->SetTableValue(85 + i, 1.0, f, 0);
-    }
+  }
 
  // yellow to white
   for (int i = 0; i < 85; ++i)
-    {
+  {
     float f = static_cast<float>(i) / 84.0;
     this->ContinuousDataLookupTable->SetTableValue(170 + i, 1.0, 1.0, f);
-    }
+  }
 
   this->ColorLegendLookupTable->DeepCopy(
     this->ContinuousDataLookupTable.GetPointer());
@@ -236,7 +267,7 @@ void vtkHeatmapItem::GenerateContinuousDataLookupTable()
 //-----------------------------------------------------------------------------
 void vtkHeatmapItem::AccumulateProminentCategoricalDataValues(vtkIdType column)
 {
-  vtkStringArray *stringColumn = vtkStringArray::SafeDownCast(
+  vtkStringArray *stringColumn = vtkArrayDownCast<vtkStringArray>(
     this->Table->GetColumn(column));
 
   // search for values that occur more than once
@@ -244,27 +275,27 @@ void vtkHeatmapItem::AccumulateProminentCategoricalDataValues(vtkIdType column)
   std::map<std::string, int> CountMap;
   std::map<std::string, int>::iterator mapItr;
   for (int i = 0; i < stringColumn->GetNumberOfTuples(); ++i)
-    {
+  {
     CountMap[stringColumn->GetValue(i)]++;
-    }
+  }
 
   for (mapItr = CountMap.begin(); mapItr != CountMap.end(); ++mapItr)
-    {
+  {
     if (mapItr->second > 1)
-      {
+    {
       repeatedValues->InsertNextValue(mapItr->first);
-      }
     }
+  }
 
   // add each distinct, repeated value from this column to our master list
   for (int i = 0; i < repeatedValues->GetNumberOfTuples(); ++i)
-    {
+  {
     vtkVariant v = repeatedValues->GetVariantValue(i);
     if (this->CategoricalDataValues->LookupValue(v) == -1)
-      {
+    {
       this->CategoricalDataValues->InsertNextValue(v.ToString());
-      }
     }
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -275,11 +306,11 @@ void vtkHeatmapItem::GenerateCategoricalDataLookupTable()
 
   // make each distinct categorical value an index into our lookup table
   for (int i = 0; i < this->CategoricalDataValues->GetNumberOfTuples(); ++i)
-    {
+  {
     this->CategoricalDataLookupTable->SetAnnotation(
       this->CategoricalDataValues->GetValue(i),
       this->CategoricalDataValues->GetValue(i));
-    }
+  }
 
   vtkNew<vtkColorSeries> colorSeries;
   colorSeries->SetColorScheme(vtkColorSeries::BREWER_QUALITATIVE_SET3);
@@ -308,10 +339,6 @@ void vtkHeatmapItem::PaintBuffers(vtkContext2D *painter)
   double labelStartX = 0.0;
   double labelStartY = 0.0;
 
-  // the name of each row.
-  vtkStringArray *rowNames = vtkStringArray::SafeDownCast(
-    this->Table->GetColumn(0));
-
   bool currentlyCollapsingRows = false;
 
   bool currentlyCollapsingColumns = false;
@@ -336,9 +363,9 @@ void vtkHeatmapItem::PaintBuffers(vtkContext2D *painter)
   //canDrawText is set to false if we're too zoomed out to draw legible text.
   bool canDrawText = true;
   if (fontSize < 8)
-    {
+  {
     canDrawText = false;
-    }
+  }
   bool drawRowLabels = canDrawText;
   bool drawColumnLabels = canDrawText;
 
@@ -346,78 +373,78 @@ void vtkHeatmapItem::PaintBuffers(vtkContext2D *painter)
 
   // Detect if our row or column labels would be currently visible on screen.
   if (canDrawText)
-    {
+  {
     switch (orientation)
-      {
+    {
       case vtkHeatmapItem::DOWN_TO_UP:
         if (this->SceneBottomLeft[1] > this->MaxY + spacing ||
             this->SceneTopRight[1] < this->MaxY + spacing)
-          {
+        {
           drawRowLabels = false;
-          }
+        }
         if (this->SceneBottomLeft[0] > this->MaxX + spacing ||
             this->SceneTopRight[0] < this->MaxX + spacing)
-          {
+        {
           drawColumnLabels = false;
-          }
+        }
         break;
 
       case vtkHeatmapItem::RIGHT_TO_LEFT:
         if (this->SceneBottomLeft[0] > this->MinX - spacing ||
             this->SceneTopRight[0] < this->MinX - spacing)
-          {
+        {
           drawRowLabels = false;
-          }
+        }
         else
-          {
+        {
           painter->GetTextProp()->SetJustificationToRight();
-          }
+        }
         if (this->SceneBottomLeft[1] > this->MaxY + spacing &&
             this->SceneTopRight[1] < this->MaxY + spacing)
-          {
+        {
           drawColumnLabels = false;
-          }
+        }
         break;
 
       case vtkHeatmapItem::UP_TO_DOWN:
         if (this->SceneBottomLeft[1] > this->MinY - spacing ||
             this->SceneTopRight[1] < this->MinY - spacing)
-          {
+        {
           drawRowLabels = false;
-          }
+        }
         else
-          {
+        {
           painter->GetTextProp()->SetJustificationToRight();
-          }
+        }
         if (this->SceneBottomLeft[0] > this->MaxX + spacing ||
             this->SceneTopRight[0] < this->MaxX + spacing)
-          {
+        {
           drawColumnLabels = false;
-          }
+        }
         break;
 
       case vtkHeatmapItem::LEFT_TO_RIGHT:
       default:
         if (this->SceneBottomLeft[0] > this->MaxX + spacing ||
             this->SceneTopRight[0] < this->MaxX + spacing)
-          {
+        {
           drawRowLabels = false;
-          }
+        }
         if (this->SceneBottomLeft[1] > this->MaxY + spacing &&
             this->SceneTopRight[1] < this->MaxY + spacing)
-          {
+        {
           drawColumnLabels = false;
-          }
+        }
         break;
-      }
     }
+  }
 
   // set the orientation of our text property to draw row names
   if (drawRowLabels)
-    {
+  {
     painter->GetTextProp()->SetOrientation(
       this->GetTextAngleForOrientation(orientation));
-    }
+  }
 
   // keep track of what row & column we're drawing next
   vtkIdType rowToDraw = 0;
@@ -425,62 +452,68 @@ void vtkHeatmapItem::PaintBuffers(vtkContext2D *painter)
   bool columnMapSet = false;
 
   for (vtkIdType row = 0; row != this->Table->GetNumberOfRows(); ++row)
-    {
+  {
     // check if this row has been collapsed or not
     if (this->CollapsedRowsArray && this->CollapsedRowsArray->GetValue(row) == 1)
-      {
+    {
       // a contiguous block of collapsed rows is represented as a single blank
       // row by this item.
       if (!currentlyCollapsingRows)
-        {
+      {
         this->SceneRowToTableRowMap[rowToDraw] = -1;
         ++rowToDraw;
         currentlyCollapsingRows = true;
-        }
-      continue;
       }
+      continue;
+    }
     currentlyCollapsingRows = false;
 
     // get the name of this row
     std::string name = "";
-    if (rowNames)
-      {
-      name = rowNames->GetValue(row);
-      }
+    if (this->RowNames)
+    {
+      name = this->RowNames->GetValue(row);
+    }
 
     // only draw the cells of this row if it isn't explicitly marked as blank
     if (this->BlankRows.find(name) == this->BlankRows.end())
-      {
+    {
       columnToDraw = 0;
-      for (vtkIdType column = 1; column < this->Table->GetNumberOfColumns();
+      for (vtkIdType column = 0; column < this->Table->GetNumberOfColumns();
            ++column)
+      {
+        // don't draw the name column as part of the heatmap
+        // (it's used later to label the rows instead)
+        if (this->Table->GetColumn(column) == this->GetRowNames())
         {
+          continue;
+        }
 
         // check if this column has been collapsed or not
         if (this->CollapsedColumnsArray &&
             this->CollapsedColumnsArray->GetValue(column) == 1)
-          {
+        {
           // a contiguous block of collapsed columns is represented as a single blank
           // column by this item.
           if (!currentlyCollapsingColumns)
-            {
+          {
             this->SceneColumnToTableColumnMap[columnToDraw] = -1;
             ++columnToDraw;
             currentlyCollapsingColumns = true;
-            }
-          continue;
           }
+          continue;
+        }
         currentlyCollapsingColumns = false;
 
         // get the color for this cell from the lookup table
         double color[4];
         vtkVariant value = this->Table->GetValue(row, column);
         if (value.IsString())
-          {
+        {
           this->CategoricalDataLookupTable->GetAnnotationColor(value, color);
-          }
+        }
         else
-          {
+        {
           // set the range on our continuous lookup table for this column
           this->ContinuousDataLookupTable->SetRange(
             this->ColumnRanges[column].first,
@@ -488,14 +521,14 @@ void vtkHeatmapItem::PaintBuffers(vtkContext2D *painter)
 
           // get the color for this value
           this->ContinuousDataLookupTable->GetColor(value.ToDouble(), color);
-          }
+        }
         painter->GetBrush()->SetColorF(color[0], color[1], color[2]);
 
         // draw this cell of the table
         double w = 0.0;
         double h = 0.0;
         switch(orientation)
-          {
+        {
           case vtkHeatmapItem::DOWN_TO_UP:
             cellStartX = this->Position[0] + this->CellHeight * rowToDraw;
             cellStartY = this->MinY + this->CellWidth * columnToDraw;
@@ -524,38 +557,38 @@ void vtkHeatmapItem::PaintBuffers(vtkContext2D *painter)
             w = this->CellWidth;
             h = this->CellHeight;
             break;
-          }
+        }
 
         if (this->LineIsVisible(cellStartX, cellStartY,
                                 cellStartX + this->CellWidth,
                                 cellStartY + this->CellHeight) ||
             this->LineIsVisible(cellStartX, cellStartY + this->CellHeight,
                                 cellStartX + this->CellWidth, cellStartY))
-          {
+        {
           painter->DrawRect(cellStartX, cellStartY, w, h);
-          }
+        }
 
         if (!columnMapSet)
-          {
+        {
           this->SceneColumnToTableColumnMap[columnToDraw] = column;
-          }
+        }
 
         ++columnToDraw;
-        }
-      columnMapSet = true;
       }
+      columnMapSet = true;
+    }
 
     this->SceneRowToTableRowMap[rowToDraw] = row;
     ++rowToDraw;
 
     // draw this row's label if it would be visible
     if (!drawRowLabels)
-      {
+    {
       continue;
-      }
+    }
 
     switch (orientation)
-      {
+    {
       case vtkHeatmapItem::DOWN_TO_UP:
         labelStartX = cellStartX + this->CellHeight / 2.0;
         labelStartY = this->MaxY + spacing;
@@ -573,37 +606,37 @@ void vtkHeatmapItem::PaintBuffers(vtkContext2D *painter)
         labelStartX = this->MaxX + spacing;
         labelStartY = cellStartY + this->CellHeight / 2.0;
         break;
-      }
+    }
 
     if (name != "" &&
         this->SceneBottomLeft[0] < labelStartX &&
         this->SceneTopRight[0] > labelStartX   &&
         this->SceneBottomLeft[1] < labelStartY &&
         this->SceneTopRight[1] > labelStartY)
-      {
+    {
       painter->DrawString(labelStartX, labelStartY, name);
-      }
     }
+  }
 
   // draw column labels
   if (!canDrawText)
-    {
+  {
     this->RowLabelWidth = 0.0;
     this->ColumnLabelWidth = 0.0;
     return;
-    }
+  }
 
   if (!drawColumnLabels)
-    {
+  {
     this->ComputeLabelWidth(painter);
     this->ColumnLabelWidth = 0.0;
     return;
-    }
+  }
 
   // set up our text property to draw column labels appropriately for
   // the current orientation.
   switch (orientation)
-    {
+  {
     case vtkHeatmapItem::DOWN_TO_UP:
     case vtkHeatmapItem::UP_TO_DOWN:
       painter->GetTextProp()->SetOrientation(0);
@@ -614,31 +647,38 @@ void vtkHeatmapItem::PaintBuffers(vtkContext2D *painter)
     default:
       painter->GetTextProp()->SetOrientation(90);
       break;
-    }
+  }
 
   painter->GetTextProp()->SetJustificationToLeft();
 
   columnToDraw = 1;
-  for (vtkIdType column = 1; column < this->Table->GetNumberOfColumns();
+  for (vtkIdType column = 0; column < this->Table->GetNumberOfColumns();
        ++column)
+  {
+    // don't draw the name column as part of the heatmap
+    // (it's used later to label the rows instead)
+    if (this->Table->GetColumn(column) == this->GetRowNames())
     {
+      continue;
+    }
+
     // check if this column has been collapsed or not
     if (this->CollapsedColumnsArray &&
         this->CollapsedColumnsArray->GetValue(column) == 1)
-      {
+    {
       // a contiguous block of collapsed columns is represented as a single blank
       // column by this item.
       if (!currentlyCollapsingColumns)
-        {
+      {
         ++columnToDraw;
         currentlyCollapsingColumns = true;
-        }
-      continue;
       }
+      continue;
+    }
     currentlyCollapsingColumns = false;
 
     switch(orientation)
-      {
+    {
       case vtkHeatmapItem::DOWN_TO_UP:
       case vtkHeatmapItem::UP_TO_DOWN:
         labelStartX = this->MaxX + spacing;
@@ -653,18 +693,18 @@ void vtkHeatmapItem::PaintBuffers(vtkContext2D *painter)
           this->MinX + this->CellWidth * columnToDraw - this->CellWidth / 2;
         labelStartY = this->MaxY + spacing;
         break;
-      }
+    }
 
     std::string columnName = this->Table->GetColumn(column)->GetName();
     if (this->SceneBottomLeft[0] < labelStartX &&
         this->SceneTopRight[0] > labelStartX &&
         this->SceneBottomLeft[1] < labelStartY &&
         this->SceneTopRight[1] > labelStartY)
-      {
+    {
       painter->DrawString(labelStartX, labelStartY, columnName);
-      }
-    ++columnToDraw;
     }
+    ++columnToDraw;
+  }
 
   // update the size of our labels
   this->ComputeLabelWidth(painter);
@@ -706,50 +746,50 @@ bool vtkHeatmapItem::LineIsVisible(double x0, double y0,
         yMinScene <= y0 && yMaxScene >= y0) ||
        (xMinScene <= x1 && xMaxScene >= x1 &&
         yMinScene <= y1 && yMaxScene >= y1) )
-    {
+  {
     return true;
-    }
+  }
 
   // figure out which end point is "greater" than the other in both dimensions
   double xMinLine, xMaxLine, yMinLine, yMaxLine;
   if (x0 < x1)
-    {
+  {
     xMinLine = x0;
     xMaxLine = x1;
-    }
+  }
   else
-    {
+  {
     xMinLine = x1;
     xMaxLine = x0;
-    }
+  }
   if (y0 < y1)
-    {
+  {
     yMinLine = y0;
     yMaxLine = y1;
-    }
+  }
   else
-    {
+  {
     yMinLine = y1;
     yMaxLine = y0;
-    }
+  }
 
   // case where the Y range of the line falls within the visible scene
   // and the X range of the line contains the entire visible scene
   if (yMinScene <= yMinLine && yMaxScene >= yMinLine &&
       yMinScene <= yMaxLine && yMaxScene >= yMaxLine &&
       xMinLine <= xMinScene && xMaxLine >= xMaxScene)
-    {
+  {
     return true;
-    }
+  }
 
   // case where the X range of the line falls within the visible scene
   // and the Y range of the line contains the entire visible scene
   if (xMinScene <= xMinLine && xMaxScene >= xMinLine &&
       xMinScene <= xMaxLine && xMaxScene >= xMaxLine &&
       yMinLine <= yMinScene && yMaxLine >= yMaxScene)
-    {
+  {
     return true;
-    }
+  }
 
   return false;
 }
@@ -758,7 +798,7 @@ bool vtkHeatmapItem::LineIsVisible(double x0, double y0,
 bool vtkHeatmapItem::MouseMoveEvent(const vtkContextMouseEvent &event)
 {
   if (event.GetButton() == vtkContextMouseEvent::NO_BUTTON)
-    {
+  {
     float pos[3];
     vtkNew<vtkMatrix3x3> inverse;
     pos[0] = event.GetPos().GetX();
@@ -768,25 +808,25 @@ bool vtkHeatmapItem::MouseMoveEvent(const vtkContextMouseEvent &event)
     inverse->MultiplyPoint(pos, pos);
     if (pos[0] <= this->MaxX && pos[0] >= this->MinX &&
         pos[1] <= this->MaxY && pos[1] >= this->MinY)
-      {
+    {
       this->Tooltip->SetPosition(pos[0], pos[1]);
 
       std::string tooltipText = this->GetTooltipText(pos[0], pos[1]);
       if (tooltipText.compare("") != 0)
-        {
+      {
         this->Tooltip->SetText(tooltipText);
         this->Tooltip->SetVisible(true);
         this->Scene->SetDirty(true);
         return true;
-        }
       }
+    }
     bool shouldRepaint = this->Tooltip->GetVisible();
     this->Tooltip->SetVisible(false);
     if (shouldRepaint)
-      {
+    {
       this->Scene->SetDirty(true);
-      }
     }
+  }
   return false;
 }
 
@@ -798,47 +838,45 @@ std::string vtkHeatmapItem::GetTooltipText(float x, float y)
   int orientation = this->GetOrientation();
   if (orientation == vtkHeatmapItem::UP_TO_DOWN ||
       orientation == vtkHeatmapItem::DOWN_TO_UP)
-    {
-    sceneRow = floor(abs(x - this->Position[0]) / this->CellHeight);
-    sceneColumn = floor((y - this->MinY) / this->CellWidth);
-    }
+  {
+    sceneRow = static_cast<int>(floor(fabs(x - this->Position[0]) / this->CellHeight));
+    sceneColumn = static_cast<int>(floor((y - this->MinY) / this->CellWidth));
+  }
   else
-    {
-    sceneRow = floor(abs(y - this->Position[1]) / this->CellHeight);
-    sceneColumn = floor((x - this->MinX) / this->CellWidth);
-    }
+  {
+    sceneRow = static_cast<int>(floor(fabs(y - this->Position[1]) / this->CellHeight));
+    sceneColumn = static_cast<int>(floor((x - this->MinX) / this->CellWidth));
+  }
 
   vtkIdType row = -1;
   if (static_cast<unsigned int>(sceneRow) < this->SceneRowToTableRowMap.size())
-    {
+  {
     row = this->SceneRowToTableRowMap[sceneRow];
-    }
+  }
   vtkIdType column = -1;
   if (static_cast<unsigned int>(sceneColumn) <
       this->SceneColumnToTableColumnMap.size())
-    {
+  {
     column = this->SceneColumnToTableColumnMap[sceneColumn];
-    }
+  }
 
   if (row > -1 && column > -1)
-    {
-    vtkStringArray *rowNames = vtkStringArray::SafeDownCast(
-      this->Table->GetColumn(0));
+  {
     std::string rowName;
-    if (rowNames)
-      {
-      rowName = rowNames->GetValue(row);
-      }
+    if (this->RowNames)
+    {
+      rowName = this->RowNames->GetValue(row);
+    }
     else
-      {
+    {
       std::stringstream ss;
       ss << row;
       rowName = ss.str();
-      }
+    }
     if (this->BlankRows.find(rowName) != this->BlankRows.end())
-      {
+    {
       return "";
-      }
+    }
 
     std::string columnName = this->Table->GetColumn(column)->GetName();
 
@@ -850,28 +888,28 @@ std::string vtkHeatmapItem::GetTooltipText(float x, float y)
     tooltipText += this->Table->GetValue(row, column).ToString();
 
     return tooltipText;
-    }
+  }
   return "";
 }
 
 //-----------------------------------------------------------------------------
 void vtkHeatmapItem::SetOrientation(int orientation)
 {
-  vtkIntArray *existingArray = vtkIntArray::SafeDownCast(
+  vtkIntArray *existingArray = vtkArrayDownCast<vtkIntArray>(
     this->Table->GetFieldData()->GetArray("orientation"));
   if (existingArray)
-    {
+  {
     existingArray->SetValue(0, orientation);
-    }
+  }
   else
-    {
+  {
     vtkSmartPointer<vtkIntArray> orientationArray =
       vtkSmartPointer<vtkIntArray>::New();
     orientationArray->SetNumberOfComponents(1);
     orientationArray->SetName("orientation");
     orientationArray->InsertNextValue(orientation);
     this->Table->GetFieldData()->AddArray(orientationArray);
-    }
+  }
 
   //reposition the legends
   this->PositionLegends(orientation);
@@ -880,12 +918,12 @@ void vtkHeatmapItem::SetOrientation(int orientation)
 //-----------------------------------------------------------------------------
 int vtkHeatmapItem::GetOrientation()
 {
-  vtkIntArray *orientationArray = vtkIntArray::SafeDownCast(
+  vtkIntArray *orientationArray = vtkArrayDownCast<vtkIntArray>(
     this->Table->GetFieldData()->GetArray("orientation"));
   if (orientationArray)
-    {
+  {
     return orientationArray->GetValue(0);
-    }
+  }
   return vtkHeatmapItem::LEFT_TO_RIGHT;
 }
 
@@ -893,24 +931,20 @@ int vtkHeatmapItem::GetOrientation()
 double vtkHeatmapItem::GetTextAngleForOrientation(int orientation)
 {
   switch(orientation)
-    {
+  {
     case vtkHeatmapItem::DOWN_TO_UP:
       return 90.0;
-      break;
 
     case vtkHeatmapItem::RIGHT_TO_LEFT:
       return 0.0;
-      break;
 
     case vtkHeatmapItem::UP_TO_DOWN:
       return 270.0;
-      break;
 
     case vtkHeatmapItem::LEFT_TO_RIGHT:
     default:
       return 0.0;
-      break;
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -922,52 +956,54 @@ void vtkHeatmapItem::ComputeLabelWidth(vtkContext2D *painter)
   int fontSize = painter->ComputeFontSizeForBoundedString("Igq", VTK_FLOAT_MAX,
                                                           this->CellHeight);
   if (fontSize < 8)
-    {
+  {
     return;
-    }
+  }
 
   // temporarily set text to default orientation
-  int orientation = painter->GetTextProp()->GetOrientation();
+  double orientation = painter->GetTextProp()->GetOrientation();
   painter->GetTextProp()->SetOrientation(0.0);
 
   float bounds[4];
   // find the longest row label
-  vtkStringArray *rowNames = vtkStringArray::SafeDownCast(
-    this->Table->GetColumn(0));
-  if (rowNames)
-    {
+  if (this->RowNames)
+  {
 
     for (vtkIdType row = 0; row != this->Table->GetNumberOfRows(); ++row)
-      {
+    {
       if (this->CollapsedRowsArray &&
           this->CollapsedRowsArray->GetValue(row) == 1)
-        {
+      {
         continue;
-        }
-      std::string name = rowNames->GetValue(row);
+      }
+      std::string name = this->RowNames->GetValue(row);
       painter->ComputeStringBounds(name, bounds);
       if (bounds[2] > this->RowLabelWidth)
-        {
+      {
         this->RowLabelWidth = bounds[2];
-        }
       }
     }
+  }
 
   // find the longest column label
-  for (vtkIdType col = 1; col != this->Table->GetNumberOfColumns(); ++col)
+  for (vtkIdType col = 0; col != this->Table->GetNumberOfColumns(); ++col)
+  {
+    if (this->Table->GetColumn(col) == this->GetRowNames())
     {
+      continue;
+    }
     if (this->CollapsedColumnsArray &&
         this->CollapsedColumnsArray->GetValue(col) == 1)
-      {
+    {
       continue;
-      }
+    }
     std::string name = this->Table->GetColumn(col)->GetName();
     painter->ComputeStringBounds(name, bounds);
     if (bounds[2] > this->ColumnLabelWidth)
-      {
+    {
       this->ColumnLabelWidth = bounds[2];
-      }
     }
+  }
 
   // restore orientation
   painter->GetTextProp()->SetOrientation(orientation);
@@ -980,48 +1016,52 @@ void vtkHeatmapItem::ComputeBounds()
   bool currentlyCollapsingRows = false;
   int numRows = 0;
   for (vtkIdType row = 0; row != this->Table->GetNumberOfRows(); ++row)
-    {
+  {
     if (this->CollapsedRowsArray &&
         this->CollapsedRowsArray->GetValue(row) == 1)
-      {
+    {
       // a contiguous block of collapsed rows is represented as a single blank
       // row by this item.
       if (!currentlyCollapsingRows)
-        {
+      {
         ++numRows;
         currentlyCollapsingRows = true;
-        }
-      continue;
       }
+      continue;
+    }
     currentlyCollapsingRows = false;
     ++numRows;
-    }
+  }
 
   // figure out how many actual columns will be drawn
   bool currentlyCollapsingColumns = false;
   int numColumns = 0;
-  for (vtkIdType col = 1; col != this->Table->GetNumberOfColumns(); ++col)
+  for (vtkIdType col = 0; col != this->Table->GetNumberOfColumns(); ++col)
+  {
+    if (this->Table->GetColumn(col) == this->GetRowNames())
     {
+      continue;
+    }
     if (this->CollapsedColumnsArray &&
         this->CollapsedColumnsArray->GetValue(col) == 1)
-      {
+    {
       // a contiguous block of collapsed columns is represented as a single blank
       // column by this item.
       if (!currentlyCollapsingColumns)
-        {
+      {
         ++numColumns;
         currentlyCollapsingColumns = true;
-        }
-      continue;
       }
+      continue;
+    }
     currentlyCollapsingColumns = false;
     ++numColumns;
-    }
+  }
 
   this->MinX = this->Position[0];
   this->MinY = this->Position[1];
   switch (this->GetOrientation())
-    {
+  {
     case vtkHeatmapItem::RIGHT_TO_LEFT:
     case vtkHeatmapItem::LEFT_TO_RIGHT:
     default:
@@ -1034,7 +1074,7 @@ void vtkHeatmapItem::ComputeBounds()
       this->MaxX = this->MinX + this->CellHeight * numRows;
       this->MaxY = this->MinY + this->CellWidth * numColumns;
       break;
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -1046,14 +1086,14 @@ void vtkHeatmapItem::GetBounds(double bounds[4])
   bounds[3] = this->MaxY;
 
   if (this->RowLabelWidth == 0.0 && this->ColumnLabelWidth == 0.0)
-    {
+  {
     return;
-    }
+  }
 
   double spacing = this->CellWidth * 0.25;
 
   switch (this->GetOrientation())
-    {
+  {
     case vtkHeatmapItem::LEFT_TO_RIGHT:
     default:
       bounds[1] += spacing + this->RowLabelWidth;
@@ -1074,7 +1114,7 @@ void vtkHeatmapItem::GetBounds(double bounds[4])
       bounds[1] += spacing + this->ColumnLabelWidth;
       bounds[3] += spacing + this->RowLabelWidth;
       break;
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -1096,30 +1136,30 @@ bool vtkHeatmapItem::MouseDoubleClickEvent(const vtkContextMouseEvent &event)
   inverse->MultiplyPoint(pos, pos);
   if (pos[0] <= this->MaxX && pos[0] >= this->MinX &&
       pos[1] <= this->MaxY && pos[1] >= this->MinY)
-    {
+  {
     vtkIdType column = 0;
     int orientation = this->GetOrientation();
     if (orientation == vtkHeatmapItem::UP_TO_DOWN ||
         orientation == vtkHeatmapItem::DOWN_TO_UP)
-      {
-      column = floor((pos[1] - this->MinY) / this->CellWidth);
-      }
+    {
+      column = static_cast<vtkIdType>(floor((pos[1] - this->MinY) / this->CellWidth));
+    }
     else
-      {
-      column = floor((pos[0] - this->MinX) / this->CellWidth);
-      }
+    {
+      column = static_cast<vtkIdType>(floor((pos[0] - this->MinX) / this->CellWidth));
+    }
     ++column;
 
     if (!this->LegendPositionSet)
-      {
+    {
       this->PositionLegends(this->GetOrientation());
-      }
+    }
 
     if (this->Table->GetValue(0, column).IsString())
-      {
+    {
       // categorical data
       // generate an array of distinct values from this column
-      vtkStringArray *stringColumn = vtkStringArray::SafeDownCast(
+      vtkStringArray *stringColumn = vtkArrayDownCast<vtkStringArray>(
         this->Table->GetColumn(column));
       this->CategoryLegendValues->Reset();
       this->CategoryLegendValues->Squeeze();
@@ -1135,9 +1175,9 @@ bool vtkHeatmapItem::MouseDoubleClickEvent(const vtkContextMouseEvent &event)
       this->ColorLegend->SetVisible(false);
       this->Scene->SetDirty(true);
       return true;
-      }
+    }
     else
-      {
+    {
       // continuous data
       // set up the scalar bar legend
       this->ColorLegend->GetTransferFunction()->SetRange(
@@ -1151,16 +1191,16 @@ bool vtkHeatmapItem::MouseDoubleClickEvent(const vtkContextMouseEvent &event)
       this->CategoryLegend->SetVisible(false);
       this->Scene->SetDirty(true);
       return true;
-      }
     }
+  }
   bool shouldRepaint = this->ColorLegend->GetVisible() ||
                        this->CategoryLegend->GetVisible();
   this->CategoryLegend->SetVisible(false);
   this->ColorLegend->SetVisible(false);
   if (shouldRepaint)
-    {
+  {
     this->Scene->SetDirty(true);
-    }
+  }
 
   return false;
 }
@@ -1170,12 +1210,12 @@ void vtkHeatmapItem::PositionLegends(int orientation)
 {
   // bail out early if we don't have meaningful bounds yet.
   if (this->MinX > this->MaxX || this->MinY > this->MaxY)
-    {
+  {
     return;
-    }
+  }
 
   switch(orientation)
-    {
+  {
     case vtkHeatmapItem::DOWN_TO_UP:
     case vtkHeatmapItem::UP_TO_DOWN:
 
@@ -1216,7 +1256,7 @@ void vtkHeatmapItem::PositionLegends(int orientation)
         this->MaxX - this->MinX,
         this->ColorLegend->GetSymbolWidth());
       break;
-    }
+  }
   this->LegendPositionSet = true;
 }
 
@@ -1234,7 +1274,7 @@ void vtkHeatmapItem::PrintSelf(ostream &os, vtkIndent indent)
   this->Superclass::PrintSelf(os, indent);
   os << "Table: " << (this->Table ? "" : "(null)") << std::endl;
   if (this->Table->GetNumberOfRows() > 0)
-    {
+  {
     this->Table->PrintSelf(os, indent.GetNextIndent());
-    }
+  }
 }
