@@ -17,8 +17,8 @@
  * vtkWrap provides useful functions for generating wrapping code.
 */
 
-#ifndef VTK_WRAP_H
-#define VTK_WRAP_H
+#ifndef vtkWrap_h
+#define vtkWrap_h
 
 #include "vtkParse.h"
 #include "vtkParseHierarchy.h"
@@ -48,6 +48,7 @@ int vtkWrap_IsCharPointer(ValueInfo *val);
 int vtkWrap_IsPODPointer(ValueInfo *val);
 int vtkWrap_IsVTKObject(ValueInfo *val);
 int vtkWrap_IsSpecialObject(ValueInfo *val);
+int vtkWrap_IsPythonObject(ValueInfo *val);
 int vtkWrap_IsQtObject(ValueInfo *val);
 int vtkWrap_IsQtEnum(ValueInfo *val);
 /*@}*/
@@ -117,7 +118,7 @@ int vtkWrap_IsVTKObjectBaseType(
   HierarchyInfo *hinfo, const char *classname);
 
 /**
- * Check if the WRAP_SPECIAL flag is set for the class.
+ * Check whether the class is not derived from vtkObjectBase.
  * If "hinfo" is NULL, it defaults to just checking if
  * the class starts with "vtk" and returns -1 if so.
  */
@@ -132,6 +133,11 @@ int vtkWrap_IsSpecialType(
 int vtkWrap_IsTypeOf(
   HierarchyInfo *hinfo, const char *classname, const char *superclass);
 
+/**
+ * Check if the type of the value is an enum member of the class.
+ */
+int vtkWrap_IsEnumMember(ClassInfo *data, ValueInfo *arg);
+
 /**
  * Check whether a class is wrapped.  If "hinfo" is NULL,
  * it just checks that the class starts with "vtk".
@@ -157,6 +163,15 @@ int vtkWrap_HasPublicCopyConstructor(ClassInfo *data);
 void vtkWrap_ExpandTypedefs(
   ClassInfo *data, FileInfo *finfo, HierarchyInfo *hinfo);
 
+/**
+ * Apply any using declarations that appear in the class.
+ * If any using declarations appear in the class that refer to superclass
+ * methods, the superclass header file will be parsed and the used methods
+ * will be brought into the class.
+ */
+void vtkWrap_ApplyUsingDeclarations(
+  ClassInfo *data, FileInfo *finfo, HierarchyInfo *hinfo);
+
 /**
  * Apply any hints about array sizes, e.g. hint that the
  * GetNumberOfComponents() method gives the tuple size.
@@ -232,7 +247,8 @@ int vtkWrap_CountRequiredArguments(FunctionInfo *f);
  * - "const" is removed except for return values with "&" or "*".
  */
 void vtkWrap_DeclareVariable(
-  FILE *fp, ValueInfo *v, const char *name, int idx, int flags);
+  FILE *fp, ClassInfo *data, ValueInfo *v, const char *name,
+  int idx, int flags);
 
 /**
  * Write an "int" size variable for arrays, initialized to
@@ -242,6 +258,12 @@ void vtkWrap_DeclareVariable(
 void vtkWrap_DeclareVariableSize(
   FILE *fp, ValueInfo *v, const char *name, int idx);
 
+/**
+ * Makes a superclass name into a valid identifier. Returns NULL if the given
+ * name is valid as-is.
+ */
+char *vtkWrap_SafeSuperclassName(const char *name);
+
 
 #ifdef __cplusplus
 }
